<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 04/07/2018
 * Time: 14:43
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarTurbo;
use App\Admin\Dashboard\Models\Product;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\NewCarJob;
use App\Repasse\CarUtil;
use App\Repasse\Products\Turbo\ScheduleTurbo;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;

class AdminOrderController extends CoreController
{
    use DispatchesJobs;

    protected $user;

    public function __construct(Auth $auth)
    {
        $this->user = $auth::user();
    }

    public function orderCreate(Request $request, Response $response)
    {
        //variáveis: id do anúncio, id do produto

        // primeira verificação findorfail no anúncio
        // segunda verificação: Está em aberto? Está vencido?

        // definir claramente os caminhos: cortesia e pedido

        // fazer o pedido normal por aqui foi cancelado
        // pedido, faz a mesma coisa que o pedido do moip e o usuário é o dono do anúnci
        // pedido finaliza aqui; carturbo+moip+salvar dados do moip no banco

        // cortesia só cria o CarTurbo e o valor é zero e não faz a parte do moip
        // cortesia o user_id é o administrador logado
        // cortesia agenda as tarefas de acordo com o plano contratado (a mesma coisa que handleWebhook)
        // cortesia altera car_status_id do carro para nove
        // cortesia seta para


        $anuncio_id = $request->get('car_id');
        $product_id = $request->get('product_id');
        $user_id = $this->user->id;

        $car = Car::findOrFail($anuncio_id);
        $product = Product::findOrFail($product_id);

        if ( (int)$car->car_status_id !== 1 ) {
            $erro = '';
            $erro .= ((int)$car->car_status_id !== 1) ? ' anúncio não está aberto ' : '';
            $response->setStatusCode(400);
            $response->setContent(['error' => $erro]);
            return $response;
        }

        $Order = new CarTurbo();
        $Order->user_id = $user_id; // user id é o administrador logado
        $Order->car_id = $anuncio_id;
        $Order->status = 1;
        $Order->product_id = $product_id;
        $Order->price = 0; // Cortesia
        $Order->order_id = 'REPORD_' . uuidv4();
        $Order->order_status = 'ORDER.PAID';
        $Order->hired = $product->options['hired'];
        $Order->boost_interval_hours = $product->options['boost_interval_hours'];
        $Order->ad_airtime_hours = $product->options['ad_airtime_hours'];
        $Order->fulfilled = 0;

        if ( $Order->save() ) {

            $scheduler = new ScheduleTurbo($Order);
            $scheduler->run();

        }

        $response->setStatusCode(201);
        $response->setContent(['success' => true]);
        return $response;

    }

}