<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 14/02/2017
 * Time: 16:26
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Models\TokenBlackList;
use App\Admin\Dashboard\Models\UserBlacklist;
use App\Core\Http\Controllers\CoreController;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class BlacklistController extends CoreController
{
    protected $user;

    public function __construct(Auth $auth)
    {
        $this->user = $auth::user();
    }

    public function index()
    {
        // blacklist de token
        /** @var TokenBlackList $token */
        $token = TokenBlackList::all();
        // blacklist de cadastro
        $userbl = UserBlacklist::all();
        return view('admin::blacklist.index')->with('collapse', 'config')->with('tokens', $token)->with('users',
            $userbl);

    }

    public function create(Request $request)
    {

        $type = $request->get('blacklist_type');

        $rules = [
            'blacklist_type' => 'required',
            'blacklist_value' => 'required',
            'blacklist_reason' => 'required|max:255'
        ];

        // validar
        $this->validate($request, $rules);
        // Reason é qualquer coisa que veio do formulário mais o nome de quem pediu
        $reason = $request->blacklist_reason;
        $reason .= ' Solicitação: ' . $this->user->name;
        if ($type === 'token') {
            $find_token = TokenBlackList::where('device_token', $request->blacklist_value)->get();

            if ($find_token->isEmpty()) {
                $token_blacklist = TokenBlackList::create([
                    'attempts' => 0,
                    'device_token' => $request->blacklist_value,
                    'reason' => $reason
                ]);
            } else {
                if ($request->ajax() || $request->wantsJson()) {
                    return new JsonResponse(['Conteúdo informado já está na lista de restrições'], 422);
                } else {
                    return back()->withInput()->withErrors( 'Conteúdo informado já está na lista de restrições');
                }
            }

        } else {
            // limpar (menos token)
            $content = preg_replace("/\D/", '', $request->blacklist_value);

            if (empty($content)) {
                if ($request->ajax() || $request->wantsJson()) {
                    return new JsonResponse(['Campo está vazio'], 422);
                } else {
                    return back()->withInput()->withErrors('Campo está em branco!');
                }
            }

            $find = UserBlacklist::where('field_name', $request->blacklist_type)->where('field_content', $content)->get();

            if ($find->isEmpty()) {
                $user_blacklist = UserBlacklist::create([
                    'field_name' => $request->blacklist_type,
                    'field_content' => $content,
                    'reason' => $reason,
                    'attempts' => 0
                ]);
            } else {
                if ($request->ajax() || $request->wantsJson()) {
                    return new JsonResponse(['Conteúdo informado já está na lista de restrições'], 422);
                } else {
                    return back()->withInput()->withErrors( 'Conteúdo informado já está na lista de restrições');
                }
            }
        }

        if ($request->ajax() || $request->wantsJson()) {
            return new JsonResponse(['Sucesso'], 201);
        } else {
            return back();
        }
    }

}