<?php
/**
 * Created by PhpStorm.
 * User: Rafael
 * Date: 06/12/2016
 * Time: 13:36
 */

namespace App\Admin\Dashboard\Http\Controllers;

use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarEdit;
use App\Admin\Dashboard\Models\CarOptional;
use App\Admin\Dashboard\Models\CarPhoto;
use App\Admin\Dashboard\Models\CarPublish;
use App\Admin\Dashboard\Models\CarSell;
use App\Admin\Dashboard\Models\CarTurbo;
use App\Admin\Dashboard\Models\CarType;
use App\Admin\Dashboard\Models\Fipe;
use App\Admin\Dashboard\Models\FipeConfig;
use App\Admin\Dashboard\Models\Optional;
use App\Admin\Dashboard\Models\Store\Store;
use App\Auth\Models\User;
use App\Auth\Models\UserType;
use App\Chat\Agent;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\Car\CreateCarImageJob;
use App\Core\Jobs\CarStatusPodioJob;
use App\Core\Jobs\EditCarPodioJob;
use App\Core\Jobs\NewCarJob;
use App\Core\Jobs\NewCarPodioJob;
use App\Repasse\AnuncioFileUpload;
use App\Repasse\Audit\CopyCar;
use App\Repasse\CarUtil;
use App\Repasse\Fipe\FipeLimit;
use App\Repasse\Products\Turbo\ScheduleTurbo;
use App\Repasse\Services\ImageService;
use App\Transformers\Staff\StaffTransformer;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class CarController extends CoreController
{
    use DispatchesJobs;

    private $user;
    private $auth;
    private $request;

    public function __construct(Auth $auth, User $user, Request $request)
    {
        $this->user = $user;
        $this->auth = $auth::user();
        $this->request = $request;

    }

    public function newCar($vendedor_id = null)
    {
        //$vendedores = $this->user->where('role_id', 2)->where('is_aprovado', 1)->orderBy('name', 'ASC')->select('id', 'name', 'dealership')->get();

        $stores = Store::all();
        $tipos = CarType::get(['id', 'name']);
        $user_types = UserType::get(['id', 'name']);

        return view('admin::dashboard.cadastro')
            ->with('vendedor_id', $vendedor_id)
            ->with('tipos', $tipos)
            ->with('user_types', $user_types)
            ->with('stores', $stores)
            ->with('collapse', 'anuncio');
    }

    public function store()
    {

        $this->validate(
            $this->request,
            [
                'color_id' => ['required'],
                'brand_id' => ['required'],
                'fipe_id' => ['required'],
                'year' => ['required'],
                'observation' => ['required'],
                'price' => ['required'],
                'km' => ['required']

            ]);

        $params = $this->request->all();

        $car = new Car();
        $car->fill($params);

        /*
         * Ticket#490 o status do anúncio é sempre em cadastro
         * o que faz ele ser publicado é a rotina new car job
         */
        $car_status_id = $params['status'];
        $car->car_status_id = 4;

        $price = str_replace(['R$ ', '.', ','], ['', '', '.'], trim($params['price']));
        $car->km = str_replace(['.', ','], ['', '.'], trim($params['km']));
        $car->price = $price;

        $user = $this->user->find($params['vendedor']);
        $car->user_id = $user->id;
        $car->user_ddd = substr($user->cell_phone, 0, 2);
        $fipe = Fipe::find($params['fipe_id']);
        $car->fipe_price = $fipe->price;
        $car->car_type = $fipe->type;
        $car->doors = !empty($params['doors']) ? $params['doors'] : null;

        // Verificação da fipe para carros exclusivos de site

        $fipe_percent = FipeLimit::getDefaultFipePercent($user->user_type, $fipe->year);
        $percent = -1 * abs($fipe_percent);

        $fipe = ($price - $car->fipe_price) / $car->fipe_price * 100;


        $has_site = false;
        if ($fipe > $percent) {
            //
            $stores = $user->stores;

            foreach ($stores as $store) {
                if ($store->site) {
                    $has_site = true;
                }
            }

            if (!$has_site) {
                return redirect(route('admin.car.new'))->withErrors('Falha ao cadastrar o anúncio viola regra da Fipe');
            }
        }

        $car->site_only = $has_site;

        if ($car->save()) {
            if (isset($params['optionals'])) {
                $car_optional_original = new CarOptional();
                foreach ($params['optionals'] as $optional_id) {
                    $car_optional = clone $car_optional_original;
                    $car_optional->optional_id = $optional_id;
                    $car_optional->car_id = $car->id;
                    $car_optional->save();
                }
            }

            if (isset($params['user_types'])) {
                foreach ($params['user_types'] as $user_type) {
                    $carPublish = CarPublish::create(
                        [
                            'car_id' => $car->id,
                            'user_type' => $user_type
                        ]
                    );
                }
            }

            $files = $this->request->file('filename');
            foreach ($files as $file) {
                AnuncioFileUpload::create($car->id, $file);
            }

            $podioJob = (new NewCarPodioJob($car))->onQueue('push');
            $this->dispatch($podioJob);

            if ($car_status_id == 1) {

                if ($has_site) {
                    // Anúncio exclusivo do site
                    $car->car_status_id = $car_status_id;
                    $car->published_at = Carbon::now();
                    $car->save();
                } else {
                    $carob = new CarUtil($car);
                    $car_data = $carob->getCarObject();

                    $job = (new NewCarJob($car_data))->onQueue('push');
                    $this->dispatch($job);
                }
            }

            return redirect(route('admin.car.new'))->with('status', 'Anúncio cadastrado com sucesso!')->with('car_id',
                $car->id);

        } else {
            return redirect(route('admin.car.new'))->withErrors('Falha ao cadastrar o anúncio');
        }

    }

    public function publishCar()
    {
        $response = new Response();
        $car_id = $this->request->get('car_id');
        $action = $this->request->get('action');
        //$publicar = $this->request->get('user_type');

        // Pegar o carro
        $car = Car::find($car_id);
        if ($car) {
            if ($action === 'publicar') {
                // Verificar status
                // Carro só pode ser publicado se estiver com status 4 ou 5
                if (in_array($car->car_status_id, [1, 2, 3, 6, 7])) {
                    $response->setStatusCode(400);
                    $response->setContent([
                        'success' => false,
                        'msg' => 'Carro não pode ser publicado (Status Inválido)'
                    ]);
                    return $response;
                }

                if ($car->expirado) {
                    $response->setStatusCode(400);
                    $response->setContent([
                        'success' => false,
                        'msg' => 'Carro não pode ser publicado (Anúncio expirado)'
                    ]);
                    return $response;
                }

                // Contar as fotos
                $car_photo = CarPhoto::where('car_id', $car_id)->count();
                if (($car_photo > 4) OR ($car_photo < 10)) {

                    // Enviar o push

                    $carob = new CarUtil($car);
                    $car_data = $carob->getCarObject();

                    if (empty($car_data->visible_to)) {
                        $response->setStatusCode(400);
                        $response->setContent([
                            'success' => false,
                            'msg' => 'Carro não pode ser publicado (Público não selecionado)'
                        ]);
                        return $response;

                    }

                    // Aqui entra a lógica do turbo pendente ;)
                    // Selecionar um pedido com delayed_schedule = 1
                    $pedido = CarTurbo::where('car_id', $car_id)->where('delayed_schedule', 1)->first();

                    if ($pedido) {
                        $schedule = new ScheduleTurbo($pedido);
                        $schedule->run();
                    } else {
                        // eventualmente esta parte não existirá mais pois o anúncio novo não será mais enviado push.
                        $job = (new NewCarJob($car_data))->onQueue('push');
                        $this->dispatch($job);

                    }


                } else {
                    $response->setStatusCode(409);
                    $response->setContent([
                        'success' => false,
                        'msg' => 'A quantidade de fotos difere da solicitada (entre 4 e 10)'
                    ]);
                    return $response;
                }
            }

            if ($action === 'despublicar') {

                // Despublicar
                $car->car_status_id = 4;
                $car->save();

                $podioStatusJob = (new CarStatusPodioJob($car, 4))->onQueue('push');
                $this->dispatch($podioStatusJob);

                return ['success' => true, 'msg' => 'Carro teve a publicação removida com sucesso'];
            }

            if ($action === 'liberar') {
                $car_status_id = 1;
                $car->car_status_id = $car_status_id;
                $car->is_edited = 0;
                $car->save();

                $host = config('chat.host');
                $port = config('chat.port');
                $token = config('chat.token');
                $message = [
                    'sender_id' => $car->user_id,
                    'receiver_id' => null,
                    'car_id' => $car->id,
                    'car_status_id' => $car_status_id
                ];

                $podioStatusJob = (new CarStatusPodioJob($car, 1))->onQueue('push');
                $this->dispatch($podioStatusJob);

                $agent = new Agent($host, $port, $token);
                $agent->sendMessage($message);

                return ['success' => true, 'msg' => 'Carro teve a publicação liberada com sucesso'];
            }

            if ($action === 'reativar') {

                if ($car->published_at <= 0) {
                    // Correção para tarefa #645 anúncio precisa ter data de publicação
                    // Anúncio não foi publicado ainda então não pode ser reativado
                    $response->setStatusCode(400);
                    $response->setContent([
                        'success' => false,
                        'msg' => 'Anúncio não pode ser reativado pois nunca foi publicado'
                    ]);
                    return $response;

                }

                $car_status_id = 1;
                $car->car_status_id = $car_status_id;
                $car->save();

                // Se tiver alguma venda desse carro remover aqui:
                $venda = CarSell::where('car_id', $car->id)->delete();

                $host = config('chat.host');
                $port = config('chat.port');
                $token = config('chat.token');
                $message = [
                    'sender_id' => $car->user_id,
                    'receiver_id' => null,
                    'car_id' => $car->id,
                    'car_status_id' => $car_status_id
                ];
                $agent = new Agent($host, $port, $token);
                $agent->sendMessage($message);

                return ['success' => true, 'msg' => 'Anúncio reativado com sucesso'];
            }

        } else {
            $response->setStatusCode(404);
            $response->setContent(['success' => false, 'msg' => 'Veículo não encontrado!']);
            return $response;
        }
    }

    public function editCar($car_id)
    {
        // Mandar limite da fipe pelo usuário proprietário
        $car = Car::findOrFail($car_id);
        $fipe = FipeLimit::getFipePercent($car->user, $car->year);
        $carUtil = new CarUtil($car);
        $optionals = Optional::where('type', $car->car_type)->get();

        return view('admin::dashboard.edicao')
            ->with('anuncio', $carUtil->getCarObject())
            ->with('fipe', $fipe)
            ->with('optionals', $optionals)
            ->with('collapse', 'anuncio');
    }

    public function updateCar()
    {
        $car_id = $this->request->get('car_id');
        // Car Object
        $car = Car::findOrFail($car_id);
        $carUtil = new CarUtil($car);
        $carEdit = new CarEdit();
        // Pega cópia
        $copyCar = new CopyCar($carEdit, $this->auth->id, $carUtil->getCarObject(), 1);
        $copyCar->make();
        // Salva novo
        $this->validate(
            $this->request,
            [
                'price' => ['required'],
                'color_id' => ['required'],
                'km' => ['required'],
                'observation' => ['required']
            ]);

        $params = $this->request->all();

        $car->km = str_replace(['.', ','], ['', '.'], trim($params['km']));
        $car->price = str_replace(['R$ ', '.', ','], ['', '', '.'], trim($params['price']));
        $car->doors = !empty($params['doors']) ? $params['doors'] : null;
        $car->color_id = $params['color_id'];
        $car->observation = $params['observation'];
        // Ticekt#458 - Fipe
        $fipe = Fipe::find($car->fipe_id);
        $car->fipe_price = $fipe->price;

        // Remove opcionais
        $car->optionals()->delete();

        if (isset($params['optionals'])) {
            $car_optional_original = new CarOptional();
            foreach ($params['optionals'] as $optional_id) {
                $car_optional = clone $car_optional_original;
                $car_optional->optional_id = $optional_id;
                $car_optional->car_id = $car->id;
                $car_optional->save();
            }
        }

        if ($car->save()) {

            $editCarJob = (new EditCarPodioJob($car))->onQueue('push');
            $this->dispatch($editCarJob);

            $printJob = (new CreateCarImageJob($car))->onQueue('push');
            $this->dispatch($printJob);

            return redirect(route('admin.car.edit', $car->id))->with('status',
                'Anúncio alterado com sucesso!')->with('car_id', $car->id);
        } else {
            return redirect(route('admin.car.edit', $car->id))->withErrors('Falha ao editar o anúncio');
        }
    }

    public function photoRemove()
    {
        $photo_id = $this->request->get('photo_id');
        $photo = CarPhoto::findOrFail($photo_id);
        $car = Car::findOrFail($photo->car_id);
        $carUtil = new CarUtil($car);
        // Cópia do anúncio
        $carEdit = new CarEdit();
        // Pega cópia
        $copyCar = new CopyCar($carEdit, $this->auth->id, $carUtil->getCarObject(), 2);
        $copyCar->make();
        // Remove photo do banco
        if ($photo->delete()) {
            // Retorna
            return ['success' => true, 'msg' => 'Foto removida!'];
        } else {
            $response = new Response();
            $response->setStatusCode(500);
            $response->setContent(['success' => false, 'msg' => 'Falha ao remover a foto']);
            return $response;
        }
    }

    public function photoUpload()
    {
        $car_id = $this->request->get('car_id');
        $car = Car::findOrFail($car_id);

        if ($this->request->hasFile('filename')) {
            $carUtil = new CarUtil($car);
            $carEdit = new CarEdit();
            $copyCar = new CopyCar($carEdit, $this->auth->id, $carUtil->getCarObject(), 2);
            $copyCar->make();

            $files = $this->request->file('filename');
            foreach ($files as $file) {
                AnuncioFileUpload::create($car->id, $file);
            }
            return redirect(route('admin.car.edit', $car->id))->with('status',
                'Anúncio alterado com sucesso!')->with('car_id', $car->id);
        } else {
            return redirect(route('admin.car.edit',
                $car->id))->withErrors('Nenhuma foto foi selecionada!')->with('car_id', $car->id);
        }
    }

    public function photoFirst()
    {
        $photo_id = $this->request->get('photo_id');
        $photo = CarPhoto::findOrFail($photo_id);

        $car = Car::findOrFail($photo->car_id);
        $carUtil = new CarUtil($car);
        $carEdit = new CarEdit();

        $copyCar = new CopyCar($carEdit, $this->auth->id, $carUtil->getCarObject(), 2);
        $copyCar->make();

        $setFirstPhoto = $carUtil->setFirstPhoto($photo->id);
        $photos = $carUtil->getCarPhotos();
        return $photos;

    }

    public function listPublishables()
    {
        //$cars = Car::whereIn('car_status_id', [1,4])->orderByRaw(\DB::raw("FIELD(car_status_id, 4,1)"))->get();


        $cars = Car::join('user', 'user.id', '=', 'car.user_id')
            ->join('fipe', 'fipe.id', '=', 'car.fipe_id')
            ->whereIn('car_status_id', [1, 4])
            ->orderByRaw(\DB::raw(' FIELD(car_status_id, 4,1) '))->select('car.*', 'user.dealership', 'user.name',
                'fipe.model', 'fipe.year as anomodelo')->get();


        /*

                $results = [];

                foreach ($cars as $car) {
                    $carUtil = new CarUtil($car);
                    $results[] = $carUtil->getCarObject();
                }
        */
        return view('admin::dashboard.carpublish')->with('anuncios', $cars)->with('collapse', 'anuncio');
    }

    public function listUsers($type)
    {
        $users = DB::table('user')->where('role_id', 2)->where('is_aprovado', 1)->where('user_type',
            $type)->orderBy('name', 'ASC')->select('id', 'name', 'dealership')->get();
        $response = new Response();
        $response->setContent($users);
        return $response;
    }


    public function getAllStaff(Response $response, $store_id)
    {
        if (!$store = Store::find($store_id)) {
            $response->setStatusCode(404);
            $response->setContent(['success' => false, 'msg' => 'Não encontrado', 'errors' => []]);
            return $response;
        }

        $users = \DB::select('SELECT user_id FROM store_user WHERE store_id = ?', [$store_id]);
        $staff = User::whereIn('id', array_pluck($users, 'user_id'))->get(['id', 'name', 'user_type']);

        $response->setContent($staff);
        return $response;

    }

    public function getFipeLimit($user_id, $year, Response $response)
    {
        $user = User::findOrFail($user_id);

        $response->setContent(['success' => true, 'fipe_percent' => FipeLimit::getFipePercent($user, $year)]);
        return $response;
    }

    public function photoPrint($car_id)
    {
        $car = Car::findOrFail($car_id);
        ImageService::generateSaveImage($car);

        return ['success' => true, 'msg' => 'Imagem gerada com sucesso!'];

    }

}