<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 29/12/2016
 * Time: 14:52
 */

namespace App\Admin\Dashboard\Http\Controllers;

use App\Admin\Dashboard\Http\Requests\SaveConfigFipeRequest;
use App\Admin\Dashboard\Models\FipeConfig;
use App\Auth\Models\UserType;
use App\Core\Jobs\Fipe\AutoVinculoFipeJob;
use App\Repasse\Fipe\FipeApiService;
use App\Repasse\Search\SearchPopulate;
use Illuminate\Foundation\Bus\DispatchesJobs;
use App\Admin\Dashboard\Models\Config;
use App\Admin\Dashboard\Models\Fipe;
use App\Admin\Dashboard\Models\Modelo;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\SalvarFipe;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;
use League\Csv\Reader;
use Input;
use DB;
use Redirect;


class FipeController extends CoreController
{
    use DispatchesJobs;

    public function config(Request $request, FipeApiService $fipeApiService)
    {

        $params = Input::all();

        if (!empty($params)) {

            // Salvar o arquivo no storage
            $file = $request->file('filePlanilhaFIPE');
            $extension = $file->getClientOriginalExtension();
            $filename = $file->getFilename() . '.' . $extension;
            $original_filename = $file->getClientOriginalName();

            Storage::disk('fipe')->put($filename, File::get($file));

            // FIPE NOVA
            $csv = Reader::createFromString(File::get($file));
            $csv->setDelimiter(';');
            $headers = $csv->fetchOne();
            foreach ($headers as &$item) {
                if (preg_match('/med/', $item)) {
                    $item = getAnoColuna($item);
                }

                if ($item === 'novo_g') {
                    $item = 'Zero KM';
                }
            }
            
          //  dd($headers);

            $csv->setOffset(1);
            $lista = $csv->fetch();

            $Fipe = [];

            foreach ($lista as $row) {
                $res = array_combine($headers, $row);
                // dd($res);

                $carro['Marca'] = (isset($res['Marca']) ? $res['Marca'] : $res['marca']);
                $carro['Modelo'] = (isset($res['Modelo']) ? $res['Modelo'] : $res['modelo']);
                $carro['Fipe'] = $res['cod_fipe'];
                $carro['Tipo'] = $res['cod_fipe'][0];
                switch ($res['cod_fipe'][0]) {
                    case(5):
                        $res['Combus'] = 'DDD';
                        break;
                    case(8):
                        $res['Combus'] = 'GGG';
                        break;
                }
                $carro['Combustivel'] = isset($res['Combus']) ? $res['Combus'] : '';
                $carro['Anos'] = [];


                foreach ($res as $key => $value) {
                    if (is_numeric($key) || $key === 'Zero KM' ) {
                        if (!empty($value)) {
                            $carro['Anos'][$key] = $value;
                        }
                    }

                }

                /*echo '<pre>';
                // var_dump($carro['Fipe']);
                // var_dump($carro['Anos']);
                var_dump($carro);
                echo '</pre>';*/
                $Fipe[] = $carro;
            }
           // dd('fim');

            // FIM FIPE NOVA

            $user = Auth::user();
            $objMail = new \stdClass();
            $objMail->destinoNome = $user->name;
            $objMail->destinoEmail = $user->email;
            $objMail->filename = $original_filename;
            $jsonFipe = json_encode($Fipe);

            $job = (new SalvarFipe($jsonFipe, $objMail))->onQueue('Fipe');
            $this->dispatch($job);

        }

        $config = Config::find(1);
        $user_types = UserType::all();
        $fipe_configs = FipeConfig::orderBy('user_type_id')->orderBy('fipe_year')->get();
        $current_fipe_table_info = \Cache::remember('current_fipe_table_info',60 ,function() use ($fipeApiService) {
            return $fipeApiService->fetchCurrentTableId();
        });
        $years = SearchPopulate::getYears();

        return view('admin::fipe.config')
            ->with('current_fipe_table_info', $current_fipe_table_info)
            ->with('edtPorcentagemFIPE', $config)
            ->with('user_types', $user_types)
            ->with('fipe_configs', $fipe_configs)
            ->with('years', $years)
            ->with('collapse', 'fipe');

    }

    public function configCreate(SaveConfigFipeRequest $request, Response $response): Response
    {
        $user_type_id = $request->get('user_type_id');
        $fipe_percent = $request->get('fipe_percent');
        // Da lista inicial e final gerar um range
        $start_year = $request->get('start_year', 9999);
        $end_year   = $request->get('end_year', 9999);


        $ranges = range($start_year, $end_year);

        foreach ($ranges as $range) {
            $fipe = FipeConfig::where('user_type_id', $user_type_id)->where('fipe_year', $range)->first();

            if(!empty($fipe)) {
                $fipe->fipe_percent = $fipe_percent;
                $fipe->save();
            } else {
                $fipe = FipeConfig::create(['user_type_id' => $user_type_id, 'fipe_year' => $range, 'fipe_percent' => $fipe_percent]);
            }
        }

        $response->setContent(['success' => true, 'msg' => 'Dados cadastrados com sucesso']);
        return $response;

    }


    public function listOrfaos()
    {

        $versoes = Fipe::listOrfaos();

        foreach($versoes as &$versao) {
            //
            //$versao->possiveis = Fipe::with('modelos')->where('code', $versao->code)->where('modelo_id', '!=', 0)->get();

            $versao->possiveis = DB::table('fipe')
                ->join('modelos', 'modelos.id', '=', 'fipe.modelo_id')
                ->where('code', $versao->code)
                ->select(['fipe.modelo_id', 'modelos.name as modelo'])
                ->groupBy('modelos.id')
                ->get();
        }


        return view('admin::fipe.orfaos')->with('versoes', $versoes)->with('collapse', 'fipe');

    }

    public function populateModel($car_type, $brand_id)
    {
        $modelos = Modelo::where('car_type', $car_type)->where('brand_id', $brand_id)->orderBy('name', 'ASC')->get();
        return ['success' => true, 'data' => $modelos];
    }

    public function saveOrfaos(Request $request)
    {

        $codes = $request->get('code');
        $modelo_id = $request->get('modelo_id');
        $atualizar = Fipe::whereIn('code', $codes)
            ->update(['modelo_id' => $modelo_id]);
        if ($atualizar) {
            return ['success' => true, 'msg' => 'Dados atualizados com sucesso!'];
        } else {
            $response = new Response();
            $response->setStatusCode(500);
            $response->setContent(['success' => false, 'msg' => 'Falha ao atualizar os dados']);
            return $response;
        }

    }

    public function fipeModelos()
    {
        $modelos = DB::table('modelos')
            ->join('car_types', 'modelos.car_type', '=', 'car_types.id')
            ->join('brand', 'brand.id', '=', 'modelos.brand_id')
            ->select('modelos.id as id', 'car_types.name as tipo ', 'brand.name as marca', 'modelos.name as modelo',
                'car_types.id as idtipo', 'brand.id as idmarca')
            ->get();

        return view('admin::fipe.modelos')->with('modelos', $modelos)->with('collapse', 'fipe');
    }

    public function saveModelo(Request $request)
    {

        if (empty($request->get('inputId'))) {
            $modelo = Modelo::create([
                'car_type' => $request->get('inputTipo'),
                'brand_id' => $request->get('inputMarca'),
                'name' => $request->get('inputModelo')
            ]);
        } else {
            $modelo = Modelo::find($request->get('inputId'));
            $modelo->car_type = $request->get('inputTipo');
            $modelo->brand_id = $request->get('inputMarca');
            $modelo->name = $request->get('inputModelo');
            $modelo->save();

        }

        return ['success' => true, 'msg' => 'Modelo salvo com sucesso!'];

    }

    public function viewModelo($modelo_id)
    {

        $modelo = Modelo::findOrFail($modelo_id);

        return view('admin::fipe.modelo')->with('modelo', $modelo)->with('colapse', 'fipe');

    }

    public function createOrfaos(Request $request, Response $response)
    {
        //
        $this->validate($request, [
            'fipe_code' => 'required'
        ]);

        Fipe::where('code', $request->get('fipe_code'))->update(['modelo_id' => 0]);

        $response->setContent(['success' => true, 'msg' => 'Vinculo removido com sucesso!']);

        return $response;
    }

    public function configRemove($config_id)
    {
        FipeConfig::destroy($config_id);

        return ['success' => true];

    }

    public function autoOrfaos()
    {
        // usuário logado etc etc
        $user = Auth::user();
        $job = (new AutoVinculoFipeJob($user->email))->onQueue('Fipe');
        $this->dispatch($job);

        return ['success' => true];

    }

    public function saveTabelaConfig(Request $request)
    {
        $codTabelaFipe = $request->get('edtCodigoFipe');
        $config = Config::findOrFail(1);
        $config->current_fipe_table_id = $codTabelaFipe;
        $config->save();

        return Redirect::route('admin.fipe.config');
    }

}