<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 03/02/2017
 * Time: 11:45
 */

namespace App\Admin\Dashboard\Http\Controllers;

use App\Admin\Dashboard\Models\CarTurbo;
use App\Core\Jobs\CarStatusPodioJob;
use App\Core\Jobs\PushNotificationJob;
use Illuminate\Foundation\Bus\DispatchesJobs;
use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarEdit;
use App\Admin\Dashboard\Models\CarIncident;
use App\Auth\Models\User;
use App\Chat\Agent;
use App\Core\Http\Controllers\CoreController;
use App\Push\PushNotification;
use App\Repasse\Audit\Edits;
use App\Repasse\CarUtil;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Log;


class ModerarController extends CoreController
{

    use DispatchesJobs;

    private $car;

    public function __construct(Car $car)
    {
        $this->car = $car;
    }

    public function index()
    {

        $carros_moderar = $this->car->join('user', 'car.user_id', '=', 'user.id')
            ->where('car_status_id', 5)
            ->where('user.is_aprovado', '<>', 0)
            ->orderBy('car.is_edited', 'DESC')
            ->select('car.*')->get();
        $moderar = [];
        foreach ($carros_moderar as $car) {
            $carUtil = new CarUtil($car);
            $moderar[] = $carUtil->getCarObject();
        }

        $carros_denuncia = $this->car->join('user', 'car.user_id', '=', 'user.id')
            ->join('car_incidents', 'car_incidents.car_id', '=', 'car.id')
            ->where('car_incidents.status', 1)
            ->groupBy('car.id')
            ->orderBy('car_incidents.created_at', 'ASC')
            ->select('car.*')
            ->get();

        $denuncia = [];
        foreach ($carros_denuncia as $car) {
            $carUtil = new CarUtil($car);
            $denuncia[] = $carUtil->getCarObject();
        }

        return view('admin::moderar.lista')->with('moderar', $moderar)->with('denuncia', $denuncia);
    }


    public function denuncia(Request $request)
    {
        $denuncia = CarIncident::findOrFail($request->get('id'));

        $denuncia->status = 0;
        $denuncia->save();

        return ['success' => true, 'msg' => 'Denúncia dispensada com sucesso'];

    }

    public function decisao(Request $request)
    {
        // Pegar a ação
        $action = $request->get('action');
        $id = $request->get('id');
        $reason = $request->get('reason');
        $car = Car::findOrFail($id);
        $car_name = $car->brand->name . ' ' . $car->fipe->model;
        $usuario = User::findOrFail($car->user_id);
        $device_token = $usuario->device_token;
        switch ($action) {
            case 'suspender':
                $car_status = 6;
                $push_title = "Anúncio {$car_name} suspenso devido a denúncias";
                $push_text = 'Seu anúncio foi suspenso e deve ser editado para poder receber novas negociações';
                $user_text = 'Analisamos sua denúncia e o anúncio foi suspenso, o mesmo só voltará ao aplicativo após ser corrigido pelo usuário e avaliado por nossa equipe, bons negócios';
                $url_denunciado = 'http://www.aplicativorepasse.com.br/blog/seu-anuncio-foi-suspenso/';
                $url_denunciante = 'http://www.aplicativorepasse.com.br/blog/denuncia-foi-aprovada-e-o-anuncio-suspenso/';
                break;
            case 'bloquear':
                $car_status = 7;
                $push_title = "Anúncio {$car_name} bloqueado devido a denúncias";
                $push_text = 'Seu anúncio foi bloqueado por infringir as regras do aplicativo, cadastre corretamente e evite o bloqueio da sua conta.';
                $user_text = 'Analisamos sua denúncia e o anúncio foi bloqueado. O anunciante foi orientado a não fazer mais esse tipo de anúncio';
                $url_denunciado = 'http://www.aplicativorepasse.com.br/blog/seu-anuncio-foi-bloqueado/';
                $url_denunciante = 'http://www.aplicativorepasse.com.br/blog/denuncia-foi-aprovada-e-o-anuncio-bloqueado/';
                break;
            default:
                $car_status = $car->car_status_id;
                $url_denunciado = '';
                $url_denunciante = '';
                $user_text = '';
        }

        // Marcar com o status correspondente (suspenso/bloqueado)

        $car->car_status_id = $car_status;
        $car->reason = $reason;
        $car->save();

        // Marca todas as denúncias como lidas
        $denuncias = CarIncident::where('car_id', $id)->where('status', 1)->get();
        $denunciantes = [];
        foreach ($denuncias as $d) {
            $denunciantes[] = $d->user_id;
            $d->status = 0;
            $d->save();
        }

        // Bloqueio no chat
        $host = config('chat.host');
        $port = config('chat.port');
        $token = config('chat.token');
        $message = [
            'sender_id' => $car->user_id,
            'receiver_id' => null,
            'car_id' => $car->id,
            'car_status_id' => $car_status
        ];
        $agent = new Agent($host, $port, $token);
        $agent->sendMessage($message);

        $parameters = [
            'include_player_ids' => [],
            'headings' => [
                'en' => $push_title
            ],
            'contents' => [
                'en' => $push_text
            ],
            'android_group' => 3,
            'android_group_message' => [
                'en' => '$[notif_count] denúncias'
            ],
            'small_icon' => 'repasse_small_icon_white',
            'large_icon' => 'repasse_icon',
            'url' => $url_denunciado

        ];
        // Push para o vendedor
        if ($device_token != null && isUuid($device_token)) {
            $parameters['include_player_ids'][] = $device_token;
            if (!empty($parameters['include_player_ids'])) {
                Log::info('Player ids not empty Mandando push para o usuario anunciante');
                $jobVendedor = (new PushNotificationJob($parameters))->onQueue('push');
                $this->dispatch($jobVendedor);
                //$push->sendCustom($parameters);
            } else {
                Log::info('include_player_ids vazio na rotina de envio para anunciante',
                    $parameters['include_player_ids']);
            }
        }
        // Push para todos que tem denúncia em aberto
        $usersDenuncia = User::whereIn('id', $denunciantes)->get();

        $parameters['include_player_ids'] = [];
        foreach ($usersDenuncia as $userDenuncia) {
            if ($userDenuncia->device_token != null && isUuid($userDenuncia->device_token)) {
                $parameters['include_player_ids'][] = $userDenuncia->device_token;
            }
        }
        $parameters['contents']['en'] = $user_text;
        $parameters['url'] = $url_denunciante;
        if (!empty($parameters['include_player_ids'])) {
            Log::info('Player ids not empty Mandando push para os usuario que fizeram denuncia');
            $jobDenunciante = (new PushNotificationJob($parameters))->onQueue('push');
            $this->dispatch($jobDenunciante);
            //$push->sendCustom($parameters);
        } else {
            Log::info('include_player_ids vazio na rotina de envio para denunciantes',
                $parameters['include_player_ids']);
        }

        $podioStatusJob = (new CarStatusPodioJob($car, $car_status))->onQueue('push');
        $this->dispatch($podioStatusJob);


        // Retorna
        return ['success' => true, 'msg' => 'Decisão finalizada com sucesso'];

    }

}