<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 22/12/2016
 * Time: 13:27
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarEdit;
use App\Admin\Dashboard\Models\CarIncident;
use App\Admin\Dashboard\Models\CarSell;
use App\Admin\Dashboard\Models\CarTurbo;
use App\Admin\Dashboard\Models\Moderation\ModerationResponse;
use App\Admin\Dashboard\Models\UserLead;
use App\Auth\Models\User;
use App\Auth\Models\UserType;
use App\Core\Http\Controllers\CoreController;
use App\Repasse\Audit\Edits;
use App\Repasse\CarUtil;
use Carbon\Carbon;
use Illuminate\Pagination\LengthAwarePaginator;
use Illuminate\Pagination\Paginator;
use DB;
use Illuminate\Support\Facades\Input;

class ReportController extends CoreController
{
    public function reportEstoque($user_id = null)
    {

        $user = [];
        $itemsPerPage = 10;
        $anuncios = Car::orderBy('published_at', 'DESC');
        if (isset($user_id)) {
            $user = User::findOrFail($user_id);
            $anuncios = $anuncios->where('user_id', $user_id);
        }

        return view('admin::reports.estoque')->with('anuncios',
            $anuncios->paginate($itemsPerPage))->with('collapse', 'relatorios')->with('user', $user);

    }


    public function reportAnuncio($id = null)
    {
        $car = Car::findOrFail($id);
        $carUtil = new CarUtil($car);
        $anuncio = $carUtil->getCarObject();
        //$negotiations = $carUtil->getNegotiations();


        $negotiations = $carUtil->getInteressados();
        $calls = $carUtil->getCalls();

        // ediçoes
        $edicoes = CarEdit::where('car_id', $id)->join('user', 'user.id', '=',
            'car_edits.user_id')->orderBy('car_edits.created_at', 'DESC')->select('car_edits.*', 'user.name')->get();
        $edits = [];
        foreach ($edicoes as $e) {
            $edit = new Edits($anuncio, $e);
            $e->edits = $edit->getEditArray();
            $edits[] = $e;
        }
        // denúncias
        //$denuncias = CarIncident::where('car_id', $id)->join('user', 'user.id', '=', 'car_incidents.user_id')->select('car_incidents.*', 'user.name')->get();
        $denuncias = CarIncident::where('car_id', $car->id)->get();

        $pedidos = CarTurbo::where('car_id', $car->id)->get();
        
        $moderacaoRespostas = ModerationResponse::all();

        return view('admin::reports.anuncio')
            ->with('anuncio', $anuncio)
            ->with('denuncias', $denuncias)
            ->with('edits', $edits)
            ->with('collapse', 'relatorios')
            ->with('interessados', $negotiations)
            ->with('ligacoes', $calls)
            ->with('car', $car)
            ->with('pedidos', $pedidos)
            ->with('respostasmoderacao', $moderacaoRespostas);
    }

    public function reportInstall()
    {
        $clientes = User::where('role_id', 2)->where('is_aprovado',
            1)->whereNotNull('latitude')->whereNotNull('longitude')->get();

        $states = DB::table('user')
            ->select('state', DB::raw('count(*) as total'))
            ->whereNotNull('city')->whereNotNull('state')
            ->where('role_id', 2)->where('is_aprovado', 1)
            ->groupBy('state')
            ->get();

        $dadosInstalacoes = [];

        foreach ($states as $state) {

            $instalacoes = DB::table('user')
                ->select('city', 'state', DB::raw('count(*) as total'))
                ->whereNotNull('city')->whereNotNull('state')
                ->where('role_id', 2)->where('is_aprovado', 1)->where('state', $state->state)
                ->groupBy('state')->groupBy('city')
                ->get();
            $dadosInstalacoes[$state->state]['total'] = $state->total;
            $dadosInstalacoes[$state->state]['dados'] = $instalacoes;
        }

        return view('admin::reports.install')
            ->with('instalacoes', $dadosInstalacoes)
            ->with('clientes', $clientes)
            ->with('collapse', 'relatorios');
    }


    public function reportnegotiations()
    {

        $negotiations = CarSell::where('reason_id', 1)->orderBy('created_at', 'desc')->paginate(3);

        return view('admin::reports.reportnegotiations')->with('negotiations', $negotiations)->with('collapse',
            'relatorios');

    }


    public function reportRatings()
    {
        $average = DB::table('user_rating')
            ->select(DB::raw('AVG(rating) as average, count(id) as total'))
            ->first();

        $user = DB::table('user')
            ->join('user_rating', 'user_rating.user_id', '=', 'user.id')
            ->join('user_type', 'user_type.id', '=', 'user.user_type')
            ->orderBy('user_rating.created_at', 'DESC');
        $ratings = $user
            ->where('is_aprovado', 1)
            ->select('user.dealership', 'user.photo', 'user_type.name as type', 'user_rating.*')->paginate(5);

        return view('admin::reports.avaliacoes')
            ->with('collapse', 'relatorios')
            ->with('ratings', $ratings)
            ->with('average', $average->average)
            ->with('total', $average->total);

    }


    public function reportads()
    {
        $ads = Car::where('car_status_id', '<>', 4)->orderBy('published_at', 'desc')->paginate(5);
        return view('admin::reports.reportads')->with('ads', $ads)->with('collapse', 'relatorios');

    }


    public function reportdealerships()
    {

        $order = 'DESC';

        $params = Input::all();

        if (!empty($params['order'])) {
            $order = $params['order'];
        }

        $dealerships = User::where('is_aprovado', '1')->where('role_id', '2')->orderBy('created_at',
            $order)->paginate(10);

        return view('admin::dashboard.reportdealerships')->with('dealerships', $dealerships)->with('order',
            $order)->with('collapse', 'relatorios');

    }


    public function reportLeads()
    {

        $leads = UserLead::orderBy('created_at', 'DESC')->paginate(10);

        return view('admin::reports.leads', ['leads' => $leads, 'collapse' => 'relatorios']);

    }

}