@extends('admin.master')
@section('content')
    <section id="dashboard-content">
        <div class="panel panel-default" id="form-usuario">
            <div class="panel-heading">
                @if(session()->has('message'))
                    <div class="alert alert-success">
                        {{session()->get('message')}}
                    </div>
                @endif
                @if(session()->has('errors'))
                    <div class="alert alert-danger">
                        <ul>
                            @foreach ($errors->all() as $error)
                                <li>{{ $error }}</li>
                            @endforeach
                        </ul>
                    </div>
                @endif
                <h3 class="card-title" style="padding-left: 15px;">Loja</h3>
            </div>
            <div class="row">
                <div class="col-xs-12">
                    <div class="panel-body">
                        <div class="card">
                            <div class="card-block">
                                <div class="row">
                                    <div class="col-xs-6">
                                        <h4>Dados da Loja</h4>
                                        <ul class="list-unstyled">
                                            <li><span>Id:</span> {{$store->id}}</li>
                                            <li><span>Proprietário:</span> {{($store->owner->name) ?? 'Sem dono' }}</li>
                                            <li><span>Nome:</span> {{$store->company_name}}</li>
                                            <li><span>Nome Fantasia:</span> {{$store->trade_name}}</li>
                                            <li><span>Documento (CPF/CNPJ):</span> {{$store->cnpj}}</li>
                                            <li><span>Endereço:</span> {{$store->street}}, {{$store->number}} {{$store->neighborhood}} - {{$store->city->name or ''}} {{$store->city->state->initials or ''}} {{$store->complement}} {{$store->landmark}} {{$store->zipcode}}</li>
                                            <li><span>Cadastro:</span> {{$store->created_at->format('d/m/Y H:i:s')}}</li>
                                            @if ( !($store->cnpj === '33333333333333' || $store->cnpj === '44444444444444'))
                                            <li>
                                                <span>Possui site:</span> {{ ($store->site) ? 'Sim' : 'Não'  }}
                                                <button type="button"
                                                        id="btn-site"
                                                        data-store="{{$store->id}}"
                                                        title="Ativar/Desativar site do cliente"
                                                        class="btn btn-xs btn-default">
                                                    <i class="fa {{ $store->site ? 'fa-toggle-on' : 'fa-toggle-off'}}"></i>
                                                </button>
                                            </li>
                                            @if($store->site)
                                                <li>
                                                    <span>Token:</span> {{$store->store_token}}
                                                    <button type="button"
                                                            id="btn-refresh"
                                                            title="Regerar token do site"
                                                            data-store="{{$store->id}}"
                                                            class="btn btn-xs btn-default">
                                                        <i class="fa fa-refresh"></i>
                                                    </button>
                                                </li>
                                                <li>
                                                    <span>Site:</span> {{$store->site_url}}
                                                    <button type="button"
                                                            id="btn-url"
                                                            data-store="{{$store->id}}"
                                                            class="btn btn-xs btn-default">
                                                        <i class="fa fa-pencil"></i>
                                                    </button>
                                                </li>
                                            @endif
                                                <div x-data="dropdown">
                                                <li>
                                                    <span>Repasse Express:</span>

                                                    <button type="button"
                                                            class="btn btn-xs btn-default"
                                                            >
                                                        <i class="fa " x-bind:class="entrega ? 'fa-toggle-on' : 'fa-toggle-off' " x-on:click="changeEntrega"></i>
                                                    </button>
                                                    <i class="fa fa-spin fa-spinner" x-show="loading"></i>

                                                </li>
                                                </div>
                                        </ul>
                                        @endif

                                    </div>
                                    <div class="col-xs-6">
                                        <h4>Usuários da Loja</h4>
                                        <ul>
                                            @if(!empty($store->staff) && !($store->cnpj === '33333333333333' || $store->cnpj === '44444444444444') )
                                                @foreach($store->staff as $staff)
                                                    <li><a href="{{route('admin.user.edit', $staff->id)}}">{{ $staff->id }}:
                                                            {{ $staff->name }}</a> ({{($staff->pivot->status === 1) ? 'Ativo' : 'Inativo' }})
                                                        @if($staff->roles)
                                                            <ul>
                                                                @foreach($staff->roles as $staff)
                                                                    <li>{{$staff->display_name}}</li>
                                                                @endforeach
                                                            </ul>
                                                        @endif
                                                    </li>
                                                @endforeach
                                            @endif
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection
@section('scripts')
    <script>
        $(document).ready(function() {
            var btnrefresh = $("#btn-refresh");
            btnrefresh.click(function() {
                if (confirm('Deseja regerar o token de acesso desta loja?')) {
                    btnrefresh.attr('disabled', 'disabled');
                    var data = {
                        "_token": '{{csrf_token()}}',
                        store_id: btnrefresh.data('store'),
                    };
                    $.ajax({
                        url: '{{ route('admin.ajax.store.generatetoken') }}',
                        method: 'POST',
                        dataType: 'json',
                        data: data,
                        error: function() {
                            alert('ocorreu um erro.');
                        }
                    }).done(function() {
                        alert('Token gerado com sucesso');
                        window.location.reload();
                    });
                }
            });


            var btnsite = $("#btn-site");
            btnsite.click(function() {
                if (confirm('Deseja alterar o acesso ao site desta loja?')) {
                    btnsite.attr('disabled', 'disabled');
                    var data = {
                        "_token": '{{csrf_token()}}',
                        store_id: btnsite.data('store'),
                    };
                    $.ajax({
                        url: '{{ route('admin.ajax.store.changesite') }}',
                        method: 'POST',
                        dataType: 'json',
                        data: data,
                        error: function() {
                            alert('ocorreu um erro.');
                        }
                    }).done(function() {
                        alert('Alterado com sucesso');
                        window.location.reload();
                    });
                }
            });

            var btnurl = $("#btn-url");
            btnurl.click(function() {
                var url =  prompt('Informe o site do cliente', 'http://');

                if (url === null || url === '') {
                    // cancelado
                    return true;
                } else {
                    var data = {
                        "_token": '{{csrf_token()}}',
                        store_id: btnurl.data('store'),
                        url: url
                    };

                    $.ajax({
                        url: '{{ route('admin.ajax.store.setsiteurl') }}',
                        method: 'POST',
                        dataType: 'json',
                        data: data,
                        error: function() {
                            alert('ocorreu um erro.');
                        }
                    }).done(function() {
                        alert('Alterado com sucesso');
                        window.location.reload();
                    });
                }
            });
        });

        document.addEventListener('alpine:init', () => {
            Alpine.data('dropdown', () => ({
                entrega: {{$store->has_delivery}},
                loading: false,
                async changeEntrega() {
                    this.loading = true;
                    fetch('{{route('admin.ajax.store.changedelivery', ['store_id' => $store->id])}}').then(res => res.json()).then(res => {
                        this.loading = false;
                        console.log(res);
                        this.entrega = res.store.has_delivery;
                    });
                }
            }));
        });

    </script>
@endsection