<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 21/08/2017
 * Time: 14:48
 */

namespace App\Api\Http\Controllers;


use App\Admin\Dashboard\Models\Loan;
use App\Admin\Dashboard\Models\LoanRate;
use App\Core\Http\Controllers\CoreController;
use App\Repasse\Loan\Tps;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;
use Log;

class ApiQuoteController extends CoreController
{
    protected $request;
    protected $user;

    public function __construct(Request $request, Auth $auth)
    {
        $this->request = $request;
        $this->user = $auth::user();
    }

    public function simulate()
    {
        $response = new Response();
        // verifica se tem valor do veículo (400 se não tiver)
        if (!$this->request->has('veiculo')) {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Falta um parâmetro obrigatório']);
            return $response;
        }

        $veiculo = $this->request->get('veiculo');
        // verifica se tem entrada (se não tem atribuir 0)
        $entrada = $this->request->get('entrada', 0);

        if ($entrada > $veiculo) {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Entrada não pode ser maior que valor do veículo']);
            return $response;
        }

        // diminui a entrada do valor do veículo
        $valorBem = $veiculo - $entrada;
        $tps = new Tps($valorBem);
        $valorTps = $tps->getTps();

        $valor = $valorBem + $valorTps;
        // Puxa todas as linhas da tabela de coeficiente e pra cada uma delas faz a conta (entrada - veiculo) * coeficiente
        $anuncio = $this->request->get('anuncio');
        $produto = ($anuncio['ad']['produto'] === 'Financiamento') ? 1 : 2;
        $rates = LoanRate::where('produto', '=', $produto)->get();
        $quotes = [];
        foreach ($rates as $rate) {
            $quotes[] = [
                'parcela' => $rate->parcela,
                'prestacao' => $valor * $rate->coeficiente,
                'coeficiente' => $rate->coeficiente,
                'tps' => $valorTps
            ];
        }

        $response->setStatusCode(200);
        $response->setContent(
            [
                'success' => true,
                'data' => [
                    'valor' => $valorBem,
                    'quotes' => $quotes
                ]
            ]
        );

        // retorna os quotes encapsulado em data
        return $response;
    }

    public function apply()
    {
        // Colocar o ddd colado no telefone pra ficar melhor
        $telefoneEmpresa = '(48)99147-3020';

        // verificar se tem
        $anuncio = $this->request->input('anuncio');
        $anuncio_id = (int)$anuncio['id'];
        Log::info('Anuncio:' . (int)$anuncio['id'] );

        // Não deixar a mesma proposta entrar duas vezes
        $pesquisaLoans = Loan::where('user_id', '=', $this->user->id)->where('car_id', '=',  $anuncio['id']);

        if ($pesquisaLoans->first()) {
            // retornar um status OK
            Log::info('Usuário já tem proposta para este anúncio, descartando');
            return ['success' => true, 'msg' => 'Sua proposta já foi encaminhada, não é permitido enviar mais de uma proposta para o mesmo veículo Dúvidas, através do Whatsapp', 'telefone' => $telefoneEmpresa];
        }

        $veiculo = $this->request->input('veiculo');
        $entrada = $this->request->input('entrada', 0);
        $valorBem = $veiculo - $entrada;
        $tps = new Tps($valorBem);

        $solicitante = $this->request->input('solicitante');
        $proposta = [
            'veiculo' => $veiculo,
            'entrada' => $entrada,
            'parcela' => $this->request->input('parcela'),
            'coeficiente' => $this->request->input('coeficiente'),
            'prestacao' => $this->request->input('prestacao'),
            'tps' => $tps->getTps(),
            'telefone_confirmado' => $this->request->input('cell_phone'),
            'email_confirmado' => $this->request->input('email')
        ];




        $loanRequest = Loan::create([
            'user_id' => $this->user->id,
            'car_id' => $anuncio_id,
            'solicitante' => json_encode($solicitante),
            'anuncio' => json_encode($anuncio),
            'proposta' => json_encode($proposta),
            'status' => 1
        ]);


        return ['success' => true, 'msg' => 'Sua solicitação foi enviada. Em breve entraremos em contato para concluir seu cadastro. Dúvidas, através do WhatsApp' , 'telefone' => $telefoneEmpresa];
    }

}