<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 09/01/2017
 * Time: 11:54
 */

namespace App\Api\Http\Controllers;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\StateDdd;
use App\Core\Http\Controllers\CoreController;
use App\Repasse\CarUtil;
use App\Repasse\Search\SearchPopulate;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use DB;

class ApiSearchController extends CoreController
{
    protected $request;
    protected $user;

    public function __construct(Request $request, Auth $auth)
    {

        $this->request = $request;
        $this->user = $auth::user();

    }


    public function search(): array
    {

        $tipo_usuario = $this->user->user_type;

        // Pesquisa avançada
        $data = Carbon::now();

        $search = Car::join('fipe', 'fipe.id', '=', 'car.fipe_id')
            ->join('user', 'user.id', '=', 'car.user_id')
            ->join('brand', 'brand.id', '=', 'car.brand_id')
            ->join('car_publish', function ($join) use ($tipo_usuario) {
                $join->on('car.id', '=', 'car_publish.car_id')
                    ->on('car_publish.user_type', '=', DB::raw($tipo_usuario));
            })
            ->where('car.site_only', false)
            ->whereIn('car_status_id', [1, 9])
            ->where('user.is_aprovado', 1);

        // Tarefa#597
        // se stock_id for enviado ignorar todos os dados (menos a ordem) e trazer os veículos de um usuário

        $stock_id = $this->request->get('stock_id');

        if ($stock_id) {

            $search = $search->where('car.user_id', $stock_id);

        } else {

            //  Tipo (carro moto caminhão)
            $car_type = $this->request->get('car_type');
            if ($car_type !== null) {
                $search = $search->where('car.car_type', $car_type);
            }
            // Marca
            $brand_id = $this->request->get('brand_id');
            if ($brand_id !== null) {
                $search = $search->where('car.brand_id', $brand_id);
            }
            // Modelo
            $modelo_id = $this->request->get('model_id');
            if ($modelo_id !== null) {
                $search = $search->where('fipe.modelo_id', $modelo_id);
            }
            // Ano inicial Ano Final
            $start_year = ($this->request->get('start_year') == null) ? 1984 : $this->request->get('start_year');
            $end_year = ($this->request->get('end_year') == null) ? 'Zero' : $this->request->get('end_year');

            if ($start_year && $end_year) {
                $search = $search->whereBetween('fipe.year', [$start_year, $end_year]);
            }

            // Combustível
            $fuel = $this->request->get('fuel');

            if (!empty($fuel)) {
                $search = $search->whereIn('fipe.fuel', $fuel);
            }
            // Valor Inicial / Final
            $start_price = ($this->request->get('start_price') == null) ? 0 : $this->request->get('start_price');
            $end_price = ($this->request->get('end_price') == null) ? 2000000 : $this->request->get('end_price');

            if ($start_price !== null && $end_price !== null) {
                $search = $search->whereBetween('car.price', [$start_price, $end_price]);
            }

            // Portas (aceita um array)
            $doors = $this->request->get('doors');
            if (!empty($doors)) {
                $search = $search->whereIn('car.doors', $doors);
            }

            // Eixos (aceitar array)
            $eixos = $this->request->get('eixos');
            if (!empty($eixos)) {
                $search = $search->whereIn('car.eixos', $eixos);
            }

            // Cor (aceita um array)
            $color_ids = $this->request->get('color_ids');
            if (!empty($color_ids)) {
                $search = $search->whereIn('car.color_id', $color_ids);
            }

            // km  inicial / final
            $start_km = ($this->request->get('start_km') == null) ? 0 : $this->request->get('start_km');
            $end_km = ($this->request->get('end_km') == null) ? SearchPopulate::MAX_KM : $this->request->get('end_km');

            if ($start_km !== null && $end_km !== null) {
                $search = $search->whereBetween('car.km', [$start_km, $end_km]);
            }

            // Opcionais (aceita um array)
            $opcionais = $this->request->get('optionals_id');
            if (!empty($opcionais)) {
                $search = $search->join('car_optional', 'car_optional.car_id', '=',
                    'car.id')->whereIn('car_optional.optional_id', $opcionais);
                $search = $search->havingRaw('count(car_optional.car_id) = ' . count($opcionais));
            }

            // Estados e DDDs
            $state_id = $this->request->get('state_id');
            $ddds = $this->request->get('ddds');
            if ($state_id !== null && !empty($ddds)) {
                $search = $search->whereIn('car.user_ddd', $ddds);
            }

            if ($state_id !== null && empty($ddds)) {
                $ddds = StateDdd::where('state_id', $state_id)->get(['ddd']);
                $search = $search->whereIn('car.user_ddd', $ddds);
            }
            /*

            if ($ddds) {
                $search = $search->whereIn('car.user_ddd', $ddds);
            }
            */

            // Anúncios por tipo de usuário
            $user_type = $this->request->get('user_type');
            if (!empty($user_type)) {
                $search = $search->whereIn('user.user_type', $user_type);
            }
        }

        // Ordem dos anúncios
        $order = $this->request->get('order_by');
        $direction = $this->request->get('direction');


        if ($order) {
            switch ($order) {
                case 'price' :
                    $search = $search->orderBy('car.price', $direction);
                    break;
                case 'year':
                    $search = $search->orderBy('fipe.year', $direction);
                    break;
                case 'km':
                    $search = $search->orderBy('car.km', $direction);
                    break;
                default:
                    $search = $search->orderBy('car.published_at');
            }
        } else {
            $search = $search->orderBy('car.published_at', 'DESC');
        }

        // paginação
        $page = $this->request->get('page', 1);
        $max = 15;
        //$qtsearch = clone($search);
        $quantidade = $search->groupBy('car.id')->selectRaw('count(car.id) as qtd')->get();
        $total = \count($quantidade);

        // die(var_dump($quantidade));
        $search = $search->limit($max)->offset(($page - 1) * $max)->groupBy('car.id');

        $searchResults = $search->select('car.*')->distinct()->get();
        //passar pelo get car object e retornar
        $results = [];
        foreach ($searchResults as $car) {
            unset($car->cost);
            $car_util = new CarUtil($car);
            $results[] = $car_util->getCarObject($this->user->id);
        }
        return [
            'success' => true,
            'total' => $total,
            'order_by' => SearchPopulate::getAvailableSorting(),
            'data' => $results
        ];

    }

    public function startPopulate(): array
    {
        // todos os tipos Enviar todas as marcas todos os modelos  uma lista de aos

        // Tipos de veículos:
        $car_types = SearchPopulate::getCarTypes();
        // Marcas
        $brands = SearchPopulate::getBrands();
        //Modelos
        $modelos = SearchPopulate::getModels();
        // Lista de anos)
        $years = SearchPopulate::getYears();
        // Combustíveis
        $fuel = SearchPopulate::getFuel();
        // Opcionais
        $optional = SearchPopulate::getOptionals();
        // Portas e Eixos
        $doors = SearchPopulate::getDoors();
        $eixos = SearchPopulate::getEixos();
        // Cores
        $colors = SearchPopulate::getColors();
        // Regiões (estados)
        $states = SearchPopulate::getStates();
        // DDD
        $ddds = SearchPopulate::getDDD();
        // Tipos de usuário
        $user_types = SearchPopulate::getUserTypes();
        // Range de preço
        $price_range = SearchPopulate::getPriceRange(0, 2000000, 5000);
        // Range de KM
        $km_range = SearchPopulate::getKmRange(50000, SearchPopulate::MAX_KM, 50000);
        // Ordens
        $orders = SearchPopulate::getAvailableSorting();

        return array(
            'success' => true,
            'data' => array(
                'car_types' => $car_types,
                'brands' => $brands,
                'models' => $modelos,
                'optionals' => $optional,
                'doors' => $doors,
                'eixos' => $eixos,
                'fuel' => $fuel,
                'years' => $years,
                'colors' => $colors,
                'states' => $states,
                'ddds' => $ddds,
                'user_types' => $user_types,
                'price' => $price_range,
                'km' => $km_range,
                'order_by' => $orders,
            )
        );

    }

    public function populateByCarType($car_type): array
    {
        $brands = SearchPopulate::getBrands($car_type);
        $modelos = SearchPopulate::getModels(null, $car_type);
        $optional = SearchPopulate::getOptionals($car_type);
        return array(
            'success' => true,
            'data' => array(
                'brands' => $brands,
                'models' => $modelos,
                'optional' => $optional
            )
        );

    }

    public function populateModels($brand_id): array
    {
        $models = SearchPopulate::getModels($brand_id, null);
        return [
            'success' => true,
            'data' => [
                'models' => $models
            ]
        ];
    }

    public function populateDdd($state_id): array
    {
        $ddds = SearchPopulate::getDDD($state_id);

        return [
            'success' => true,
            'data' => [
                'ddds' => $ddds
            ]
        ];
    }

}