<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 29/04/2019
 * Time: 15:10
 */

namespace App\Api\Http\Controllers\Bid;



use App\Admin\Dashboard\Models\Room;
use App\Chat\Room\RoomFactory;
use App\Core\Http\Controllers\CoreController;
use App\Http\Requests\Bid\BidRequest;
use App\Traits\Rest\ResponseHelpers;
use Illuminate\Support\Facades\Log;

class BidController extends CoreController
{

    use ResponseHelpers;

    /**
     * @SWG\Post(path="/bid",
     *   tags={"Bid"},
     *   summary="Enviar lance para um anúncio",
     *   description="",
     *   operationId="createBid",
     *   produces={"application/json"},
     *   @SWG\Parameter( in="query", name="per_page", description="Default: 20", required=false, type="integer" ),
     *   @SWG\Parameter( in="header", name="Authorization", description="Basic Auth", required=true, type="string" ),
     *   @SWG\Parameter( in="formData", name="car_id", description="ID do Veículo", required=true, type="integer" ),
     *   @SWG\Parameter( in="formData", name="buyer_id", description="ID do interessado", required=true, type="integer" ),
     *   @SWG\Parameter( in="formData", name="bid", description="Proposta (lance) do interessado", required=true, type="number" ),
     *   @SWG\Response( response=200, description="",
     *       @SWG\Schema(
     *           @SWG\Property(property="success", type="boolean"),
     *           @SWG\Property( property="data", type="array",
     *               @SWG\Items( type="object",
     *                   @SWG\Property(property="totals", type="integer"),
     *                   @SWG\Property(property="per_page", type="integer"),
     *                   @SWG\Property(property="current_page", type="integer"),
     *                   @SWG\Property(property="items", type="array", @SWG\Items(
     *                       type="object", ref="#/definitions/Room"
     *                   ))
     *               )
     *           ),
     *       )
     *   ),
     *   @SWG\Response( response=400, description="",
     *       @SWG\Schema(
     *           @SWG\Property( property="error", type="string", description="Bad Request" )
     *       )
     *   ),
     *   @SWG\Response( response=401, description="", @SWG\Schema(
     *            @SWG\Property( property="error", type="string", description="Error message" )
     *        )
     *    ),
     *   @SWG\Response( response=422, description="", @SWG\Schema(
     *            @SWG\Property( property="message", type="string", description="Validation failed" ),
     *            @SWG\Property( property="errors", type="array",
     *                @SWG\Items( type="object",
     *                    @SWG\Property(property="field", type="string"),
     *                )
     *            ),
     *        )
     *    )
     * )
     */
    public function create(BidRequest $request)
    {

        try {
            $user = auth()->user();
            $buyer_id = $request->get('buyer_id');
            $car_id  = $request->get('car_id');
            $bid     = $request->get('bid');

            //

            $room = RoomFactory::create($car_id, $buyer_id, $bid);
            $room_id = $room->getRoomId();

//            $room = Room::find($room_id);


            // Verificar se o carro é do anúncio?
  /*          if ($room->car_id !== $car_id) {
                return $this->badRequest(['success'=>false,'msg'=>trans( 'messages.error.forbidden' ), 'errors'=>[]] , 401 );
            }

            // Verificar se a sala é do usuário (comprador_id)

            if ($room->comprador_id !== $user->id) {
                // Usuário não é o dono do chat / não autorizado
                return $this->badRequest(['success'=>false,'msg'=>trans( 'messages.error.forbidden' ), 'errors'=>[]] , 401 );
            }

            // Atualizar dado
            $room->bid = $bid;
            $room->save();*/

            return ['success' => true, 'data' => ['room' => $room_id]];
        // @codeCoverageIgnoreStart
        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['success'=>false, 'msg'=>trans( 'messages.error.unavailable' ), 'errors'=>[]] , 500 );
            // @codeCoverageIgnoreEnd
        }

    }



    /**
     * @SWG\Get(path="/bid/{room_id}",
     *   tags={"Bid"},
     *   summary="visualizar proposta (lance) dada no anúncio",
     *   description="",
     *   operationId="getBid",
     *   produces={"application/json"},
     *    @SWG\Parameter( in="header", name="Authorization", description="Basic Auth", required=true, type="string" ),
     *    @SWG\Parameter( in="path", name="car_id", description="ID Anúncio", required=true, type="integer" ),
     *    @SWG\Parameter( in="path", name="buyer_id", description="ID do interessado", required=true, type="integer" ),
     *   @SWG\Response( response=200, description="",
     *       @SWG\Schema(
     *           @SWG\Property( property="success", type="boolean"),
     *           @SWG\Property( property="data", type="array",
     *               @SWG\Items( type="object",
     *                   @SWG\Property(property="success", type="boolean"),
     *                   @SWG\Property(property="data", type="object", @SWG\Property(property="room", type="array", @SWG\Items(
     *                       type="object", ref="#/definitions/Room")
     *                   ))
     *               )
     *           ),
     *       )
     *   ),
     *   @SWG\Response( response=400, description="",
     *       @SWG\Schema(
     *           @SWG\Property( property="error", type="string", description="Bad Request" )
     *       )
     *   )
     * )
     */
    public function getBid($car_id, $buyer_id)
    {
        //
        $room = Room::where('car_id', $car_id)->where('comprador_id', $buyer_id)->first();

        return ['success' => true, 'data' => ['room' => $room]];
    }

}