<?php

namespace App\Api\Http\Controllers\CarQuery;

use App\Admin\Dashboard\Models\CarQuery\HistoricCarQuery;
use App\Http\Requests\CarQuery\CarQueryRequest;
use App\Repasse\Products\Voucher\ConsumeVoucher;
use DB;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Storage;
use PDF;
use GuzzleHttp\Client;
use App\Auth\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Pagination\Paginator;
use App\Traits\Rest\ResponseHelpers;
use App\Admin\Dashboard\Models\Product;
use App\Admin\Dashboard\Models\Order\Order;
use App\Transformers\Order\OrderTransformer;
use App\Http\Requests\Checkout\CheckoutRequest;
use App\Admin\Dashboard\Models\CarQuery\CarQuery;
use App\Transformers\CarQuery\CarQueryTransformer;
use App\Admin\Dashboard\Models\OrderItem\OrderItem;
use App\Core\Http\Controllers\CoreController as CoreController;

class CarQueryController extends CoreController
{
	use ResponseHelpers;

    /**
    * @SWG\Get(path="/order/{id}/car-query",
    *   tags={"CarQuery"},
    *   summary="View a CarQuery",
    *   description="",
    *   operationId="viewCarQuery",
    *   produces={"application/json"},
    *   @SWG\Parameter( in="header", name="Authorization", description="Basic Auth", required=true, type="string" ),
    *   @SWG\Parameter( in="path", name="id", description="ID do pedido", required=true, type="string", @SWG\Schema(ref="#/definitions/Order") ),
    *   @SWG\Response( response=200, description="", @SWG\Schema(ref="#/definitions/CarQuery") ),
    *   @SWG\Response( response=400, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="error", type="string", description="Bad Request" )
    *       )
    *   ),
    *   @SWG\Response( response=404, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="message", type="string", description="Model not found " ),
    *       )
    *   ),
    * )
    */
	public function show( $order_id )
	{
		try {
			$user = auth()->user();

			if ( !$order = Order::where( 'id', $order_id )->first() ) {
                return $this->modelNotFound( ['success'=>false,'msg'=>trans( 'messages.error.notfound' ), 'errors'=>[]] );
            }

            if ( $order->user_id != $user->id ) {
            	return $this->badRequest( ['success'=>false,'msg'=>trans( 'messages.error.forbidden' ), 'errors'=>[]] , 401 );
            }

            if ( $order->status != 1 ) {
        		return $this->badRequest( ['success'=>false,'msg'=>trans( 'messages.error.payment.pending' ), 'errors'=>[]] , 402 );
            }

    		if ( !$car_query = CarQuery::where( 'order_id', $order_id )->first() ) {

                $client = new Client();

                $item_order = json_decode( $order->items[0]->options );

                $response = $client->get( 'https://sistemasx.com.br/ws/cmcpj/v1/consultaSuperLaudoV.php?chave=c9e076eba5b5b84ffacaf1497074c87c&valor=' . $item_order->license_plate .'&campo=placa' );
                $response = json_decode( $response->getBody()->getContents() );

                if ( $response->codigo == 101 ) {
                    return $this->badRequest( ['success'=>false,'msg'=>$response->mensagem, 'errors'=>[]] , 400 );
                }

                $car_query = CarQuery::create([
                	'order_id' => $order->id,
                	'response' => json_encode( $response ),
                	'license_plate' => $item_order->license_plate
                ]);

                // Historic car query
                $historic_car_query = HistoricCarQuery::create([
                    'car_query_id' => $car_query->id,
                    'user_id'      => $user->id
                ]);
            }

            return ( new CarQueryTransformer )->transform( $car_query );
		} catch ( \Exception $e ) {
            \Sentry::captureException($e);
			Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
         	return $this->badRequest( ['success'=>false,'msg'=>trans( 'messages.error.unavailable' ), 'errors'=>[]] , 500 );
		}
	}

    public function generatePDF( $car_query_id )
    {
        try {
            if ( !$car_query = CarQuery::find( $car_query_id ) ) {
                return $this->modelNotFound( ['success'=>false,'msg'=>trans( 'messages.error.notfound' ), 'errors'=>[]] );
            }

            if ( auth()->user()->id != $car_query->order->user_id ) {
                return $this->badRequest( ['success'=>false,'msg'=>trans( 'messages.error.forbidden' ), 'errors'=>[]] , 401 );
            }

            $response = json_decode( $car_query->response );

            $pdf = PDF::loadView( 'pdf/consulta-veicular', ['data'=>$car_query] );

            $pdf->output();
            $dom_pdf = $pdf->getDomPDF();

            $canvas = $dom_pdf ->get_canvas();
            $canvas->page_text( 500, 800, "Página {PAGE_NUM} de {PAGE_COUNT}", null, 8, array(0.5, 0.5, 0.5));

            $message = "Consulta feita em: " . $car_query->created_at->format( 'd/m/Y' ) . ' às ' . $car_query->created_at->format( 'H:i:s' );

            $canvas->page_text( 58, 800, $message, null, 8, array(0.5, 0.5, 0.5));
            $canvas->page_text( 58, 810, 'Código da consulta: ' . $response->codigo_consulta, null, 8, array(0.5, 0.5, 0.5));

            return $pdf->download( 'consulta-veicular.pdf' );

        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['success'=>false,'msg'=>trans( 'messages.error.unavailable' ), 'errors'=>[]] , 500 );
        }
    }


    /**
     * @SWG\Post(path="/products/consume/car-query",
     *    tags={"CarQuery"}, summary="Consume CarQuery, without checkout", description="", operationId="consumeCarQuery", produces={"application/json"},
     *    @SWG\Parameter( in="header", name="Authorization", description="Basic Auth", required=true, type="string" ),
     *    @SWG\Parameter( name="product_id", in="formData", description="", required=true, type="integer" ),
     *    @SWG\Parameter( name="license_plate", in="formData",  description="Max: 7", required=true, type="string" ),
     *    @SWG\Response( response=201, description="", @SWG\Schema( ref="#/definitions/City" ) ),
     *    @SWG\Response( response=400, description="", @SWG\Schema( @SWG\Property( property="error", type="string", description="Bad Request") ) ),
     *    @SWG\Response( response=401, description="", @SWG\Schema(
     *            @SWG\Property( property="error", type="string", description="Error message" )
     *        )
     *    ),
     *    @SWG\Response( response=404, description="", @SWG\Schema(
     *            @SWG\Property( property="message", type="string", description="Model not found " ),
     *        )
     *    ),
     *    @SWG\Response( response=422, description="", @SWG\Schema(
     *            @SWG\Property( property="message", type="string", description="Validation failed" ),
     *            @SWG\Property( property="errors", type="array",
     *                @SWG\Items( type="object",
     *                    @SWG\Property(property="field", type="string"),
     *                )
     *            ),
     *        )
     *    ),
     * )
     * @param CarQueryRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function consumeCarQuery(CarQueryRequest $request)
    {
        // Rota protegida, Request validado, registrar consumo, registrar voucher e emitir a consulta (esse endpoint subsitui o checkout e salva a consulta no banco)

        try {
            $fields  = $request->all();
            $user    = auth()->user();
            $product = Product::find( $fields['product_id'] );

            DB::beginTransaction();

            $order = Order::create([
                'user_id'  => $user->id,
                'total'    => ( $product->price / 100 ),
                'subtotal' => ( $product->price / 100 ),
                'status'     => 1
            ]);

            OrderItem::create([
                'order_id'   => $order->id,
                'product_id' => $product->id,
                'price'      => ( $product->price / 100 ),
                'qty'        => 1,
                'options'    => json_encode( ['license_plate'=>$fields['license_plate']] )
            ]);

            // Voucher
            if ($request->has('voucher')) {
                ConsumeVoucher::doConsume($request->get('voucher'), $user->id, $order->car_id);
            }

            $client = new Client();

            $item_order = json_decode( $order->items[0]->options );

            $response = $client->get( 'https://sistemasx.com.br/ws/cmcpj/v1/consultaSuperLaudoV.php?chave=c9e076eba5b5b84ffacaf1497074c87c&valor=' . $item_order->license_plate .'&campo=placa' );
            $response = json_decode( $response->getBody()->getContents() );

            if ( $response->codigo == 101 ) {
                return $this->badRequest( ['success'=>false,'msg'=>$response->mensagem, 'errors'=>[]] , 400 );
            }

            $car_query = CarQuery::create([
                'order_id' => $order->id,
                'response' => json_encode( $response ),
                'license_plate' => $item_order->license_plate
            ]);

            // Historic car query
            $historic_car_query = HistoricCarQuery::create([
                'car_query_id' => $car_query->id,
                'user_id'      => $user->id
            ]);


            DB::commit();


            return (new CarQueryTransformer)->transform($car_query);
            //return $this->ApiResponse( ['success'=>true, 'msg'=>trans( 'messages.success.checkout.finished' )], 201 );

        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['success'=>false,'msg'=>trans( 'messages.error.unavailable' ), 'errors'=>[]] , 500 );
        }
    }

    /**
     * @return array
     */
    public function getOrdersCarQuery()
    {
        $user = auth()->user();
        // A lista de consulta veicular por usuário logado com situação do pagamento.
        $carQueries = CarQuery::where('user_id', $user->id)->orderBy('created_at', 'DESC')->get();
        $data = [];

        $url_base = url('/');
        foreach($carQueries as $carQuery) {
            //
            $car = 'Aguardando resultado';
            $pdf = null;
            if ($carQuery->response !== null) {
                $resp = json_decode($carQuery->response);
                if (isset($resp->VEICULAR->AGREGADOS->REGISTROS[0]->MARCA_MODELO)) {
                    $car = $resp->VEICULAR->AGREGADOS->REGISTROS[0]->MARCA_MODELO;
                }

                if (isset($resp->VEICULAR->BIN_NACIONAL->MARCA_MODELO)) {
                    $car = $resp->VEICULAR->BIN_NACIONAL->MARCA_MODELO;
                }

            }

            if ($carQuery->local_pdf !== null) {
                $pdf = $url_base . '/api/car-query/' . $carQuery->local_pdf;
            }

            $data[] = [
                'id' => $carQuery->id,
                'order_id' => $carQuery->order_id,
                'order_status' => $carQuery->order->situation,
                'license_plate' => $carQuery->license_plate,
                'car' => $car,
                'response' => $carQuery->response,
                'pdf' => $pdf,
                'created_at' => $carQuery->created_at->format('d/m/Y')
            ];
        }

        return [
            'success' => true,
            'data' => $data
        ];
    }

    public function carQueryPdf($filename)
    {
        //
        try {
            $file = Storage::disk('carqueries')->get($filename);
        } catch (\Illuminate\Contracts\Filesystem\FileNotFoundException $fl) {
            $response = new Response();
            $response->setStatusCode(404);
            $response->setContent(['success' => false, 'msg' => 'Arquivo não encontrado']);
            return $response;
        }
        $x = storage_path('carqueries') . '/' . $filename;

        return response()->download($x);

    }
}
