<?php

namespace App\Api\Http\Controllers\Role;

use DB;
use App\Admin\Role\Models\Role;
use Illuminate\Support\Facades\Log;
use App\Traits\Rest\ResponseHelpers;
use App\Http\Requests\Role\UpdatePermissionsRequest;
use App\Core\Http\Controllers\CoreController as CoreController;

class RoleController extends CoreController
{
	use ResponseHelpers;

     /**
    * @SWG\Put(path="/role/{id}/permissions",
    *   tags={"Role"},
    *   summary="Update permissions of the Role",
    *   description="",
    *   operationId="updatePermissions",
    *   produces={"application/json"},
    *   @SWG\Parameter( in="header", name="Authorization", description="Bearer + {token}", required=true, type="string" ),
    *   @SWG\Parameter( in="path", name="id", description="", required=true, type="integer" ),
    *   @SWG\Parameter( in="formData", name="permissions", description="Format: ARRAY", required=false, type="string" ),
    *   @SWG\Response( response=200, description="", @SWG\Schema( ref="#/definitions/Role" ) ),
    *   @SWG\Response( response=404, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="message", type="string", description="Model not found " ),
    *       )
    *   ),
    * )
    */
    public function AddOrUpdatePermissions( UpdatePermissionsRequest $request, $id )
    {
        try {
            if ( !$role = Role::find( $id ) ) {
                return $this->modelNotFound( ['message'=>__( 'messages.error.notfound' )] );
            }

            $permissions = $request->input( 'permissions' );
            $role->perms()->sync( $permissions );

            return $this->ApiResponse( ['success'=>true, 'msg'=>trans( 'messages.success.updated' )] );
        } catch ( \Moip\Exceptions\UnexpectedException $e ) {
		    DB::rollBack();
        	Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
         	return $this->badRequest( ['success'=>false, 'msg'=>trans( 'messages.error.unavailable' )] , 500 );
		}
    }
}
