<?php

/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| Here is where you can register all of the routes for an application.
| It's a breeze. Simply tell Laravel the URIs it should respond to
| and give it the controller to call when that URI is requested.
|
*/
// Rotas para deletar antes de commitar (testes)
// Route::get('cep/{cep}', ['uses' => 'ApiCepController@getCepPretend']);
//Categories

// Rotas sem autenticação

// Login e cadastro
Route::get( 'check-exist-field', ['uses' => 'ApiUserController@checkExistField']);
Route::post('register', ['middleware' => ['dbtransaction'], 'uses' => 'ApiUserController@registerUser']);
Route::post('user-image', ['uses' => 'ApiUserController@userUploadImage']);

//Moderador app
Route::post('admin-login', ['uses' => 'ApiUserController@adminLogin']);

// Check de versão
Route::get('version', ['uses' => 'ApiController@checkVersion']);

// Tipo de usuário
Route::get('/user/types', ['uses' => 'ApiUserController@getUserTypes']);

// Imagens do chat
Route::get('get-chat-image/{filename}', ['uses' => 'ApiController@chatImage']);
Route::get('get-chat-audio/{filename}', ['uses' => 'ApiController@chatAudio']);
Route::get('/car-query/{filename}', ['uses' => 'CarQuery\CarQueryController@carQueryPdf']);

// Recuperar senha
Route::post('recupera-senha', ['uses' => 'ApiController@passwordReset']);

// Cidade, Estado e DDD
Route::get('states', ['uses' => 'CityStateDDDController@getStates']);
Route::get('cities/{stateId?}', ['uses' => 'CityStateDDDController@getCities'])->where('stateId', '[0-9]+');
Route::get('ddd/{stateId?}',  ['uses' => 'CityStateDDDController@getDDD'])->where('stateId', '[0-9]+');

//light purchase
Route::group(['prefix' => 'open'], function() {
    Route::post('ofertas', ['uses' => 'ApiOpenController@ofertas']);
});

// Webhooks
Route::group(['prefix' => 'webhooks'], function () {
    Route::post('payments', ['uses' => 'ApiProductsController@handleWebhooks']);
    Route::post('carqueries', ['uses' => 'ApiProductsController@handleCarQueryWebhooks']);
});

// Contato do site
Route::post('contact', ['uses' => 'ApiOpenController@formContatoLead']);

// Listagem de planos
Route::get('plans', ['uses' => 'Plan\PlanController@index']);

// Rota para sites
Route::group(['middleware' => 'auth.site.check', 'prefix' => 'store_site/{store_id}'], function() {

    // Search populate
    Route::group(['prefix' => 'populate'], static function() {
        // Start - Lista para popular todos os dados independentemente do tipo + anos cores e Combustível
        Route::get('/', ['uses' => 'ApiSearchController@startPopulate']);
        // carrega marcas, modelos, opcionais informando um tipo de carro
        Route::get('/type/{car_type}', ['uses' => 'ApiSiteController@populateByCarType'])->where('car_type', '[0-9]+');
        // carrega modelos informando uma marca
        Route::get('/models/{brand_id}', ['uses' => 'ApiSiteController@populateModels'])->where('brand_id', '[0-9]+');
        // Carrega fipes informando um modelo + ano
        Route::get('/model/{model_id}/{year}', ['middleware' => 'auth.store.token', 'uses' => 'ApiSiteController@populateFipe']);

    });

    // Email gateway
    Route::post('/contact', ['uses' => 'ApiSiteController@sendContact']);

    // Formulários Genéricos
    Route::post('/form', ['uses' => 'ApiSiteController@sendForm']);

    // Listagem de anúncios
    Route::get('/cars', ['uses' => 'ApiSiteController@getCars']);
    // Interna do anúncio
    Route::get('/car/{car_id}', ['uses' => 'ApiSiteController@getCar'])->where('car_id', '[0-9]+');

    Route::group(['middleware' => 'auth.store.token', 'prefix' => 'car'], function() {
        Route::post('/', ['uses' => 'ApiSiteController@saveCar']);
        Route::group(['prefix' => '{car_id}'], function() {
            Route::put('/', ['uses' => 'ApiSiteController@updateCar']);
            Route::post('/remove', ['uses' => 'ApiSiteController@removeCar']);
            Route::post('/publish', ['uses' => 'ApiSiteController@publishCar']);
            Route::group(['prefix' => 'image'], function() {
                Route::post('/', ['uses' => 'ApiSiteController@saveCarImage']);
                Route::delete('/{image_id}', ['uses' => 'ApiSiteController@removeCarImage']);
            });

        });

    });

});



// Rotas autenticadas
Route::group(['middleware' => ['auth.basic.once', 'auth.check.status'] ], function () {

    Route::post('checkout', ['uses' => 'Checkout\CheckoutController@checkout']);

    Route::get('orders', ['uses' => 'Order\OrderController@getAllByUserOrders']);
    Route::get('order/{id}', ['uses' => 'Order\OrderController@viewOrder'])->where('id', '[0-9]+');

    Route::put('order', ['uses' => 'Order\OrderController@updateStatus']);

    Route::get('order/{order_id}/car-query', ['uses' => 'CarQuery\CarQueryController@show'])->where('order_id', '[0-9]+');
    Route::get('car-queries', ['uses' => 'CarQuery\CarQueryController@index']);
    Route::get('car-query/{id}', ['uses' => 'CarQuery\CarQueryController@generatePDF'])->where('id', '[0-9]+');

    // Permissions
    Route::put('role/{id}/permissions', ['uses' => 'Role\RoleController@AddOrUpdatePermissions'])->where('order_id', '[0-9]+');

    // Plans
    Route::post('plan', ['uses' => 'Plan\PlanController@create']);

    Route::get('plan/{id}', ['uses' => 'Plan\PlanController@show'])->where('order_id', '[0-9]+');
    Route::put('plan/{id}', ['uses' => 'Plan\PlanController@update'])->where('order_id', '[0-9]+');
    Route::delete('plan/{id}', ['uses' => 'Plan\PlanController@delete'])->where('order_id', '[0-9]+');

    // Store
    Route::post('store/{id}/staff', ['middleware' => ['role:admin|chief|manager', 'dbtransaction'], 'uses' => 'Store\StoreController@createStaff'])->where('id', '[0-9]+');
    Route::get('store/{id}/staff', ['middleware' => ['role:admin|chief|manager|salesman'], 'uses' => 'Store\StoreController@getAllStaff'])->where('id', '[0-9]+');
    Route::get('store/{store_id}/staff/{staff_id}', ['uses' => 'Store\StoreController@viewStaff'])->where('store_id', '[0-9]+');
    Route::put('store/{store_id}/staff/{staff_id}', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@updateStaff'])->where('store_id', '[0-9]+');
    Route::delete('store/{store_id}/staff/{staff_id}', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@removeStaff'])->where('store_id', '[0-9]+');
    Route::put('store/{store_id}/staff/{staff_id}/invite', ['middleware' => ['role:admin|chief', 'dbtransaction'], 'uses' => 'Store\StoreController@inviteStaff'])->where('store_id', '[0-9]+');
    Route::put('store/{store_id}/accept/invite', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@acceptInvite'])->where('store_id', '[0-9]+');
    Route::put('store/{store_id}/reject/invite', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@rejectInvite'])->where('store_id', '[0-9]+');
    Route::put('store/{store_id}/cancel/invite/staff/{staff_id}', ['middleware' => ['role:admin|chief', 'dbtransaction'], 'uses' => 'Store\StoreController@cancelInvite'])->where('store_id', '[0-9]+');
    Route::get('store/staff/invites', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@getAllInvites']);
    Route::put('store/{id}/migrate/cars', ['middleware' => ['dbtransaction'], 'uses' => 'ApiController@migrateCars'])->where('id', '[0-9]+');
    Route::get('store/{store_id}/cars', ['middleware' => ['role:admin|chief|manager|salesman', 'dbtransaction'], 'uses' => 'Store\StoreController@getCarsByStore'])->where('store_id', '[0-9]+');

    // Chats
    Route::get('store/{store_id}/car/{car_id}/chats', ['uses' => 'ApiController@getAllChats'])->where(['store_id' => '[0-9]+', 'car_id' => '[0-9]+']);
    Route::get('car/{car_id}/chat/{chat_id}', ['uses' => 'ApiController@viewChat'])->where(['car_id' => '[0-9]+', 'chat_id' => '[0-9]+']);

    // Bids
    Route::group(['prefix' => 'bid'], static function() {
        Route::post('/', ['uses' => 'Bid\\BidController@create']);
        Route::get('/{car_id}/{buyer_id}', ['uses' => 'Bid\\BidController@getBid'])->where('car_id', '[0-9]+')->where('buyer_id', '[0-9]+');
    });

    // Favorites
    Route::get('my-favorites', ['uses' => 'ApiFavoriteController@index']);


    Route::get('report/overview', ['uses' => 'Report\ReportController@index']);
    Route::get('report/scoreboard', ['middleware'=>['role:chief|admin'], 'uses' => 'Report\ReportController@scoreboard']);
    Route::get('report/billing/{user_id?}', ['middleware'=>['role:chief|admin'], 'uses' => 'Report\ReportController@getBilling']);

	Route::post('update-token', ['uses' => 'ApiUserController@updateToken']);

	Route::get('populate-announce/{type?}', ['uses' => 'ApiController@populateAnnounce'])->where('type', '[0-9]+');
	Route::get('populate-model/{brand_id?}/{year?}', ['uses' => 'ApiController@populateModel']);
    Route::get('populate-year/{type}/{brand_id}', ['uses' => 'ApiController@populateYear']);
    Route::get('populate-edit/{car_type}/{year?}', ['uses' => 'ApiController@populateEdit'])->where('car_type', '[0-9]+');
    Route::get('populate-reason', ['uses' => 'ApiController@populateReason']);
    Route::get('populate-vehicle/{fipe_id}', ['uses' => 'ApiController@populateFipe'])->where('fipe_id', '[0-9]+');

    /*
     * Listagem de carros (meus anúncios e comprar)
     */
	Route::get('my-ads/{user_id?}/{page?}', ['uses' => 'ApiController@myAds', 'as' => 'api.my-ads' ]);
	Route::post('purchase', ['uses' => 'ApiController@purchase']);

	// Cadastrar anúncio
	Route::post('car', ['uses' => 'ApiController@saveCar']);
	Route::post('car-image/{car_id?}', ['uses' => 'ApiController@saveCarImage'])->where('car_id', '[0-9]+');
    Route::post('car-publish', ['uses' => 'ApiController@publishCar']);

    // Editar anúncio Apagar foto do anúncio
    Route::post('car-edit', ['uses' => 'ApiController@updateCar']);
    Route::get('car-photo-remove/{id?}', ['uses' => 'ApiController@removeCarPhoto'])->where('id', '[0-9]+');

    // Excluir / marcar carro como vendido
	Route::post('car-sold', ['uses' => 'ApiController@carSold']);

	// Marcar carro como negociando (não se usa atualmente)
	Route::get('car-negociando/{id?}', ['uses' => 'ApiController@carNegociando']);

	// Excluir carro
	Route::post('car-remove', ['uses' => 'ApiController@removeCar']);

	// Excluir da tela comprar (ignorar anúncio)
	Route::post('car-ignore', ['uses' => 'ApiController@ignoreCar']);



	// Grupo de rotas para o usuário autenticado
    Route::group(['prefix' => 'user'], function() {
        // Get (dados do usuário
        Route::get('/{user_id?}', ['uses' => 'ApiUserController@getUser'])->where('user_id','[0-9]+');
        // Usuário teve um minuto para ouvir falar dos novos termos de uso?
        Route::get('/terms', ['uses' => 'ApiUserController@getTermsStatus']);
        Route::post('/terms/accept', ['uses' => 'ApiUserController@setTermsStatus']);

        Route::put('/trial', ['uses' => 'ApiUserController@setTrialStatus']);


        // Post
        // Atualizar usuário (dados, imagem, login e senha, tipo)
        Route::post('/update', ['uses' => 'ApiUserController@updateUser']);
        Route::post('/image/update', ['uses' => 'ApiUserController@updateAvatar']);
        Route::post('/credentials/update', ['uses' => 'ApiUserController@updateCredentials' ])->where('user_id','[0-9]+');
        Route::post('/type/update', ['uses' => 'ApiUserController@setUserType']);

        Route::get('/search', ['uses' => 'ApiUserController@search']);
        Route::get('/{user_id}/cars', ['uses' => 'ApiUserController@getCarsByUser'])->where('user_id', '[0-9]+');

    });

    // Grupo de rotas relacionadas a tela de pesquisa
    Route::group(['prefix' => 'search'], function() {
        // Pesquisa própriamente dita
        Route::post('/', ['uses' => 'ApiSearchController@search']);

        // Listagens para popular tela de pesquisa
        Route::group(['prefix' => 'populate'], function() {
            // Start - Lista para popular todos os dados independentemente do tipo + anos cores e Combustível
            Route::get('/', ['uses' => 'ApiSearchController@startPopulate']);
            // carrega marcas, modelos, opcionais informando um tipo de carro
            Route::get('/type/{car_type}', ['uses' => 'ApiSearchController@populateByCarType'])->where('car_type', '[0-9]+');
            // carrega modelos informando uma marca
            Route::get('/models/{brand_id}', ['uses' => 'ApiSearchController@populateModels'])->where('brand_id', '[0-9]+');
            // carrega ddds informando estado
            Route::get('/ddds/{state_id}', ['uses' => 'ApiSearchController@populateDdd'])->where('state_id', '[0-9]+');
        });

    });

    // Controle de favoritos
    Route::group(['prefix' => 'favorites'], function() {
        // Listar favoritos
        Route::post('/', ['uses' => 'ApiFavoriteController@listFavorites']);
        // Adicionar remover do favoritos
        Route::get('/{car_id}/change', ['uses' => 'ApiFavoriteController@setFavorite'])->where('car_id', '[0-9]+');
    });

    Route::get('info-chat/{car_id?}/{client_id?}', ['uses' => 'ApiController@infoChat'])->where(['car_id' => '[0-9]+','client_id' => '[0-9]+']);

	Route::post('chat-image', ['uses' => 'ApiController@chatUploadImage']);
	Route::post('chat-audio', ['uses' => 'ApiController@chatUploadAudio']);


	Route::get('car-negotiations/{car_id}', ['uses' => 'ApiController@carNegotiations'])->where('car_id', '[0-9]+');
	Route::get('negotiations/{car_id?}', ['uses' => 'ApiController@negotiations'])->where('car_id', '[0-9]+');

	Route::post('call', ['uses' => 'ApiController@registerUserCall']);

	// Denúncia
	Route::post('denounce', ['uses' => 'ApiController@denounce']);

	//Perfis de compra e anúncio silenciado
    Route::group(['prefix' => 'profile'], function() {
        //Post Routes
        Route::post('/save', ['uses' => 'ProfileController@saveProfile']);
        Route::post('/{profile_id}/update', ['uses' => 'ProfileController@updateProfile'])->where('profile_id', '[0-9]+');
        Route::post('/remove', ['uses' => 'ProfileController@removeProfile']);

        //Get Routes
        Route::get('/states', ['uses' => 'ProfileController@getProfileStates']);
        Route::get('/list', ['uses' => 'ProfileController@listProfile']);
        Route::get('/{profile_id?}', ['uses' => 'ProfileController@getProfile'])->where('profile_id', '[0-9]+');

        //Muted Routes
        Route::group(['prefix' => 'muted'], function() {
            Route::post('/update', ['uses' => 'ProfileController@muteProfile']);
            Route::delete('/remove', ['uses' => 'ProfileController@removeMuted']);
            Route::get('/until', ['uses' => 'ProfileController@mutedUntil']);
            Route::get('/list', ['uses' => 'ProfileController@mutedList']);
        });
    });

    // Avaliar aplicativo
    Route::group(['prefix' => 'ratings'], function() {
        Route::get('/status', ['uses' => 'ApiRatingsController@getStatus']);
        Route::post('/save', ['uses' => 'ApiRatingsController@store']);

    });

    // Simulador
    Route::group(['prefix' => 'quote'], function() {
        Route::post('/simulate', ['uses' => 'ApiQuoteController@simulate']);
        Route::post('/apply', ['uses' => 'ApiQuoteController@apply']);
    });


    // Produtos
    Route::group(['prefix' => 'products'], function() {

        // Consumíveis
        Route::group(['prefix' => 'consume', 'middleware' => ['role:chief|manager|salesman']], function() {
            // Turbo
            Route::post('/turbo', ['uses' => 'ApiProductsController@consumeTurbo']);
            // Consulta Veicular
            Route::post('/car-query', ['uses' => 'CarQuery\CarQueryController@consumeCarQuery']);


        });

        Route::post('/order/new', ['uses' => 'ApiProductsController@createOrder']);
        Route::get('/order/turbo/{order_id}', ['uses' => 'ApiProductsController@getTurboOrder']);
        Route::get('/order/{order_id}', ['uses' => 'ApiProductsController@getOrder'])->where('order_id', '[0-9]+');
        Route::get('/quote/{product_id}', ['uses' => 'ApiProductsController@getQuoteByType']);
        Route::get('/orders/car/{car_id}', ['uses' => 'ApiProductsController@getOrdersByCar'])->where('car_id', '[0-9]+');
        Route::get('/orders/car-query', ['uses' => 'CarQuery\CarQueryController@getOrdersCarQuery']);

        Route::get('/reach/{car_id}', ['uses' => 'ApiProductsController@getAdReach'])->where('car_id', '[0-9]+');

        // Avisos (ads)
        Route::get('/avisos', ['uses' => 'ApiAvisoController@getAvisos']);


    });

    // Leads
    Route::group(['prefix' => 'leads'], function() {
        Route::post('/new', ['uses' => 'ApiLeadsController@createLead']);
    });

});


Route::group(['prefix' => 'v2'], function () {

    Route::post('login', ['uses' => 'ApiUserController@authenticate']);

    Route::get('plans', ['uses' => 'Plan\PlanController@index']);

    // Refresh Token
    Route::post('refresh', ['uses' => 'ApiUserController@refresh']);

    Route::get('cep/{cep}', ['uses' => 'ApiCepController@getCep']);

    // Rotas autenticadas com JWT
    Route::group( ['middleware' => ['jwt.auth', 'auth.check.status']], function () {


        Route::post('checkout', ['uses' => 'Checkout\CheckoutController@checkout']);

        Route::get('orders', ['uses' => 'Order\OrderController@getAllByUserOrders']);
        Route::get('order/{id}', ['uses' => 'Order\OrderController@viewOrder'])->where('id', '[0-9]+');

        Route::put('order', ['uses' => 'Order\OrderController@updateStatus']);

        Route::get('order/{order_id}/car-query', ['uses' => 'CarQuery\CarQueryController@show'])->where('order_id', '[0-9]+');
        Route::get('car-queries', ['uses' => 'CarQuery\CarQueryController@index']);
        Route::get('car-query/{id}', ['uses' => 'CarQuery\CarQueryController@generatePDF'])->where('id', '[0-9]+');

        Route::post('update-token', ['uses' => 'ApiUserController@updateToken']);

        Route::get('populate-announce/{type?}', ['uses' => 'ApiController@populateAnnounce'])->where('type', '[0-9]+');
        Route::get('populate-model/{brand_id?}/{year?}', ['uses' => 'ApiController@populateModel']);
        Route::get('populate-year/{type}/{brand_id}', ['uses' => 'ApiController@populateYear']);
        Route::get('populate-edit/{car_type}/{year}', ['uses' => 'ApiController@populateEdit'])->where('car_type', '[0-9]+');
        Route::get('populate-reason', ['uses' => 'ApiController@populateReason']);
        Route::get('populate-vehicle/{fipe_id}', ['uses' => 'ApiController@populateFipe'])->where('fipe_id', '[0-9]+');

         // Permissions
        Route::put('role/{id}/permissions', ['uses' => 'Role\RoleController@AddOrUpdatePermissions'])->where('order_id', '[0-9]+');

        // Plans
        Route::post('plan', ['middleware' => ['role:admin', 'dbtransaction'], 'uses' => 'Plan\PlanController@create']);
        Route::get('plan/{id}', ['middleware' => ['role:admin'], 'uses' => 'Plan\PlanController@show'])->where('order_id', '[0-9]+');
        Route::put('plan/{id}', ['middleware' => ['role:admin', 'dbtransaction'], 'uses' => 'Plan\PlanController@update'])->where('order_id', '[0-9]+');
        Route::delete('plan/{id}', ['middleware' => ['role:admin', 'dbtransaction'], 'uses' => 'Plan\PlanController@delete'])->where('order_id', '[0-9]+');

        // Store
        Route::post('store/{id}/staff', ['middleware' => ['role:admin|chief|manager', 'dbtransaction'], 'uses' => 'Store\StoreController@createStaff'])->where('id', '[0-9]+');
        Route::get('store/{id}/staff', ['middleware' => ['role:admin|chief|manager|salesman'], 'uses' => 'Store\StoreController@getAllStaff'])->where('id', '[0-9]+');
        Route::get('store/{store_id}/staff/{staff_id}', ['uses' => 'Store\StoreController@viewStaff'])->where('store_id', '[0-9]+');
        Route::put('store/{store_id}/staff/{staff_id}', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@updateStaff'])->where('store_id', '[0-9]+');
        Route::delete('store/{store_id}/staff/{staff_id}', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@removeStaff'])->where('store_id', '[0-9]+');
        Route::put('store/{store_id}/staff/{staff_id}/invite', ['middleware' => ['role:admin|chief','dbtransaction'], 'uses' => 'Store\StoreController@inviteStaff'])->where('store_id', '[0-9]+');
        Route::put('store/{store_id}/accept/invite', ['as' => 'store.invite.accept', 'middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@acceptInvite'])->where('store_id', '[0-9]+');
        Route::put('store/{store_id}/reject/invite', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@rejectInvite'])->where('store_id', '[0-9]+');
        Route::put('store/{store_id}/cancel/invite/staff/{staff_id}', ['middleware' => ['role:admin|chief', 'dbtransaction'], 'uses' => 'Store\StoreController@cancelInvite'])->where('store_id', '[0-9]+');
        Route::get('store/staff/invites', ['middleware' => ['dbtransaction'], 'uses' => 'Store\StoreController@getAllInvites']);
        Route::put('store/{id}/migrate/cars', ['middleware' => ['dbtransaction'], 'uses' => 'ApiController@migrateCars'])->where('id', '[0-9]+');
        Route::get('store/{store_id}/cars', ['middleware' => ['role:admin|chief|manager|salesman', 'dbtransaction'], 'uses' => 'Store\StoreController@getCarsByStore'])->where('store_id', '[0-9]+');

        // Bids
        Route::group(['prefix' => 'bid'], static function() {
            Route::post('/', ['uses' => 'Bid\\BidController@create']);
            Route::get('/{car_id}/{buyer_id}', ['uses' => 'Bid\\BidController@getBid'])->where('car_id', '[0-9]+')->where('buyer_id', '[0-9]+');
        });

        // Chats
        Route::get('store/{store_id}/car/{car_id}/chats', ['uses' => 'ApiController@getAllChats'])->where(['store_id' => '[0-9]+', 'car_id' => '[0-9]+']);
        Route::get('car/{car_id}/chat/{chat_id}', ['uses' => 'ApiController@viewChat'])->where(['car_id' => '[0-9]+', 'chat_id' => '[0-9]+']);

        // Favorites
        Route::get('my-favorites', ['uses' => 'ApiFavoriteController@index']);

        Route::get('report/overview', ['uses' => 'Report\ReportController@index']);
        Route::get('report/scoreboard', ['middleware'=>['role:chief|admin'], 'uses' => 'Report\ReportController@scoreboard']);
        Route::get('report/billing/{user_id?}', ['middleware'=>['role:chief|admin'], 'uses' => 'Report\ReportController@getBilling']);

        /*
         * Listagem de carros (meus anúncios e comprar)
         */
        Route::get('my-ads/{user_id?}/{page?}', ['uses' => 'ApiController@myAds']);
        Route::post('purchase', ['uses' => 'ApiController@purchase']);

        // Cadastrar anúncio
        Route::post('car', ['uses' => 'ApiController@saveCar']);
        Route::post('car-image/{car_id?}', ['uses' => 'ApiController@saveCarImage'])->where('car_id', '[0-9]+');
        Route::post('car-publish', ['uses' => 'ApiController@publishCar']);

        // Editar anúncio Apagar foto do anúncio
        Route::post('car-edit', ['uses' => 'ApiController@updateCar']);
        Route::get('car-photo-remove/{id?}', ['uses' => 'ApiController@removeCarPhoto'])->where('id', '[0-9]+');

        // Excluir / marcar carro como vendido
        Route::post('car-sold', ['uses' => 'ApiController@carSold']);

        // Marcar carro como negociando (não se usa atualmente)
        Route::get('car-negociando/{id?}', ['uses' => 'ApiController@carNegociando']);

        // Excluir carro
        Route::post('car-remove', ['uses' => 'ApiController@removeCar']);

        // Excluir da tela comprar (ignorar anúncio)
        Route::post('car-ignore', ['uses' => 'ApiController@ignoreCar']);



        // Grupo de rotas para o usuário autenticado
        Route::group(['prefix' => 'user'], function() {
            // Get (dados do usuário
            Route::get('/{user_id?}', ['uses' => 'ApiUserController@getUser'])->where('user_id','[0-9]+');
            // Usuário teve um minuto para ouvir falar dos novos termos de uso?
            Route::get('/terms', ['uses' => 'ApiUserController@getTermsStatus']);
            Route::post('/terms/accept', ['uses' => 'ApiUserController@setTermsStatus']);

            Route::put('/trial', ['uses' => 'ApiUserController@setTrialStatus']);
            // Post
            // Atualizar usuário (dados, imagem, login e senha, tipo)
            Route::post('/update', ['uses' => 'ApiUserController@updateUser']);
            Route::post('/image/update', ['uses' => 'ApiUserController@updateAvatar']);
            Route::post('/credentials/update', ['uses' => 'ApiUserController@updateCredentials' ])->where('user_id','[0-9]+');
            Route::post('/type/update', ['uses' => 'ApiUserController@setUserType']);

            Route::get('/search', ['uses' => 'ApiUserController@search']);
            Route::get('/{user_id}/cars', ['uses' => 'ApiUserController@getCarsByUser'])->where('user_id', '[0-9]+');

        });

        // Grupo de rotas relacionadas a tela de pesquisa
        Route::group(['prefix' => 'search'], function() {
            // Pesquisa própriamente dita
            Route::post('/', ['uses' => 'ApiSearchController@search']);

            // Listagens para popular tela de pesquisa
            Route::group(['prefix' => 'populate'], function() {
                // Start - Lista para popular todos os dados independentemente do tipo + anos cores e Combustível
                Route::get('/', ['uses' => 'ApiSearchController@startPopulate']);
                // carrega marcas, modelos, opcionais informando um tipo de carro
                Route::get('/type/{car_type}', ['uses' => 'ApiSearchController@populateByCarType'])->where('car_type', '[0-9]+');
                // carrega modelos informando uma marca
                Route::get('/models/{brand_id}', ['uses' => 'ApiSearchController@populateModels'])->where('brand_id', '[0-9]+');
                // carrega ddds informando estado
                Route::get('/ddds/{state_id}', ['uses' => 'ApiSearchController@populateDdd'])->where('state_id', '[0-9]+');
            });

        });

        // Controle de favoritos
        Route::group(['prefix' => 'favorites'], function() {
            // Listar favoritos
            Route::post('/', ['uses' => 'ApiFavoriteController@listFavorites']);
            // Adicionar remover do favoritos
            Route::get('/{car_id}/change', ['uses' => 'ApiFavoriteController@setFavorite'])->where('car_id', '[0-9]+');
        });

        Route::get('info-chat/{car_id?}/{client_id?}', ['uses' => 'ApiController@infoChat'])->where(['car_id' => '[0-9]+','client_id' => '[0-9]+']);

        Route::post('chat-image', ['uses' => 'ApiController@chatUploadImage']);
        Route::post('chat-audio', ['uses' => 'ApiController@chatUploadAudio']);


        Route::get('car-negotiations/{car_id?}', ['uses' => 'ApiController@carNegotiations'])->where('car_id', '[0-9]+');
        Route::get('negotiations/{car_id?}', ['uses' => 'ApiController@negotiations'])->where('car_id', '[0-9]+');

        Route::post('call', ['uses' => 'ApiController@registerUserCall']);

        // Denúncia
        Route::post('denounce', ['uses' => 'ApiController@denounce']);

        //Perfis de compra e anúncio silenciado
        Route::group(['prefix' => 'profile'], function() {
            //Post Routes
            Route::post('/save', ['uses' => 'ProfileController@saveProfile']);
            Route::post('/{profile_id}/update', ['uses' => 'ProfileController@updateProfile'])->where('profile_id', '[0-9]+');
            Route::post('/remove', ['uses' => 'ProfileController@removeProfile']);

            //Get Routes
            Route::get('/states', ['uses' => 'ProfileController@getProfileStates']);
            Route::get('/list', ['uses' => 'ProfileController@listProfile']);
            Route::get('/{profile_id?}', ['uses' => 'ProfileController@getProfile'])->where('profile_id', '[0-9]+');

            //Muted Routes
            Route::group(['prefix' => 'muted'], function() {
                Route::post('/update', ['uses' => 'ProfileController@muteProfile']);
                Route::delete('/remove', ['uses' => 'ProfileController@removeMuted']);
                Route::get('/until', ['uses' => 'ProfileController@mutedUntil']);
                Route::get('/list', ['uses' => 'ProfileController@mutedList']);
            });
        });

        // Avaliar aplicativo
        Route::group(['prefix' => 'ratings'], function() {
            Route::get('/status', ['uses' => 'ApiRatingsController@getStatus']);
            Route::post('/save', ['uses' => 'ApiRatingsController@store']);

        });

        // Simulador
        Route::group(['prefix' => 'quote'], function() {
            Route::post('/simulate', ['uses' => 'ApiQuoteController@simulate']);
            Route::post('/apply', ['uses' => 'ApiQuoteController@apply']);
        });


        // Produtos
        Route::group(['prefix' => 'products'], function() {

            // Consumíveis
            Route::group(['prefix' => 'consume', 'middleware' => ['role:chief']], function() {
                // Turbo
                Route::post('/turbo', ['uses' => 'ApiProductsController@consumeTurbo']);
                // Consulta Veicular
                Route::post('/car-query', ['uses' => 'CarQuery\CarQueryController@consumeCarQuery']);

            });

            Route::post('/order/new', ['uses' => 'ApiProductsController@createOrder']);
            Route::get('/order/turbo/{order_id}', ['uses' => 'ApiProductsController@getTurboOrder']);
            Route::get('/order/{order_id}', ['uses' => 'ApiProductsController@getOrder'])->where('order_id', '[0-9]+');
            Route::get('/quote/{product_id}', ['uses' => 'ApiProductsController@getQuoteByType']);
            Route::get('/orders/car/{car_id}', ['uses' => 'ApiProductsController@getOrdersByCar'])->where('car_id', '[0-9]+');
            Route::get('/orders/car-query', ['uses' => 'CarQuery\CarQueryController@getOrdersCarQuery']);

            Route::get('/reach/{car_id}', ['uses' => 'ApiProductsController@getAdReach'])->where('car_id', '[0-9]+');

        });

        // Leads
        Route::group(['prefix' => 'leads'], function() {
            Route::post('/new', ['uses' => 'ApiLeadsController@createLead']);
            Route::post('/express', ['uses' => 'ApiLeadsController@createExpressLead']);
        });

        Route::group(['prefix' => 'conversas'], function() {
            Route::get('/', ['uses' => 'ApiConversasController@list']);
            Route::post('/', ['uses' => 'ApiConversasController@create']);
        });
    });
});