<?php

namespace App\Auth\Models;

use App\Admin\Dashboard\Models\Ads\UserAd;
use App\Admin\Dashboard\Models\Call;
use App\Admin\Dashboard\Models\Room;
use App\Repasse\TimeParser;
use Illuminate\Auth\Authenticatable;
use Illuminate\Database\Eloquent\Model;
use App\Admin\Dashboard\Models\Store\Store;
use App\Admin\Dashboard\Models\Order\Order;
use Illuminate\Auth\Passwords\CanResetPassword;
use Illuminate\Foundation\Auth\Access\Authorizable;
use Illuminate\Contracts\Auth\Authenticatable as AuthenticatableContract;
use Illuminate\Contracts\Auth\Access\Authorizable as AuthorizableContract;
use Illuminate\Contracts\Auth\CanResetPassword as CanResetPasswordContract;
use App\Auth\Models\UserType;
use App\Admin\Role\Models\Role;
use App\Admin\Dashboard\Models\Car;
use Zizaco\Entrust\Traits\EntrustUserTrait;
use App\Admin\Dashboard\Models\Transaction;
use App\Admin\Dashboard\Models\HistoricCarTurbo;
use App\Admin\Dashboard\Models\CarQuery\HistoricCarQuery;
use App\Admin\Dashboard\Models\CarFavorite;
use App\Admin\Dashboard\Models\UserAgreement;

/**
 * @SWG\Definition(type="object", @SWG\Xml(name="User"))
 */
class User extends Model implements AuthenticatableContract,
    AuthorizableContract,
    CanResetPasswordContract
{
    use Authenticatable,
        Authorizable,
        CanResetPassword,
        EntrustUserTrait // add this trait to your user model
        {
            EntrustUserTrait ::can insteadof Authorizable; //add insteadof avoid php trait conflict resolution
        }

    public $defaultPhoto = 'Avatar.png';
    protected $table = 'user';
    protected $fillable = [
        'user_type',
        'name',
        'email',
        'dealership',
        'document',
        'zipcode',
        'address',
        'number',
        'neighborhood',
        'phone',
        'cell_phone',
        'photo',
        'city',
        'state',
        'password'
    ];
    protected $dates = ['created_at', 'updated_at', 'muted_until', 'expires_at'];
    protected $hidden = ['password', 'remember_token', 'email_token', 'updated_at', 'muted_until'];

    public static function boot()
    {
        parent::boot();

        static::deleting(function ($user) {
            $user->anuncios()->delete();
            $user->calls()->delete();
            $user->agreements()->delete();
            $user->ads()->delete();
        });
    }

    public function getCreatedAtAttribute($value)
    {
        return TimeParser::format($value);
    }

    public function setPasswordAttribute($value)
    {
        $this->attributes['password'] = bcrypt($value);
    }

    public function anuncios()
    {
        return $this->hasMany(Car::class, 'user_id');
    }

    public function role()
    {
        return $this->belongsTo(Role::class, 'role_id');
    }

    public function type()
    {
        return $this->hasOne(UserType::class, 'id', 'user_type');
    }

    public function status()
    {
        return $this->hasOne(UserStatus::class, 'id', 'is_aprovado');
    }

    public function getPhotoAttribute($value)
    {
        return !empty($value) ? $value : $this->defaultPhoto;
    }

    // public function city()
    // {
    //     return $this->belongsTo('App\Auth\Models\City', 'city_id');
    // }

    public function orders()
    {
        return $this->hasMany( Order::class, 'user_id', 'id' );
    }

    public function stores()
    {
        return $this->belongsToMany( Store::class, 'store_user' )->withPivot('role_id', 'status')->withTimestamps();
    }

    public function calls()
    {
        return $this->hasMany(Call::class, 'comprador_id');
    }

    public function chats()
    {
        return $this->hasMany(Room::class, 'comprador_id');
    }

    public function myStore()
    {
        return $this->stores()->where( 'store_user.role_id', 2 )->first();
    }

    public function transactions()
    {
        return $this->hasMany( Transaction::class, 'user_id' );
    }

    public function turbos()
    {
        return $this->hasMany( HistoricCarTurbo::class, 'user_id' );
    }

    public function carQueries(){
        return $this->hasMany( HistoricCarQuery::class, 'user_id' );
    }

    public function favorites()
    {
        return $this->hasMany( CarFavorite::class, 'user_id' );
    }

    public function agreements()
    {
        return $this->hasMany(UserAgreement::class,'user_id');
    }

    public function ads()
    {
        return $this->hasMany(UserAd::class, 'user_id');
    }

    public function conversas()
    {
        return $this->hasManyThrough(
            Room::class,
            Car::class,
            'user_id',
            'car_id'
        );
    }

}
