<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 31/10/2018
 * Time: 15:48
 */

namespace App\Core\Console\Commands;


use App\Admin\Dashboard\Models\Car;
use App\Auth\Models\User;
use App\Core\Jobs\PushNotificationJob;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Foundation\Bus\DispatchesJobs;

class PushCloseAd extends Command
{

    use DispatchesJobs;

    protected $signature = 'push:closead';

    protected $description = 'Envia Push incentivando usuário a fechar seu anúncio aberto';

    protected $heading = 'Já vendeu seu veículo?';

    protected $contents = 'Se você já vendeu seu veículo acesse a tela Meus Anúncios e marque como vendido.';

    protected $data = ['car' => true];

    protected $days = 30;



    public function handle()
    {
        $date = Carbon::now()->subDays($this->days)->toDateString();

        // listar todos os anúncios que a data de abertura é a 30 dias atrás com status em aberto
        $anuncios = Car::where('car_status_id', 1)->whereRaw(" CAST( published_at AS DATE) = '{$date}' ")->distinct()->get(['user_id']);
        if (!empty($anuncios)) {
            $array_usuarios = array_pluck($anuncios->toArray(), 'user_id');
            // Esta é a lista de ids trazer os usuários poderia usar a chave estrangeira mas isso geraria uma nova query pra cada carro. Dessa forma limitamos a duas consultas
            $users = User::where('is_aprovado', 1)->where('device_token', '<>', " ''  " )->whereIn('id', $array_usuarios)->distinct()->get(['device_token']);
            if (!empty($users)) {
                $devices = array_pluck($users->toArray(), 'device_token');

                $parameters = [
                    'include_player_ids' => $devices,
                    'headings' => [
                        'en' => $this->heading
                    ],
                    'contents' => [
                        'en' => $this->contents
                    ],
                    'android_group' => 7,
                    'android_group_message' => [
                        'en' => '$[notif_count] Aviso(s)'
                    ],
                    'small_icon' => 'repasse_small_icon_white',
                    'large_icon' => 'repasse_icon',
                    'data' => $this->data
                ];

                $job = (new PushNotificationJob($parameters))->onQueue('push');
                $this->dispatch($job);

            }

        }

    }
}