<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 02/02/2021
 * Time: 14:53
 */

namespace App\Core\Console\Commands;


use App\Admin\Dashboard\Models\Order\Order;
use App\Auth\Models\User;
use App\Core\Jobs\PushNotificationJob;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Foundation\Bus\DispatchesJobs;

class PushOpenCartsCarQuery extends Command
{
    use DispatchesJobs;

    protected $signature = 'push:opencartcarquery';

    protected $description = 'Envia push notification incentivando usuários a finalizar a consulta veicular';

    protected $heading = '';

    protected $contents = '';

    protected $data = ['car' => true];

    protected $days = 1;

    public function handle()
    {
        // carrinhos de compra não finalizados em até 1 dia
        $date = Carbon::now()->subDays($this->days)->toDateString();
        \Log::debug('date: ' . $date);

        $orders = Order::whereNotIn('order_status', ['ORDER.PAID', 'ORDER.NOT_PAID'])->whereRaw(" CAST(created_at AS DATE) = '{$date}' ")->get();

        \Log::debug('orders : ' . $orders->count() );

        if ($orders) {
            foreach ($orders as $order) {

                if (!empty($order->user->device_token) && isset($order->car_query->license_plate)) {
                    $parameters = [
                        'include_player_ids' => [$order->user->device_token],
                        'headings' => [
                            'en' => " Termine sua Consulta Veicular agora mesmo."
                        ],
                        'contents' => [
                            'en' => "Saiba tudo sobre {$order->car_query->license_plate} com uma consulta veicular!"
                        ],
                        'android_group' => 7,
                        'android_group_message' => [
                            'en' => '$[notif_count] Aviso(s)'
                        ],
                        'small_icon' => 'repasse_small_icon_white',
                        'large_icon' => 'repasse_icon',
                        'data' => $this->data
                    ];

                    $job = (new PushNotificationJob($parameters))->onQueue('push');
                    $this->dispatch($job);
                }
            }

        }

    }

}