<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 21/12/2018
 * Time: 15:50
 */

namespace App\Core\Jobs;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarStatus;
use App\Repasse\Integration\Podio\Models\CarStatusFields;
use Carbon\Carbon;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Repasse\LaravelPodio\Services\PodioService;

class CarStatusPodioJob extends Job implements SelfHandling, ShouldQueue
{
    use SerializesModels, InteractsWithQueue, DispatchesJobs;

    protected $car;

    protected $action;

    public function __construct(Car $car, $action)
    {
        $this->car = $car;
        $this->action = $action;
    }

    public function handle(PodioService $podioService)
    {

        if (!$podioService->isAuthenticated()) {
            $podioService->authenticateWithPassword();
        }

        // Verificar podio_id e cadastrar antes, reenviando esta tarefa para a fila
        if (!$this->car->podio_id) {
            $appPub = $podioService->getApp('Publicações');

            $car = \PodioItem::filter($appPub['id'], [
                'limit' => 1,
                'filters' => [
                    'id-anuncio-2' => ['from' => (int)$this->car->id, 'to' => (int)$this->car->id]
                ]
            ]);

            if ($car[0]) {
                //
                $this->car->podio_id = $car[0]->item_id;
                $this->car->save();
            } else {
                //
                $carPodio = (new NewCarPodioJob($this->car))->onQueue('push');
                $this->dispatch($carPodio);
                $this->release(60);
            }
        }

        $carStatusFields = new CarStatusFields();
        $carStatusFields->setStatusField($this->car->car_status->podio_id);

        switch ($this->action) {
            case 1:
                // Nova publicação (atualiza data de publicação e status)
                // Erro da rotina de publicação, se não tiver publicado reagenda
                if ($this->car->published_at > 0) {
                    $carStatusFields->setPublishDate($this->car->published_at);
                    break;
                }
                $this->release(60);
                break;
            case 2:
                // Negociando, (não acontece)
                break;
            case 3:
                // Vendido (atualiza status, data da venda, cria carsell no podio)
                $carStatusFields->setSellDate($this->car->car_sell->created_at->toDateTimeString());
                break;
            case 4:
                // Em cadastro (não acontece, o padrão de novos anúncios)
                break;
            case 5:
                // Em análise (troca o status)
                break;
            case 6:
                // Suspenso (troca o status)
                break;
            case 7:
                // Bloqueado (troca o status)
                break;
            case 8:
                // Excluído (troca o status e atualiza a data da venda)
                // Tarefa#805 - O Anúncio não tem de fato o status correto (excluído)
                $status = CarStatus::find(8);
                $carStatusFields->setStatusField($status->podio_id);
                $carStatusFields->setSellDate(Carbon::now()->toDateTimeString());
                break;
            case 9:
                // Turbinado (troca o status)
                break;
            default:

                break;
        }

        // Envia o status + qualquer coisa que altere a publicação (data de vendido p.ex.)
        $statusFields = $carStatusFields->toPodio();
        \PodioItem::update($this->car->podio_id, $statusFields);

    }

}