<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 10/01/2019
 * Time: 11:26
 */

namespace App\Core\Jobs;


use App\Admin\Dashboard\Models\Car;
use App\Repasse\Integration\Podio\Fields\AppField;
use App\Repasse\Integration\Podio\Models\CarFields;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Repasse\LaravelPodio\Services\PodioService;

class EditCarPodioJob extends Job implements SelfHandling, ShouldQueue
{
    use SerializesModels, InteractsWithQueue, DispatchesJobs;

    protected $car;

    public function __construct(Car $car)
    {
        $this->car = $car;
    }

    public function handle(PodioService $podioService)
    {
        $appPub = $podioService->getApp('Publicações');

        if (!$podioService->isAuthenticated()) {
            $podioService->authenticateWithPassword();
        }

        if (!$this->car->podio_id) {
            $car = \PodioItem::filter($appPub['id'], [
                'limit' => 1,
                'filters' => [
                    'id-anuncio-2' => ['from' => (int)$this->car->id, 'to' => (int)$this->car->id]
                ]
            ]);

            if ($car[0]) {
                $this->car->podio_id = $car[0]->item_id;
                $this->car->save();
            } else {
                $podioJob = (new NewCarPodioJob($this->car))->onQueue('push');
                $this->dispatch($podioJob);
                $this->release(10);
            }
        }

        // Configuração deste campo não pode ser usada a mesma do banco (podio_id) por isso vamos cachear a requisição
        $user_type_field = AppField::get($appPub['id'], $appPub['user_type_field'], $podioService);
        $attributes['user_type_field'] =  ['name' => $appPub['user_type_field'], 'data' => $user_type_field ] ;


        $carFields = new CarFields($this->car, $attributes);
        $fields = $carFields->toPodio();

        $podioItem = \PodioItem::update($this->car->podio_id, $fields);

    }

}