<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 05/12/2018
 * Time: 11:59
 */

namespace App\Core\Jobs;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarStatus;
use App\Repasse\Integration\Podio\Fields\AppField;
use App\Repasse\Integration\Podio\Models\CarFields;
use Carbon\Carbon;
use Doctrine\Common\Cache\Cache;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Log;
use Repasse\LaravelPodio\Services\PodioService;

class NewCarPodioJob extends Job implements SelfHandling, ShouldQueue
{
    use InteractsWithQueue, SerializesModels, DispatchesJobs;

    /** @var Car $car */
    protected $car;

    public function __construct(Car $car)
    {
        $this->car = $car;
    }

    public function handle(PodioService $podioService)
    {

        $appPub = $podioService->getApp('Publicações');
        $appUser = $podioService->getApp('Usuários');

        // Autenticar com o app publicações,
        // $podioService->authenticateWithApp('Publicações');

        if (!$podioService->isAuthenticated()) {
            $podioService->authenticateWithPassword();
        }

        // Configuração deste campo não pode ser usada a mesma do banco (podio_id) por isso vamos cachear a requisição
        $user_type_field = AppField::get($appPub['id'], $appPub['user_type_field'], $podioService);
        $attributes['user_type_field'] =  ['name' => $appPub['user_type_field'], 'data' => $user_type_field ] ;

        $carFields = new CarFields($this->car, $attributes);
        $fields = $carFields->toPodio();

        // Usar a referência para criar o anúncio
        // Verificar se o usuário tem id do podio

        if (!$this->car->user->podio_id) {
            // Procurar no app usuários a referência númerica em id-usuario-2
            $user = \PodioItem::filter($appUser['id'], [
                'limit' => 1,
                'filters' => [
                    'id-usuario-2' => [
                        'from' => (int)$this->car->user->id,
                        'to' => (int)$this->car->user->id
                    ]
                ]
            ]);

            if ($user[0]) {
                $this->car->user->podio_id = $user[0]->item_id;
                $this->car->user->save();
                $fields['fields']['cliente'] = $this->car->user->podio_id;
            } else {

                $podioJob = (new NewUserPodioJob($this->car->user))->onQueue('push');
                $this->dispatch($podioJob);

                // Release job to queue
                $this->release(20);
            }
        }

        $podioItem = \PodioItem::create($appPub['id'], $fields);

        if ($podioItem->item_id) {
            $this->car->podio_id = $podioItem->item_id;
            $this->car->save();
        }

    }

}