<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 06/12/2018
 * Time: 15:29
 */

namespace App\Core\Jobs;


use App\Admin\Dashboard\Models\CarSell;
use App\Repasse\Integration\Podio\Models\BuyerFields;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Repasse\LaravelPodio\Services\PodioService;

class NewSellPodioJob extends Job implements SelfHandling, ShouldQueue
{
    use InteractsWithQueue, SerializesModels, DispatchesJobs;

    protected $carSell;

    public function __construct(CarSell $carSell)
    {
        $this->carSell = $carSell;
    }


    public function handle(PodioService $podioService)
    {
        $appPub = $podioService->getApp('Publicações');
        $appUser = $podioService->getApp('Usuários');
        $appCompradores = $podioService->getApp('Compradores');

        // o job só vai ser chamado se o carro for vendido pela plataforma (1)
        // vai pesquisar o carro
        // $podioService->authenticateWithApp('Compradores');
        if (!$podioService->isAuthenticated()) {
            $podioService->authenticateWithPassword();
        }

        if (!$this->carSell->car->podio_id) {

            $car = \PodioItem::filter($appPub['id'], [
                'limit' => 1,
                'filters' => [
                    'id-anuncio-2' => ['from' => (int)$this->carSell->car_id, 'to' => (int)$this->carSell->car_id]
                ]
            ]);

            if ($car[0]) {
                $this->carSell->car->podio_id = $car[0]->item_id;
                $this->carSell->car->save();
            } else {
                $podioJob = (new NewCarPodioJob($this->carSell->car))->onQueue('push');
                $this->dispatch($podioJob);
                $this->release(10);
            }

        }

        // vai chamar o userfields e atualizar os dados necessários
        $buyerFields = new BuyerFields($this->carSell);
        $fields = $buyerFields->toPodio();

        $fields['fields']['veiculo-comprado'] = $this->carSell->car->podio_id;


        // vai verificar se tem comprador
        if ((int)$this->carSell->user_buy_id !== 0) {
            // Usuário comprador não tem registro no podio
            if (!$this->carSell->user_buy->podio_id) {
                // se tem comprador, vai pesquisar o comprador
                $user = \PodioItem::filter($appUser['id'], [
                    'limit' => 1,
                    'filters' => [
                        'id-usuario-2' => [
                            'from' => (int)$this->carSell->user_buy_id,
                            'to' => (int)$this->carSell->user_buy_id
                        ]
                    ]
                ]);

                if ($user[0]) {
                    $this->carSell->user_buy->podio_id = $user[0]->item_id;
                    $this->carSell->user_buy->save();
                } else {
                    // Cadastrar usuário, release job
                    $userJob = (new NewUserPodioJob($this->carSell->user_buy))->onQueue('push');
                    $this->dispatch($userJob);
                    $this->release(10);
                }

            }

            $fields['fields']['comprador'] = $this->carSell->user_buy->podio_id;

        }

        $podioItem = \PodioItem::create($appCompradores['id'], $fields);

        if ($podioItem->item_id) {
            $this->carSell->podio_id = $podioItem->item_id;
            $this->carSell->save();
        }

    }

}