<?php

namespace App\Core\Providers;

use App\Repasse\Integration\Cep\OpenCEP\OpenCepFetch;
use App\Repasse\Integration\Cep\ViaCep\ViaCepFetch;
use Illuminate\Support\ServiceProvider;

class CepServiceProvider extends ServiceProvider
{

    public function register()
    {
        $this->app->bind('App\Repasse\Integration\Cep\CepFetchInterface', function() {
            switch (config('cep.driver')) {
                case 'opencep':
                    $class = "App\\Repasse\\Integration\\Cep\\OpenCEP\\OpenCepFetch";
                    return new $class();
                case 'viacep':
                    $class = "App\\Repasse\\Integration\\Cep\\ViaCep\\ViaCepFetch";
                    return new $class();
                case 'brasilapi':
                    $class = "App\\Repasse\\Integration\\Cep\\BrasilApi\\BrasilApiFetch";
                    return new $class();
                case 'geocoder':
                    $class = "App\\Repasse\\Integration\\Cep\\Geocoder\\GeocoderCepFetch";
                    return new $class();
                case 'local':
                    $class = "App\\Repasse\\Integration\\Cep\\Local\\LocalCepFetch";
                    return new $class();
                default:
                    throw new \Exception("Cep não configurado");
            }
        });
    }



}