<?php

namespace App\Repasse\Integration\Cep\OpenCEP;

use App\Repasse\Integration\Cep\CepFetchInterface;
use App\Repasse\Integration\Cep\DTO\FetchCepDTO;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Cache;

class OpenCepFetch implements CepFetchInterface
{
    private $client;
    const SITE_URL  = 'https://opencep.com/v1/';

    public function __construct()
    {
        $this->client = new Client(['base_uri' => self::SITE_URL]);
    }

    public function fetchCep($cep): FetchCepDTO
    {
        $cep = preg_replace("/[^0-9]/", "", $cep);

        try {
            $body = Cache::get("opencep_{$cep}", function () use ($cep) {
                $res = $this->client->request('GET', "{$cep}.json");
                return json_decode($res->getBody());
            });

            if ($body) {
                return OpenCepFetchFactory::make($body);
            }
        } catch (GuzzleException $exception) {
            throw $exception;
        }
    }
}