<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 04/12/2018
 * Time: 10:50
 */

namespace App\Repasse\Integration\Podio\Models;


use App\Auth\Models\User;
use App\Repasse\TimeParser;
use Illuminate\Support\Facades\Log;

class UserFields implements FieldsInterface
{
    protected $fields = [
        'external_id' => null,
        'fields' => [
            'nome-do-responsavel' => null,
            'data-de-cadastro' => [ 'start' => null ],
            'tipo-de-usuario' => null,
            'telefone' => [],
            'cnpj' => null,
            'id-usuario-2' => null,
            'cnpj-ou-cpf' => null,
            'email' => [
                'type' => 'work',
                'value' => null
            ],
            'cep' => null,
            'endereco' => null,
            'numero' => null,
            'bairro' => null,
            'cidade' => null,
            'estado' => null,
            'status' => null,
            'imagem' => null,
        ]
    ];

    private function getUserImage($imageName)
    {

    }


    public function __construct(User $user)
    {
        $tipo = (int)$user->type->podio_id;
        $this->fields['external_id'] = (string)$user->id;
        $this->fields['fields']['nome-do-responsavel'] = $user->name;
        $this->fields['fields']['data-de-cadastro']['start'] = TimeParser::toSqlString($user->created_at);
        $this->fields['fields']['tipo-de-usuario'] = $tipo;

        if (!empty($user->phone)) {
            $this->fields['fields']['telefone'][] = ['type' => 'work', 'value' => $user->phone];
        }

        if (!empty($user->cell_phone)) {
            $this->fields['fields']['telefone'][] = ['type' => 'mobile', 'value' => $user->cell_phone];
        }
        $this->fields['fields']['cnpj'] = $user->dealership;
        $this->fields['fields']['id-usuario-2'] = (int)$user->id;
        $this->fields['fields']['cnpj-ou-cpf'] = $user->document;
        $this->fields['fields']['email']['value'] = $user->email;

        // $this->fields['fields']['endereco'] = $user->address;

        if (!empty($user->address)) {
            $this->fields['fields']['cep'] = $user->zipcode;
            $this->fields['fields']['endereco']['value'] = "{$user->address}, {$user->number}, {$user->neighborhood}, {$user->city}, {$user->state}, {$user->zipcode}";
            $this->fields['fields']['endereco']['street_number'] = $user->number;
            $this->fields['fields']['endereco']['street_name'] = $user->address;
            $this->fields['fields']['endereco']['postal_code'] = $user->zipcode;
            $this->fields['fields']['endereco']['city'] = $user->city;
            $this->fields['fields']['endereco']['state'] = $user->state;
            $this->fields['fields']['endereco']['country'] = 'Brasil';
            $this->fields['fields']['numero'] = $user->number;
            $this->fields['fields']['bairro'] = $user->neighborhood;
            $this->fields['fields']['cidade'] = $user->city;
            $this->fields['fields']['estado'] = $user->state;
        }

        $this->fields['fields']['status'] = (int)$user->status->podio_id;
        $this->fields['fields']['monitorado-2'] = $user->is_flagged ? 1 : 2;
        // $this->fields['fields']['imagem'] = url('uploads/avatar')."/{$user->photo}";

        if (!$user->roles->isEmpty()) {
            $this->fields['fields']['subtipo'] = $user->roles()->first()->podio_id;
        }
    }


    public function toPodio() :array
    {
        if ($this->fields['external_id'] === null) {
            throw new \InvalidArgumentException('Missing data');
        }

        // Clean up data, sometimes it may be empty (particular)

        if (empty($this->fields['fields']['cnpj'])) {
            unset($this->fields['fields']['cnpj']);
        }

        if (empty($this->fields['fields']['cnpj-ou-cpf'])) {
            unset($this->fields['fields']['cnpj-ou-cpf']);
        }

        if (empty($this->fields['fields']['numero'])) {
            unset($this->fields['fields']['numero']);
        }

        if (empty($this->fields['fields']['bairro'])) {
            unset($this->fields['fields']['bairro']);
        }

        if (empty($this->fields['fields']['cep'])) {
            unset($this->fields['fields']['cep']);
        }

        if (empty($this->fields['fields']['endereco'])) {
            unset($this->fields['fields']['endereco']);
        }

        if (empty($this->fields['fields']['endereco']['value'])) {
            unset($this->fields['fields']['endereco']['value']);
        }

        if (empty($this->fields['fields']['endereco']['street_number'])) {
            unset($this->fields['fields']['endereco']['street_number']);
        }

        if (empty($this->fields['fields']['endereco']['street_name'])) {
            unset($this->fields['fields']['endereco']['street_name']);
        }

        if (empty($this->fields['fields']['endereco']['postal_code'])) {
            unset($this->fields['fields']['endereco']['postal_code']);
        }

        if (empty($this->fields['fields']['endereco']['city'])) {
            unset($this->fields['fields']['endereco']['city']);
        }

        if (empty($this->fields['fields']['endereco']['state'])) {
            unset($this->fields['fields']['endereco']['state']);
        }

        if (empty($this->fields['fields']['monitorado-2'])) {
            unset($this->fields['fields']['monitorado-2']);
        }


        Log::debug('Enviando dados ao podio: ', $this->fields );

        return $this->fields;

    }

    public function setUserStatus($podio_status_id)
    {
        $this->fields['fields']['status'] = (int)$podio_status_id;
    }


}