<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 14/10/2019
 * Time: 09:55
 */

namespace App\Repasse\Products\CarQuery;


use App\Admin\Dashboard\Models\CarQuery\CarQuery;
use App\Core\Jobs\CarQuery\FailedAdminMailJob;
use App\Core\Jobs\CarQuery\SuccessUserMailJob;
use App\Core\Jobs\PushNotificationJob;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Support\Facades\Storage;

class SuccessNotification
{
    use DispatchesJobs;

    private $carQuery;

    public function __construct(CarQuery $carQuery)
    {
        $this->carQuery = $carQuery;
    }

    public function notifySuccess()
    {
        $error = '';
        //
        // check:
        // - Has response field filled
        // - has xml field filled
        // - has pdf field filled
        // - has local_pdf field filled
        // - file (local_pdf) exists on storage

        if ($this->carQueryFieldsCheck()) {
            //
            if (Storage::disk('carqueries')->has($this->carQuery->local_pdf)) {
                // Send notifications
                if (!empty($this->carQuery->order->user->device_token)) {
                    // check for user token

                    $pushJob = (new PushNotificationJob($this->generatePushParameters()))->onQueue('push');
                    $this->dispatch($pushJob);
                }

                $emailJob = (new SuccessUserMailJob($this->carQuery))->onQueue('emails');
                $this->dispatch($emailJob);

                return true;
            } else {
                $error = 'Arquivo não existe no disco';
            }

        } else {
            $error = 'Campos não passaram na verificação, podem estar vazios.';
        }


        $failedJob = (new FailedAdminMailJob($this->carQuery, $error))->onQueue('emails');
        $this->dispatch($failedJob);

        return true;
    }

    private function carQueryFieldsCheck(): bool
    {
        return ($this->fieldCheck('response') && $this->fieldCheck('xml') && $this->fieldCheck('pdf') && $this->fieldCheck('local_pdf'));
    }

    private function fieldCheck($fieldName)
    {
        return !empty($this->carQuery->{$fieldName});
    }

    private function generatePushParameters(): array
    {
        $parameters = [
            'include_player_ids' => [$this->carQuery->order->user->device_token],
            'headings' => [
                'en' => 'Sua consulta veicular chegou!'
            ],
            'contents' => [
                'en' => 'O pagamento foi processado com sucesso e você pode acessar sua consulta através da tela de consulta de seu aplicativo '
            ],
            'android_group' => 7,
            'android_group_message' => [
                'en' => '$[notif_count] Aviso(s)'
            ],
            'small_icon' => 'repasse_small_icon_white',
            'large_icon' => 'repasse_icon',
            'data' => ['car' => true]
        ];

        return $parameters;
    }

}