<?php

namespace App\Transformers\Chat;

use App\Transformers\Transformer;

class ChatTransformer extends Transformer
{
    public function transform( $value )
    {
        $messages = [];
        foreach ( $value->messages()->where( 'msg_type', 1 )->get() as $_message ) {
            $msg  = json_decode( $_message->json );
            $date = date( 'Y-m-d', $msg->message_id / 1000 );

            $messages[$date]['date']   = $date;
            $messages[$date]['msgs'][] = $msg;

            $messages[$date]['msgs'] = $this->unique_multidim_array( $messages[$date]['msgs'], 'message_id' );
        }

        return [
            'success' => true,
        	'data' => [
	        	'dates'   => array_values( $messages )
	        ]
        ];
    }

    public function transformCollection ( $values )
    {
        $data = [];
        $total_badges = 0;
        foreach ( $values as $value ) {

            $badge = (integer)$value->badges($value->anuncio->user_id);

            if ($badge > 0) {
                ++$total_badges;
            }
            
            $data[] = [
                'room_id'   => (integer)$value->id,
                'badge'     => $badge,
                'bid'       => $value->bid,
                'purchaser' => [
                    'id'         => $value->comprador->id,
                    'name'       => $value->comprador->name,
                    'email'      => $value->comprador->email,
                    'phone'      => $value->comprador->phone,
                    'cell_phone' => $value->comprador->cell_phone,
                    'photo'      => $value->comprador->photo,
                ]
            ];
        }

        return [
            'success' => true,
            'data'  => [
                'totals'       => count( $values ),
                'per_page'     => count( $values ),
                'current_page' => 1,
                'badge'        => $total_badges,
                'items'        => $data,
            ]
        ];
    }

    protected function unique_multidim_array( $array, $key )
    {
        $temp_array = array();
        $key_array  = array();

        $i = 0;
        foreach( $array as $val ) {
            $val = (array)$val;
            if ( !in_array( $val[$key], $key_array ) ) {
                $key_array[$i]  = $val[$key];
                $temp_array[$i] = $val;
            }
            $i++;
        }
        return $temp_array;
    }
}