<?php
namespace App\Admin\Dashboard\Http\Controllers;

use App\Admin\Dashboard\Models\CarReason;
use App\Admin\Dashboard\Models\Optional;
use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarSell;
use App\Admin\Dashboard\Models\Config;
use App\Admin\Dashboard\Models\Room;
use App\Auth\Models\User;
use App\Auth\Models\UserType;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\EditUserPodioJob;
use App\Repasse\UserControl\Block;
use DB;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Redirect;
use Illuminate\Http\Response;
use Input;




class DashboardController extends CoreController
{
    use DispatchesJobs;

    protected $user;


    public function __construct()
    {
        $this->user = auth::user();
    }

    public function index(){
        $user = Auth::user();
        return view('admin::dashboard.index')->with('user', $user)->with('collapse', null);
    }

    /**
     * @param $period
     * @return mixed
     */
    public function dataIndex($period){

        $userTypes = UserType::all();
        $sellTypes = CarReason::all();

        $dealership = User::where('role_id', '2');
        $sell = new CarSell;
        $ad = Car::join('user', 'user.id', '=', 'car.user_id');
        $room = new Room();

        switch ($period) {
            case 'day':
                $date = Carbon::now();
                $dealership = $dealership->whereBetween('created_at', [
                    $date->startOfDay()->toDateTimeString(), $date->endOfDay()->toDateTimeString()
                ]);
                $sell = $sell->whereBetween('created_at', [
                    $date->startOfDay()->toDateTimeString(), $date->endOfDay()->toDateTimeString()
                ]);
                $ad = $ad->whereBetween('published_at', [
                    $date->startOfDay()->toDateTimeString(), $date->endOfDay()->toDateTimeString()
                ]);
                $room = $room->whereBetween('created_at', [
                    $date->startOfDay()->toDateTimeString(), $date->endOfDay()->toDateTimeString()
                ]);
                break;
            case 'yesterday':
                $date = Carbon::yesterday();
                $dealership = $dealership->whereBetween('created_at',[
                    $date->startOfDay()->toDateTimeString(), $date->endOfDay()->toDateTimeString()
                ]);
                $sell = $sell->whereBetween('created_at', [
                    $date->startOfDay()->toDateTimeString(), $date->endOfDay()->toDateTimeString()
                ]);
                $ad = $ad->whereBetween('published_at', [
                    $date->startOfDay()->toDateTimeString(), $date->endOfDay()->toDateTimeString()
                ]);
                $room = $room->whereBetween('created_at', [
                    $date->startOfDay()->toDateTimeString(), $date->endOfDay()->toDateTimeString()
                ]);
                break;
            case 'week':
                $dealership = $dealership->whereBetween('created_at', [
                    Carbon::parse('last sunday')->startOfDay()->toDateTimeString(),
                    Carbon::parse('next saturday')->endOfDay()->toDateTimeString(),
                ]);
                $sell = $sell->whereBetween('created_at', [
                    Carbon::parse('last sunday')->startOfDay()->toDateTimeString(),
                    Carbon::parse('next saturday')->endOfDay()->toDateTimeString(),
                ]);
                $ad = $ad->whereBetween('published_at', [
                    Carbon::parse('last sunday')->startOfDay()->toDateTimeString(),
                    Carbon::parse('next saturday')->endOfDay()->toDateTimeString(),
                ]);
                $room = $room->whereBetween('created_at', [
                    Carbon::parse('last sunday')->startOfDay()->toDateTimeString(),
                    Carbon::parse('next saturday')->endOfDay()->toDateTimeString()
                ]);
                break;
            case 'month':
                $date = Carbon::now();

                $dealership = $dealership->whereBetween( 'created_at', [
                    $date->startOfMonth()->toDateTimeString(), $date->endOfMonth()->toDateTimeString()
                ]);

                $sell = $sell->whereBetween( 'created_at', [
                    $date->startOfMonth()->toDateTimeString(), $date->endOfMonth()->toDateTimeString()
                ]);

                $ad = $ad->whereBetween( 'published_at', [
                    $date->startOfMonth()->toDateTimeString(), $date->endOfMonth()->toDateTimeString()
                ]);
                $room = $room->whereBetween('created_at', [
                    $date->startOfMonth()->toDateTimeString(), $date->endOfMonth()->toDateTimeString()
                ]);

                break;
            case 'all':
                $meta = 0;
                break;
            default:
                $meta = 0;
                break;
        }
        $count = (object) null;
        $count->dealership = $dealership->count();
        $count->dealership_types = [];
        $count->ad_types = [];

        $qtNaoInformado = clone $dealership;
        $naoInformado = [];
        $naoInformado['name'] = 'Não Informado';
        $naoInformado['quantity'] = $qtNaoInformado->where('user_type', 0)->count();
        $count->dealership_types[] = $naoInformado;

        $qtAdNaoInformado = clone $ad;
        $adNaoInformado =  [];
        $adNaoInformado['name'] = 'Não Informado';
        $adNaoInformado['quantity'] = $qtAdNaoInformado->where('user.user_type', 0 )->count();
        $count->ad_types[] = $adNaoInformado;


        foreach ($userTypes as $type) {
            $qt = clone $dealership;
            $add = [];
            $add['name'] = $type->name;
            $add['quantity'] =  $qt->where('user_type', $type->id)->count();
            $count->dealership_types[] = $add;

            $adQt = clone $ad;
            $addAd = [];
            $addAd['name'] = $type->name;
            $addAd['quantity'] = $adQt->where('user.user_type', $type->id )->count();
            $count->ad_types[] = $addAd;
        }


        $count->sell = $sell->count();
        $count->sell_types = [];
        foreach ($sellTypes as $type ) {
            if($type->id !== 3) {
                $qt = clone $sell;
                $add = [];
                $add['name'] = $type->name;
                $add['quantity'] = $qt->where('reason_id', $type->id)->count();
                $count->sell_types[] = $add;
            }
        }

        $count->ad = $ad->count();
        $count->rooms = $room->count();


        return response()->json($count);

    }



    public function carConfig() {
        $optionals = Optional::with('tipo')->get();

        return view('admin::dashboard.car')->with('optionals', $optionals)->with('collapse', 'config');
    }

    public function configPercent(){

        $params = Input::all();

        $config_percent = Config::find(1);

        if(!$config_percent){
            $config_percent = new Config();
            $config_percent->id = 1;
        }

        $config_percent->percent = $params['edtPorcentagemFIPE'];
        $config_percent->save();

        return Redirect::route('admin.fipe.config');

    }

    public function userConfig() {
        $users = User::where('role_id', 1)->get();
        return view('admin::dashboard.usuarios')->with('users', $users)->with('collapse', 'config');
    }

    public function userRegister(){

        $params = Input::all();

        $userFind = User::where('email', $params['email'])->count();

        if ($userFind >= 1) {
            $response = new Response();
            $response->setStatusCode(409);
            $response->setContent(['success' => false, 'msg' => 'O e-mail informado já existe, por favor escolha outro']);
            return $response;
        }

        $user = new User();
        $user->name = $params['name'];
        $user->role_id = 1;
        $user->chat_token = uuidv4();
        $user->email = $params['email'];
        $user->password = $params['password'];




        if($user->save()){
            return array('success' => true, 'data' => $user);
        }else {
            return array('success' => false);
        }
    }

    public function userRegisterUpdate(){

        $params = Input::all();

        $user = User::find($params['id']);
        $user->name = $params['name'];
        $user->email = $params['email'];
        if(!empty($params['password'])){
            $user->password = $params['password'];
        }
        if($user->save()){
            return array('success' => true, 'data' => $user);
        }else {
            return array('success' => false);
        }
    }

    public function userRegisterDelete(){

        $params = Input::all();

        $user = User::find($params['id']);

        if($user->delete()){
            return array('success' => true);
        }else {
            return array('success' => false);
        }
    }

    public function userAccept($user_id){
        $user = User::find($user_id);

        $user->is_aprovado = 1;
        $user->save();

        $editUserJob = (new EditUserPodioJob($user, $this->user))->onQueue('push');
        $this->dispatch($editUserJob);

        return Redirect::route('admin.permission');
    }

    public function userReject($user_id){
        $car = new Car();
        $user = new User();
        $block = new Block($user, $car, $this->user);
        $block->block($user_id);
        /*
        $user = User::find($user_id);
        $user->is_aprovado = 0;
        $user->save();
        */
        return Redirect::route('admin.permission');
    }

    public function multiUserStatusUpdate(Request $request) {
        $userList = $request->input('userid');
        $action = $request->input('action');
        $status = ($action == 'liberar') ? 1 : 0;


        if ($status == 0) {
            $car = new Car();
            $user = new User();
            $block = new Block($user, $car, $this->user);
            foreach($userList as $u) {
                $block->block($u);
            }


        } else {
            $usersUpdate = User::whereIn('id', $userList)->update(['is_aprovado' => $status]);

            foreach($userList as $u) {
                $user = User::find($u);
                $editUserJob = (new EditUserPodioJob($user, $this->user))->onQueue('push');
                $this->dispatch($editUserJob);
            }
        }

        $response = new Response();
        $response->setContent(['success' => true, 'msg' => 'Solicitação efetuada com sucesso.']);
        return $response;
    }

    public function userTypeChange(Request $request)
    {
        $this->validate($request, [
            'user_id'   => 'required',
            'user_type' => 'required'
        ]);

        $dados = $request->only(['user_id', 'user_type']);

        $usuario = User::find($dados['user_id']);

        if (!$usuario) {
            return back()->withInput()->withErrors(['msg' => 'Usuário não existe']);
        }

        $usuario->user_type = $dados['user_type'];
        $usuario->save();

        $userEditJob = (new EditUserPodioJob($usuario, $this->user))->onQueue('push');
        $this->dispatch($userEditJob);

        return back()->withInput();

    }

}
