<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 23/03/2018
 * Time: 17:21
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Models\City;
use App\Admin\Dashboard\Models\Plan\Plan;
use App\Admin\Dashboard\Models\State;
use App\Admin\Dashboard\Models\Store\Store;
use App\Auth\Models\User;
use App\Auth\Models\UserStatus;
use App\Auth\Models\UserType;
use App\Core\Http\Controllers\CoreController;
use Illuminate\Http\Request;

class UserSearchController extends CoreController
{
    public function index()
    {
        return view('admin::usersearch.index')
            ->with('collapse', 'pesquisar')
            ->with('user_types', $this->populateUserType())
            ->with('status', $this->populateUserStatus())
            ->with('states', $this->populateState());
    }

    public function search(Request $request)
    {
        $params = $request->only(['user_types', 'is_aprovado', 'state', 'name', 'document', 'telephone', 'email', 'created_at_start', 'created_at_end', 'last_seen_start', 'last_seen_end', 'user_id']);

        /** @var User $users */
        $users = User::with('type')->orderBy('created_at', 'desc')->where('role_id', 2);

        $user_types = array_filter($params['user_types']);
        if ($user_types) {
            $users->whereIn('user_type', $user_types);
        }

        $arr_isAprovado = [];
        foreach ($params['is_aprovado'] as $is_aprovado) {
            if (isset($is_aprovado) && $is_aprovado !== '') {
                $arr_isAprovado[] = $is_aprovado;
            }
        }

        if ($arr_isAprovado) {
            $users->whereIn('is_aprovado', $arr_isAprovado);
        }

        if ($params['state']) {
            $users->where('state', $params['state']);
        }

        if ($params['user_id']) {
            $users->where('id', $params['user_id']);
        }


        if ($params['name']) {
            $users->where(function ($query) use ($params) {
                $query->orWhere('name', 'like', "%{$params['name']}%");
                $query->orWhere('dealership', 'like', "%{$params['name']}%");
            });
        }

        if ($params['document']) {
            $users->where('document', $params['document']);
        }

        if ($params['telephone']) {
            $users->where(function ($query) use ($params) {
                $query->orWhere('phone', 'like', "%{$params['telephone']}%");
                $query->orWhere('cell_phone', 'like', "%{$params['telephone']}%");
            });

        }

        if ($params['email']) {
            $users->where('email', 'like', "%{$params['email']}%");
        }

        if ($params['created_at_start'] || $params['created_at_end']) {
            // inicial em branco: 01/01/2012
            $params['created_at_start'] = empty($params['created_at_start']) ? '2012-01-01' : $params['created_at_start'];
            // final em branco: 31/12/2099
            $params['created_at_end'] = empty($params['created_at_end']) ? '2099-12-31' : $params['created_at_end'];
            $users->whereBetween(\DB::raw('CAST(created_at AS DATE)'), [$params['created_at_start'], $params['created_at_end']]);
        }

        if ($params['last_seen_start'] || $params['last_seen_end']) {
            // inicial em branco: fica em branco para listar que usuários nunca entraram na sala de negociações.

            // final em branco: 31/12/2099
            $params['last_seen_end'] = empty($params['last_seen_end']) ? '2099-12-31' : $params['last_seen_end'];
            $users->whereBetween(\DB::raw('CAST(last_seen AS DATE)'), [$params['last_seen_start'], $params['last_seen_end']]);
        }

        return $users->get();

    }

    private function populateUserStatus(): array
    {

        $user_status = UserStatus::select(['id', 'name'])->get();
        $ar_status = ['' => ' - Selecione -'];

        foreach ($user_status as $status) {
            $ar_status[$status->id] = $status->name;
        }

        return $ar_status;

    }


    private function populateUserType(): array
    {
        $userTypes = UserType::select('id', 'name')->get();
        $ar_types = ['' => ' - Selecione - '];
        foreach ($userTypes as $type) {
            $ar_types[$type->id] = $type->name;
        }

        return $ar_types;

    }

    private function populateState($use_ids = null): array
    {
        $states = State::all();

        $ar_states = ['' => ' - Selecione - '];

        foreach ($states as $state) {
            if ($use_ids === null) {
                $ar_states[$state->initials] = $state->name;
            } else {
                $ar_states[$state->id] = $state->name;
            }
        }

        return $ar_states;

    }

    private function populatePlans(): array
    {
        $plans = Plan::where('status', 1)->get();

        $array_plans = ['' => ' - Selecione - '];

        foreach ($plans as $plan) {
            $array_plans[$plan->id] = $plan->title;
        }

        return $array_plans;

    }

    private function populateHasSite(): array
    {
        return [
            '' => ' - Selecione - ',
            0 => 'Sem Site',
            1 => 'Com Site'
        ];

    }

    private function populateHasDelivery(): array
    {
        return [
            '' => ' - Selecione - ',
            0 => 'Não',
            1 => 'Sim'
        ];

    }

    public function storeIndex()
    {
        return view('admin::usersearch.store')
            ->with('collapse', 'pesquisar')
            ->with('plans', $this->populatePlans())
            ->with('sites', $this->populateHasSite())
            ->with('status', $this->populateUserStatus())
            ->with('deliveries', $this->populateHasDelivery())
            ->with('states', $this->populateState(true));
    }

    public function storeSearch(Request $request)
    {
        $params = $request->only(['plans', 'has_site', 'state', 'name', 'document', 'created_at_start', 'created_at_end', 'store_id', 'has_delivery']);

        $stores = Store::with('plans', 'city', 'city.state')->orderBy('created_at', 'DESC');

        $plans = array_filter($params['plans']);
        if ($plans) {
            $stores->whereHas('plans', function ($query) use ($plans) {
                $query->whereIn('id', $plans);
            });
        }

        $has_site = array_filter($params['has_site']);
        if ($has_site) {
            $stores->whereIn('site', $has_site);
        }

        $has_delivery = array_filter($params['has_delivery']);
        if ($has_delivery) {
            $stores->whereIn('has_delivery', $has_delivery);
        }

        if ($params['state']) {
            $cities = City::where('stateId', $params['state'])->get(['id']);
            $stores->whereIn('city_id', $cities);
        }

        if ($params['store_id']) {
            $stores->where('id', $params['store_id']);
        }

        if ($params['name']) {
            // dd($params['name']);
            $stores->where(function ($query) use ($params) {
                $query->orWhere('trade_name', 'like', "%{$params['name']}%");
                $query->orWhere('company_name', 'like', "%{$params['name']}%");
            });
        }

        if ($params['document']) {
            $stores->where('cnpj', $params['document']);
        }

        if ($params['created_at_start'] || $params['created_at_end']) {
            // inicial em branco: 01/01/2012
            $params['created_at_start'] = empty($params['created_at_start']) ? '2012-01-01' : $params['created_at_start'];
            // final em branco: 31/12/2099
            $params['created_at_end'] = empty($params['created_at_end']) ? '2099-12-31' : $params['created_at_end'];
            $stores->whereBetween(\DB::raw('CAST(created_at AS DATE)'), [$params['created_at_start'], $params['created_at_end']]);
        }

        return $stores->get();

    }


}