<?php

namespace App\Admin\Dashboard\Http\Controllers;

use Illuminate\Support\Str;
use App\Admin\Dashboard\Models\UserSite\Site;
use App\Core\Http\Controllers\CoreController;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;

class UserSiteController extends CoreController
{
    use DispatchesJobs;

    protected $user;

    public function __construct()
    {
        $this->user = auth()->user();
    }

    public function index()
    {
        $sites = Site::all();

        return view('admin::sites.index')->with('sites', $sites);
    }

    public function show($site_id)
    {
        $site = Site::find($site_id);
        $domainStatusOptions = Site::domainStatusList() ?? [];

        if (!$site) {
            return redirect()->back();
        }

        return view('admin::sites.show')->with([
            'site' => $site,
            'domainStatusOptions' => $domainStatusOptions
        ]);
    }

    public function toggleStatus($site_id)
    {
        $site = Site::find($site_id);

        $site->update([
            'status' => !$site->status
        ]);

        return redirect()->back();
    }

    public function updateDomainInfo($site_id, Request $request)
    {
        $site = Site::find($site_id);

        $site->update([
            'domain' => $request->domain,
            'domain_status' => $request->domain_status
        ]);

        return ['success' => true];
    }

    public function generateToken($site_id)
    {
        $site = Site::find($site_id);

        $site->update([
            'token' => Str::random(40),
        ]);

        return redirect()->back();
    }

}