<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 07/02/2019
 * Time: 12:28
 */

namespace App\Admin\Dashboard\Http\Controllers;


use App\Admin\Dashboard\Models\Product;
use App\Admin\Dashboard\Models\Voucher\Voucher;
use App\Core\Http\Controllers\CoreController;
use App\Repasse\Products\Voucher\VoucherGenerator;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class VoucherController extends CoreController
{

    public function index()
    {
        $vouchers = Voucher::all();

        $products = Product::all();

        return view('admin::vouchers.index')->with('collapse', 'products')->with('vouchers', $vouchers)->with('products', $products);
    }

    public function edit($id)
    {
        $voucher = Voucher::findOrFail($id);

        $products = Product::all();

        return view('admin::vouchers.edit')->with('collapse', 'products')->with('voucher', $voucher)->with('products', $products);

    }

    public function store(Request $request)
    {

        $rules = [
            'product_id' => 'required|exists:products,id'
        ];

        $this->validate($request, $rules);

        // editar
        if ($request->has('id')) {
            $voucher = Voucher::findOrFail($request->get('id'));
            $voucher->product_id = $request->get('product_id');
            $voucher->save();
            return back();
        }

        // Gerar o código do token
        $code = VoucherGenerator::create();

        try {
            $voucher = Voucher::create(['product_id' => $request->get('product_id'), 'code' => $code, 'status' => 1]);
            return back();

        } catch (QueryException $e) {
            Log::error("O código do token é duplicado {$e->errorInfo['string']}", $code);
            return back()->withErrors('O código gerado é duplicado');
        }
    }

    public function delete($id, Request $request, Response $response)
    {
        Voucher::destroy($id);

        $response->setStatusCode(200);
        $response->setContent('Sucesso');

        return $response;
    }


}