<?php


Route::group(['middleware' => 'auth'], function () {
    Route::get('/', ['as' =>'admin', 'uses' => 'DashboardController@index']);
    Route::any('/configuracoes', ['as' =>'admin.config', 'uses' => 'DashboardController@config']);
    Route::get('/configuracoes/usuarios', ['as' => 'admin.users', 'uses' => 'DashboardController@userConfig']);
    Route::get('/configuracoes/carro', ['as' => 'admin.car', 'uses' => 'DashboardController@carConfig']);

    Route::group(['prefix' => 'relatorio'], function() {
        Route::get('/Concessionarias', ['as' =>'admin.reportdealerships', 'uses' => 'ReportController@reportdealerships']);
        Route::get('/Negociacoes', ['as' =>'admin.reportnegotiations', 'uses' => 'ReportController@reportnegotiations']);
        Route::get('/Anuncios', ['as' =>'admin.reportads', 'uses' => 'ReportController@reportads']);
        Route::get('/Instalacoes', ['as' => 'admin.reportinstall', 'uses' => 'ReportController@reportinstall']);
        Route::get('/Estoque/{user_id?}', ['as' => 'admin.report.estoque', 'uses' => 'ReportController@reportEstoque']);
        Route::get('/Anuncio/{id}', ['as' => 'admin.report.anuncio', 'uses' => 'ReportController@reportAnuncio']);
        Route::get('/Avaliacoes', ['as' => 'admin.report.avaliacoes', 'uses' => 'ReportController@reportRatings']);
        Route::get('/Leads', ['as' => 'admin.report.leads', 'uses' => 'ReportController@reportLeads']);
    });

    Route::group(['prefix' => 'moderar'], function() {
        Route::get('/', ['as' => 'admin.moderar.index', 'uses' => 'ModerarController@index' ]);
        Route::get('/{car_id}', ['as' => 'admin.moderar.anuncio', 'uses' => 'ReportController@reportAnuncio'] )->where('car_id', '[0-9]+');
        Route::post('/denuncia', ['as' => 'ajax.moderar.denuncia', 'uses' => 'ModerarController@denuncia']);
        Route::post('/denuncia/decisao', ['as' => 'ajax.moderar.decisao', 'uses' => 'ModerarController@decisao']);
    });

    Route::group(['prefix' => 'car'], function() {
        Route::get('/new/{vendedor_id?}', ['as' => 'admin.car.new', 'uses' => 'CarController@NewCar'])->where('vendedor_id', '[0-9]+');
        Route::get('/edit/{car_id}', ['as' => 'admin.car.edit', 'uses' => 'CarController@editCar' ])->where('car_id', '[0-9]+');
        Route::post('/update', ['as' => 'admin.car.update', 'uses' => 'CarController@updateCar']);

        Route::group(['prefix' => 'publish'], function() {
            Route::get('/', ['as' => 'admin.car.publishlist', 'uses' => 'CarController@listPublishables' ]);
            Route::post('/change', ['as' => 'ajax.car.publish', 'uses' => 'CarController@publishCar' ]);
        });

        Route::group(['prefix' => 'photo'], function() {
            Route::delete('/remove', ['as' => 'ajax.carphoto.remove', 'uses' => 'CarController@photoRemove']);
            Route::post('/upload', ['as' => 'ajax.carphoto.upload', 'uses' => 'CarController@photoUpload']);
            Route::post('/first', ['as' => 'ajax.carphoto.first', 'uses' => 'CarController@photoFirst']);
            Route::get('/print/{car_id}', ['as' => 'ajax.carphoto.print', 'uses' => 'CarController@photoPrint'])->where('car_id', '[0-9]+');
        });


        Route::get('/populate/{type?}', ['as' => 'admin.car.populate', 'uses' => '\App\Api\Http\Controllers\ApiController@populateAnnounce'])->where('type', '[0-9]+');
        Route::get('/populate-model/{brand_id?}/{year?}', ['as' => 'admin.car.models', 'uses' => '\App\Api\Http\Controllers\ApiController@populateModel'])->where(['brand_id' => '[0-9]+' ]);
        Route::get('/populate-year/{type?}/{brand_id?}', ['as' => 'admin.car.years', 'uses' => '\App\Api\Http\Controllers\ApiController@populateYear'])->where(['brand_id' => '[0-9]+', 'year' => '[0-9]+' ]);
        Route::get('/popupate-users/{type?}', ['as' => 'admin.car.users', 'uses' => 'CarController@listUsers'])->where('type', '[0-9]+');
        Route::get('/populate-staff/{store_id?}', ['as' => 'admin.car.staff', 'uses' => 'CarController@getAllStaff'])->where('store_id', '[0-9]+');
        Route::get('populate-fipe/{user_type?}/{year?}', ['as' => 'admin.car.fipe.limit', 'uses' => 'CarController@getFipeLimit'])->where('user_type', '[0-9]+');

        Route::post('/save', ['as' => 'admin.car.save', 'uses' => 'CarController@store']);

    });

    Route::group(['prefix' => 'fipe'], function() {
        Route::get('/modelo/{modelo_id}', ['as' => 'admin.fipe.modelo', 'uses' => 'FipeController@viewModelo'])->where('modelo_id', '[0-9]+');
        Route::post('/modelos/new', ['as' => 'ajax.fipe.modelos.save', 'uses' => 'FipeController@saveModelo']);
        Route::get('/modelos', ['as' => 'admin.fipe.modelos', 'uses' => 'FipeController@fipeModelos']);
        Route::get('/modelos/{car_type?}/{brand_id?}', ['as' => 'ajax.fipe.modelos', 'uses' => 'FipeController@populateModel'])->where(['brand_id' => '[0-9]+', 'car_type' => '[0-9]+' ]);
        Route::any('/configuracoes', ['as' => 'admin.fipe.config', 'uses' => 'FipeController@config']);
        Route::post('/configuracoes/create', ['as' => 'admin.ajax.fipe.config.create', 'uses' => 'FipeController@configCreate']);
        Route::delete('/configuracoes/{config_id?}', ['as' => 'admin.ajax.fipe.config.delete', 'uses' => 'FipeController@configRemove']);
        Route::get('/orfaos', ['as' => 'admin.fipe.orfaos', 'uses' => 'FipeController@listOrfaos']);
        Route::post('/orfaos/save', ['as' => 'admin.fipe.orfaos.save', 'uses' => 'FipeController@saveOrfaos']);
        Route::post('/orfaos/create', ['as' => 'admin.fipe.orfaos.create', 'uses' => 'FipeController@createOrfaos']);
        Route::get('/orfaos/auto', ['as' => 'admin.fipe.orfaos.auto', 'uses' => 'FipeController@autoOrfaos' ]);
        Route::post('/tabela', ['as' => 'admin.fipe.tabela', 'uses' => 'FipeController@saveTabelaConfig']);
    });

    Route::group(['prefix' => 'config'], function() {
        Route::post('/', ['uses' => 'DashboardController@configPercent']);

        Route::group(['prefix' => 'blacklist'], function() {
            Route::get('/', ['as' => 'admin.blacklist.index',  'uses'=> 'BlacklistController@index']);
            Route::post('/new', ['as' => 'admin.blacklist.new', 'uses' => 'BlacklistController@create']);
        });

        Route::group(['prefix' => 'versao'], function() {
            Route::get('/', ['as' => 'admin.version.config',  'uses' => 'VersaoController@index']);
            Route::post('/get', ['as' => 'ajax.version.getversion', 'uses' => 'VersaoController@getVersion']);
            Route::post('/store', ['as' => 'ajax.version.store', 'uses' => 'VersaoController@store' ]);
            Route::post('/current', ['as' => 'ajax.version.setcurrent', 'uses' => 'VersaoController@setCurrent']);
            Route::post('/remove', ['as' => 'ajax.version.remove', 'uses' => 'VersaoController@removeVersion']);
        });

        Route::group(['prefix' => 'podio'], function() {
            Route::get('/', ['as' => 'admin.podio.index', 'uses' => 'PodioController@index']);
        });

        Route::group(['prefix' => 'moderar'], function() {
            Route::get('/', ['as' => 'admin.config.moderar.index', 'uses' => 'ModerarAutoResponderController@index']);
            Route::post('/', ['as' => 'admin.config.moderar.store', 'uses' => 'ModerarAutoResponderController@store']);
            Route::delete('/{id}', ['as' => 'admin.config.moderar.delete', 'uses' => 'ModerarAutoResponderController@delete'])->where('id', '[0-9]+');
            Route::get('/user/{user_type_id}/toggle', ['as' => 'admin.config.moderar.user.toggle', 'uses' => 'ModerarAutoResponderController@toggleUserType'])->where('user_type_id', '[1-6]');
        });

    });

    Route::group(['prefix' => 'search'], function() {
        Route::get('/user', ['as' => 'admin.user.search', 'uses' => 'UserSearchController@index']);
        Route::post('/user', ['as' => 'admin.user.search.submit', 'uses' => 'UserSearchController@search']);
        Route::get('/store', ['as' => 'admin.store.search', 'uses' => 'UserSearchController@storeIndex']);
        Route::post('/store', ['as' => 'admin.store.search.submit', 'uses' => 'UserSearchController@storeSearch']);

    });

    Route::get('/user/accept/{user_id}', ['as' =>'admin.user.accept', 'uses' => 'DashboardController@userAccept']);
    Route::get('/user/reject/{user_id}', ['as' =>'admin.user.reject', 'uses' => 'DashboardController@userReject']);
    Route::get('/dataindex/{period}', ['uses' => 'DashboardController@dataIndex']);

    Route::post('/user/type/change', ['as' => 'admin.user.change', 'uses' => 'DashboardController@userTypeChange']);

    Route::post('/userRegister', ['uses' => 'DashboardController@userRegister']);
    Route::put('/userRegister', ['uses' => 'DashboardController@userRegisterUpdate']);
    Route::delete('/userRegister', ['uses' => 'DashboardController@userRegisterDelete']);
    Route::post('/user/change', ['as' => 'admin.multi.update', 'uses' => 'DashboardController@multiUserStatusUpdate'] );
    Route::post('/user/plan/change', ['as' => 'admin.ajax.user.planselect', 'uses' => 'AdminUserController@setUserPlan']);

    Route::group(['prefix' => 'chat'], function() {
        Route::get('/monitor', ['as' => 'admin.chat.monitor', 'uses' => 'ChatController@chatMonitor']);
        Route::get('/restart', ['as' => 'ajax.chat.restart', 'uses' => 'ChatController@chatRestart']);
    });

    /* Produtos */
    Route::group(['prefix' => 'products'], function() {
        /* Planos */
        Route::group(['prefix' => 'plans'], function(){
            Route::get('/', ['as' => 'admin.ajax.plans.index', 'uses' => '\\App\\Api\\Http\\Controllers\\Plan\\PlanController@index']);
        });

        /* Orçamento / Listagem de produtos por tipo */
        Route::get('/quote/{product_id}', ['as' => 'admin.ajax.product.quote', 'uses' => '\App\Api\Http\Controllers\ApiProductsController@getQuoteByType'])->where('product_id', '[0-9]+');

        /* Novo pedido */
        Route::post('/order/new', ['as' => 'admin.ajax.order.create', 'uses' => 'AdminOrderController@orderCreate']);

        /* Vouchers / Cupons de desconto */
        Route::group(['prefix' => 'vouchers'], function() {
            Route::get('/', ['as' => 'admin.products.vouchers.index', 'uses' => 'VoucherController@index']);
            Route::post('/new', ['as' => 'admin.products.vouchers.new', 'uses' => 'VoucherController@store']);

            Route::group(['prefix' => '{id}'], function() {
                Route::get('/delete', ['as' => 'admin.products.vouchers.delete', 'uses' => 'VoucherController@delete']);
                Route::get('/edit', ['as' => 'admin.products.vouchers.edit', 'uses' => 'VoucherController@edit']);
            });
        });

        /* Sistema de avisos / Publicidade */
        Route::group(['prefix' => 'avisos'], function() {
            Route::get('/', ['as' => 'admin.products.avisos.index', 'uses' => 'AvisoController@index']);
            Route::post('/create', ['as' => 'admin.products.avisos.create', 'uses' => 'AvisoController@create']);
        });

        Route::group(['prefix' => 'carqueries'], function() {
           Route::get('/', ['as' => 'admin.products.carqueries.index', 'uses' => 'CarQueryController@index']);
        });
    });

    Route::group(['prefix' => 'stores'], function() {
        Route::post('/plan/remove', ['as' => 'admin.ajax.store.removeplan', 'uses' => 'StoreController@removePlan']);
        Route::post('/token/generate', ['as' => 'admin.ajax.store.generatetoken', 'uses'=> 'StoreController@generateToken']);
        Route::post('/site/change', ['as' => 'admin.ajax.store.changesite', 'uses' => 'StoreController@changeSite']);
        Route::post('/site/set', ['as' => 'admin.ajax.store.setsiteurl', 'uses' => 'StoreController@setSiteUrl']);
        Route::group(['prefix' => '{store_id}'], function() {
            Route::get('/', ['as' => 'admin.store.view', 'uses' => 'StoreController@viewStore']);
            Route::get('/delivery', ['as' => 'admin.ajax.store.changedelivery', 'uses' => 'StoreController@changeDelivery']);
        });

    });

    Route::group(['prefix' => 'sites'], function() {
        Route::get('/', ['as' => 'admin.sites.index', 'uses' => 'UserSiteController@index']);
        Route::get('/{site_id}/visualizar', ['as' => 'admin.sites.show', 'uses' => 'UserSiteController@show']);

        Route::get('/{site_id}/toggle-status', ['as' => 'admin.sites.toggle-status', 'uses' => 'UserSiteController@toggleStatus']);
        Route::put('/{site_id}/update-domain', ['as' => 'admin.sites.update-domain', 'uses' => 'UserSiteController@updateDomainInfo']);
        Route::get('/{site_id}/generate-token', ['as' => 'admin.sites.generate-token', 'uses' => 'UserSiteController@generateToken']);

    });
});