<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 11/05/2018
 * Time: 12:04
 */

namespace App\Admin\Dashboard\Models;


use App\Auth\Models\User;
use DateTime;
use Illuminate\Database\Eloquent\Model;


/**
 * @SWG\Definition(type="object", @SWG\Xml(name="CarTurbo"))
 */
class CarTurbo extends Model
{
    protected $table = 'car_turbo';

    protected $fillable = ['order_id', 'user_id', 'car_id', 'product_id', 'status', 'order_status', 'checkout_link', 'hired', 'fulfilled', 'boost_interval_hours', 'ad_airtime_hours', 'price'];

    protected $appends = ['situation'];

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $id;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $user_id;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $car_id;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $product_id;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $price;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $status;

    /**
     * @var string
     * @SWG\Property()
     */
    protected $order_id;

    /**
     * @var string
     * @SWG\Property()
     */
    protected $order_status;

    /**
     * @var string
     * @SWG\Property()
     */
    protected $checkout_link;

    /**
     * @var boolean
     * @SWG\Property()
     */
    protected $delayed_schedule;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $hired;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $fulfilled;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $boost_interval_hours;

    /**
     * @var integer
     * @SWG\Property()
     */
    protected $ad_airtime_hours;


    /**
     * @var string
     * @SWG\Property()
     */
    protected $situation;




    public function product()
    {
        return $this->hasOne('App\Admin\Dashboard\Models\Product', 'id', 'product_id');
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function getPriceAttribute($value)
    {
        if ($value !== 0 && $this->attributes['checkout_link'] === null) {
            return 'Consumido via Plano';
        }

        return $value === 0 ? 'Grátis / Cortesia' :  number_format( ($value / 100), 2, ',', '.');
    }

    protected function serializeDate(DateTime $date)
    {
        return $date->format('d/m/Y');
    }

    public function getSituationAttribute()
    {

        switch($this->attributes['order_status']) {
            case 'CREATED':
            case 'ORDER.CREATED':
            case 'ORDER.WAITING':
                $retorno = 'Efetue o Pagamento';
                break;

            case 'ORDER.PAID':
                $retorno = 'Pagamento Efetuado';
                break;
            case 'ORDER.NOT_PAID':
            case 'ORDER.REVERSED':
                $retorno = 'Cancelado';
                break;
            default:
                $retorno = 'Aguardando';
                break;
        }

        return $retorno;
    }



}