<?php

namespace App\Admin\Dashboard\Models\Store;

use App\Auth\Models\User;
use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\City;
use Illuminate\Database\Eloquent\Model;
use App\Admin\Dashboard\Models\Plan\Plan;
use App\Admin\Dashboard\Models\Transaction;

/**
 * @SWG\Definition(type="object", @SWG\Xml(name="Store"))
 */
class Store extends Model
{
    protected $fillable = [
        'user_id', 'company_name', 'trade_name', 'cnpj', 'city_id', 'neighborhood', 'street', 'number', 'complement', 'landmark', 'status', 'zipcode'
    ];

    protected $hidden = ['store_token'];

    /**
    * @var integer
    * @SWG\Property()
    */
    private $user_id;

    /**
     * @var string
     * @SWG\Property()
     */
    private $company_name;

    /**
     * @var string
     * @SWG\Property()
     */
    private $trade_name;

    /**
     * @var string
     * @SWG\Property()
     */
    private $cnpj;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $city_id;

    /**
     * @var string
     * @SWG\Property()
     */
    private $neighborhood;

    /**
     * @var string
     * @SWG\Property()
     */
    private $street;

    /**
     * @var string
     * @SWG\Property()
     */
    private $number;

    /**
     * @var string
     * @SWG\Property()
     */
    private $complement;

    /**
     * @var string
     * @SWG\Property()
     */
    private $landmark;

    /**
     * @var string
     * @SWG\Property()
     */
    private $zipcode;

    /**
     * @var integer
     * @SWG\Property()
     */
    private $status;

    const PARTICULAR_STORE = '33333333333333';
    const CORRETOR_STORE = '44444444444444';

    public function plans()
    {
        return $this->belongsToMany( Plan::class, 'plan_store' );
    }

    public function staff()
    {
        return $this->belongsToMany( User::class, 'store_user' )->withPivot('role_id', 'status')->withTimestamps();
    }

    public function city()
    {
        return $this->hasOne( City::class, 'id', 'city_id' );
    }

    public function owner()
    {
        return $this->hasOne( User::class, 'id', 'user_id' );
    }

    public function transactions()
    {
        return $this->hasMany( Transaction::class, 'store_id' );
    }

    public function cars()
    {
        return $this->hasMany( Car::class, 'store_id' );
    }

    public static function getParticularStore()
    {
        return self::where('cnpj', '33333333333333')->first();
    }

    public static function getCorretorStore()
    {
        return self::where('cnpj', '44444444444444')->first();
    }

}
