<?php

namespace App\Admin\Dashboard\Models\UserSite;

use App\Auth\Models\User;
use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\City;
use Illuminate\Database\Eloquent\Model;
use App\Admin\Dashboard\Models\Plan\Plan;
use App\Admin\Dashboard\Models\Transaction;
use App\Traits\HasSlug;

class Site extends Model
{
    use HasSlug;

    public const PENDING = 'PE'; // Pendente (Em análise)
    public const AVAILABLE = 'AV'; // Disponível
    public const UNAVAILABLE = 'UN'; // Indisponível
    public const COMPLETED = 'CO'; // Concluído

    protected $fillable = [
        'user_id',
        'template',
        'title',
        'domain',
        'domain_status',
        'name',
        'about_text',
        'mission_text',
        'vision_text',
        'values_text',
        'opening_hours',
        'main_logo',
        'footer_logo',
        'cnpj',
        'phone',
        'email',
        'social_networks',
        'colors',
        'zipcode',
        'city_id',
        'neighborhood',
        'street',
        'number',
        'status',
        'registration_status',
        'token'
    ];

    protected $hidden = ['token'];
    protected $with = ['owner', 'city'];
    protected $casts = [
        'social_networks' => 'array',
        'colors' => 'array'
    ];

    public static function domainStatusList()
    {
        return [
            self::PENDING       => 'Em análise',
            self::AVAILABLE     => 'Disponível',
            self::UNAVAILABLE   => 'Indisponível',
            self::COMPLETED     => 'Concluído',
        ];
    }

    public function getDomainStatusLabelAttribute()
    {
        return self::domainStatusList()[$this->domain_status] ?? '-';
    }

    public function city()
    {
        return $this->belongsTo(City::class, 'city_id', 'id');
    }

    public function owner()
    {
        return $this->belongsTo(User::class, 'user_id', 'id');
    }

}
