@extends('admin.master')
@section('content')
    <section id="dashboard-content">
        @if(session('message'))
            <div class="alert alert-success">
                {{session('message')}}
            </div>
        @endif
        @if (isset($errors) && count($errors) > 0)
            <div class="alert alert-danger">
                <ul>
                    @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </div>
        @endif
        <div id="relAnuncio" class="col-xs-12 section-content">
            <div class="row">
                <div class="col-xs-12">
                    <h3>Opções da moderação</h3>
                </div>
            </div>
            <div id="rla-content">
                <div class="container-fluid" id="tela-moderar">
                    <div class="row tab-content">
                        <div class="col-xs-6">
                            <h4>Nova Resposta automatizada</h4>
                            <div class="row">
                                <div class="col-xs-6">
                                    <form class="form" action="{{route('admin.config.moderar.store')}}" method="POST">
                                        {{csrf_field()}}
                                        <div class="form-group">
                                            <label for="title">Título:</label>
                                            <input type="text" name="title" id="title" class="form-control" required/>
                                        </div>
                                        <div class="form-group">
                                            <label for="text">Texto:</label>
                                            <input type="text" name="text" id="text" class="form-control" required/>
                                        </div>

                                        <div class="form-group">
                                            <button class="btn btn-primary" type="submit">Criar</button>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-xs-6">
                            <table class="table table-condensed table-responsive table-hover">
                                <thead>
                                <tr>
                                    <th>id</th>
                                    <th>Título</th>
                                    <th>Texto</th>
                                    <th>Data</th>
                                    <th>Ações</th>
                                </tr>
                                </thead>
                                <tbody>
                                @foreach($moderations as $ad)
                                    <tr data-toggle="tooltip" data-placement="top"
                                        title="<img src='/uploads/ads/{{$ad->filename}}' width='290' height='300' />">
                                        <td>{{ $ad->id }}</td>
                                        <td>{{ $ad->title }}</td>
                                        <td>{{ $ad->text }}</td>
                                        <td>{{ $ad->created_at->format('d/m/Y H:i:s') }}</td>
                                        <td>
                                            <button class="btn btn-sm btn-danger btn-excluir" data-id="{{$ad->id}}">
                                                <i class="fa fa-trash"></i>
                                            </button>
                                        </td>
                                    </tr>
                                @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-xs-12">
                            <div align="center">
                                {!! $moderations->render() !!}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <br>

            <div id="rla-content">
                <div class="container-fluid" id="tela-moderar">
                    <div class="row">
                        <div class="col-xs-12">
                            <h4>Moderação do cadastro de usuários</h4>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-xs-12">
                            <p>Cadastros novos de usuarios marcados com <i class="fa fa-toggle-on"></i> serão moderados
                            </p>
                            @foreach($userTypes as $userType)
                                <div class="row" x-data="{
                                   status: {{$userType->create_status}},
                                   loading: false,
                                   changeStatus: function() {
                                       this.loading = true;
                                       fetch('{{route('admin.config.moderar.user.toggle', ['user_type_id' => $userType->id])}}').then(res => res.json()).then(res => { this.loading = false; this.status = res.data.create_status });
                                       },
                                }">
                                    <div class="col-xs-3">
                                        {{$userType->name}}
                                    </div>
                                    <div class="col-xs-1">
                                        <button class="btn btn-sm btn-default">
                                            <i class="fa "
                                               x-bind:class="(status == 3) ? 'fa-toggle-on' : 'fa-toggle-off' "
                                               x-on:click="changeStatus"></i>
                                        </button>
                                        <i class="fa fa-spin fa-spinner" x-show="loading"></i>
                                    </div>
                                </div>
                            @endforeach

                        </div>
                    </div>
                </div>
            </div>
        </div>

    </section>
@endsection
@section('scripts')
    <script>
        $(document).ready(function () {
            $(".btn-excluir").click(function () {

                if (confirm('Deseja realmente excluir o texto?')) {
                    var id = $(this).data('id');
                    $.ajax({
                        url: '/admin/config/moderar/' + id,
                        type: 'DELETE',
                        data: {
                            "_token": '{{csrf_token()}}'
                        }
                    }).done(function () {
                        location.reload()
                    });
                }
            });
        });
    </script>
@endsection