@extends('admin.master')
@section('content')
    <section id="dashboard-content">
        <div class="panel panel-default" id="form-usuario">
            <div class="panel-heading">
                @if(session()->has('message'))
                    <div class="alert alert-success">
                        {{session()->get('message')}}
                    </div>
                @endif
                @if(session()->has('errors'))
                    <div class="alert alert-danger">
                        <ul>
                            @foreach ($errors->all() as $error)
                                <li>{{ $error }}</li>
                            @endforeach
                        </ul>
                    </div>
                @endif
                <h4 class="card-title" style="padding-left: 15px;">Usuários</h4>
            </div>
            <div class="row">
                <div class="col-lg-1 col-lg-offset-11">
                    <div class="dropdown">
                        <button class="btn btn-default dropdown-toggle" type="button" id="dropdownMenu1" data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">
                            Ações
                            <span class="caret"></span>
                        </button>
                        <ul class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenu1">
                            <li class="{{$user->remember_token ? '' : 'disabled'}}"><a href="{{$user->remember_token ? route('user.recuperar.senha', $user->remember_token) : ''}}" target="_blank">Trocar senha</a></li>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-lg-6">
                    <div class="panel-body">
                        <div class="card">
                            <div class="card-block">
                                @if(isset($user))
                                    <h4 class="card-title">Editar usuário</h4>
                                    {!! Form::model($user, ['route' => ['admin.user.update', $user->id], 'method' => 'put']) !!}
                                @else
                                    <h4 class="card-title">Criar usuário</h4>
                                    {!! Form::open(['method' => 'post', 'autocomplete' => 'off', 'route' => ['admin.user.store']]) !!}
                                @endif

                                <div class="row">
                                    <div class="col-lg-12">
                                        {!! Form::openGroup('user_type', 'Tipo de Usuário') !!}
                                        {!! Form::select('user_type', $user_types, $user->user_type) !!}
                                        {!! Form::closeGroup() !!}
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-12">
                                        {!! Form::openGroup('dealership', 'Nome da Loja/Concessionária') !!}
                                        {!! Form::text('dealership') !!}
                                        {!! Form::closeGroup() !!}
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6">
                                        {!! Form::openGroup('name', 'Nome') !!}
                                        {!! Form::text('name') !!}
                                        {!! Form::closeGroup() !!}
                                    </div>
                                    <div class="col-lg-6">
                                        <label for="document">Documento (CPF/CNPJ)</label>
                                        <div class="input-group">
                                            <input type="tel" id="document" class="form-control" name="document"
                                                   value="{{$user->document}}"
                                                   v-mask="['###.###.###-##', '##.###.###/####-##']">
                                            <span class="input-group-btn">
                                        <button type="button" class="btn btn-default" data-toggle="tooltip"
                                                data-placement="right"
                                                title="Colocar este documento na lista de restrição"
                                                v-on:click="addBlacklist('document', '{{$user->document}}', '({{$user->id}})  {{addslashes($user->name)}} ')">
                                            <span class="fa fa-minus-circle"></span>
                                        </button>
                                    </span>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6">
                                        <label for="phone">Telefone</label>
                                        <div class="input-group">
                                            <input type="tel" class="form-control" name="phone" id="phone"
                                                   value="{{$user->phone}}"
                                                   v-mask="['(##) ####-####', '(##) #####-####']">
                                            <span class="input-group-btn">
                                        <button type="button" class="btn btn-default" data-toggle="tooltip"
                                                data-placement="right"
                                                title="Colocar este telefone na lista de restrição"
                                                v-on:click="addBlacklist('phone', '{{$user->phone}}', '({{$user->id}})  {{addslashes($user->name)}} ')">
                                            <span class="fa fa-minus-circle"></span>
                                        </button>
                                    </span>
                                        </div>
                                    </div>
                                    <div class="col-lg-6">
                                        <label for="cell_phone">Telefone Celuar</label>
                                        <div class="input-group">
                                            <input type="tel" class="form-control" name="cell_phone" id="cell_phone"
                                                   value="{{$user->cell_phone}}"
                                                   v-mask="['(##) ####-####', '(##) #####-####']">
                                            <span class="input-group-btn">
                                        <button type="button" class="btn btn-default" data-toggle="tooltip"
                                                data-placement="right"
                                                title="Colocar este telefone na lista de restrição"
                                                v-on:click="addBlacklist('phone', '{{$user->cell_phone}}', '({{$user->id}})  {{addslashes($user->name)}} ')">
                                            <span class="fa fa-minus-circle"></span>
                                        </button>
                                    </span>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6">
                                        <div class="form-group">
                                            <label for="email">Email</label>
                                            <div class="input-group">
                                                <input id="email" class="form-control" type="email" name="email"
                                                       value="{{$user->email}}" v-bind:readonly="(isDisabled)">
                                                <span class="input-group-btn">
                                            <button type="button" class="btn btn-default"
                                                    v-on:click="confirmChange"><span
                                                        class="fa fa-pencil"></span></button>
                                        </span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6">
                                        <label for="device-token">Device Token</label>
                                        <div class="input-group">
                                            <input type="text" class="form-control" value="{{$user->device_token}}"
                                                   readonly>
                                            <span class="input-group-btn">
                                        <button type="button" class="btn btn-default" data-toggle="tooltip"
                                                data-placement="right"
                                                title="Colocar este código de aparelho na lista de restrição"
                                                v-on:click="addBlacklist('token', '{{$user->device_token}}', '({{$user->id}})  {{addslashes($user->name)}} ')">
                                            <span class="fa fa-minus-circle"></span>
                                        </button>
                                    </span>
                                        </div>
                                    </div>

                                    <div class="col-lg-6">
                                        <label for="last-seen">Visto por último</label>
                                        <input type="text" class="form-control"
                                               value="{{ ($user->last_seen <= 0) ? 'Não entrou no chat' : date('d/m/Y H:i:s', strtotime($user->last_seen)) }}"
                                               readonly>
                                    </div>
                                </div>
                                <br>
                                <div class="row">
                                    <div class="col-lg-6">
                                        {!! Form::openGroup('flag', 'Monitorar') !!}
                                        {!! Form::checkbox('is_flagged', 1) !!}
                                        {!! Form::closeGroup() !!}

                                    </div>
                                </div>
                                <div class="form-actions">
                                    <button type="submit" class="btn btn-primary" :disabled="(!btnSalvar)"><span
                                                class="glyphicon glyphicon-ok"></span> Salvar
                                    </button>
                                    <button type="button" class="btn btn-danger" v-on:click="removeUser({{$user->id}})"
                                            :disabled="(!btnExcluir)"><span class="glyphicon glyphicon-trash"></span>
                                        Excluir
                                    </button>
                                </div>
                                {!! Form::close() !!}
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-lg-6">
                    <div class="panel-body">
                        <div class="card">
                            <div class="card-block">
                                <div class="row">
                                    <div class="col-xs-12">
                                        <h4 class="card-title">Permissões</h4>
                                        @if($user && $user->roles)
                                            <ul>
                                                @foreach($user->roles as $role)
                                                    <li>{{$role->display_name}}</li>
                                                @endforeach
                                            </ul>
                                        @endif
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-xs-12">
                                        @if($user && $user->stores)
                                            <h4 class="card-title">Lojas</h4>
                                            @foreach($user->stores as $store)
                                                @if(in_array($store->cnpj, $particulares) )
                                                    <p>Usuário pertence a loja de corretor/particular</p>
                                                    <ul>
                                                        <li>Endereço: {{$user->address}}, {{$user->number}}  {{$user->neighborhood}} {{$user->city}}/{{$user->state}}</li>
                                                    </ul>
                                                @else
                                                <ul class="list-unstyled">
                                                    <li><strong>Id:</strong> {{$store->id}}</li>
                                                    <li><strong>Razão Social</strong>: {{$store->company_name}}</li>
                                                    <li><strong>Nome Fantasia</strong>: {{$store->trade_name}}</li>
                                                    <li><strong>CNPJ</strong>: {{$store->cnpj}}</li>
                                                    <li><strong>Endereço</strong>: {{$store->street}}
                                                        , {{$store->number}} {{$store->complement}} {{$store->landmark}} {{$store->neighborhood}} {{$store->city->name or ''}} {{$store->city->state->name or ''}}</li>
                                                    <li><strong>{{$store->site ? "Site ID: {$store->id}"  : 'Sem site'}}</strong></li>
                                                </ul>
                                                @if($store->plans)
                                                    <h5>Plano da Loja</h5>
                                                    @foreach($store->plans as $plan)
                                                        {{$plan->title}} R$ {{number_format($plan->price, 2, ',', '.')}}
                                                    @endforeach
                                                @endif
                                                @endif
                                                <hr>
                                            @endforeach
                                        @endif
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-xs-12">
                                        <h4>Termos de uso</h4>
                                        <table class="table table-condensed">
                                            <thead>
                                                <tr>
                                                    <th>Cód</th>
                                                    <th>Data de aceite</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                            @foreach ($user->agreements as $agreement)
                                                <tr>
                                                    <td><strong>{{$agreement->version}}</strong></td>
                                                    <td>{{$agreement->created_at->format('d/m/Y h:i:s')}}
                                                </tr>
                                            
                                            @endforeach

                                            </tbody>

                                        </table>

                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        </div>
    </section>
@endsection
@section('scripts')
    <script>
        $(function () {
            $('[data-toggle="tooltip"]').tooltip()
        });
    </script>
@endsection