<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 09/03/2017
 * Time: 17:21
 */

namespace App\Api\Http\Controllers;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarFavorite;
use App\Core\Http\Controllers\CoreController;
use App\Repasse\CarUtil;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Traits\Rest\ResponseHelpers;
use Illuminate\Pagination\Paginator;
use App\Transformers\Car\CarTransformer;

class ApiFavoriteController extends CoreController
{
    protected $request;
    protected $user;

    public function __construct(Request $request, Auth $auth) {
        $this->request = $request;
        $this->user    = $auth::user();
    }


    public function setFavorite($car_id) {
        $response = new Response();

        $car_id = (int)$car_id;
        //O carro existe?
        $car = Car::find($car_id);
        if (!$car) {
            $response->setStatusCode(404);
            $response->setContent(['success' => false, 'msg' => 'Anúncio não encontrado!']);
            return $response;
        }

        if ((int)$car->car_status_id !== 1 && (int)$car->car_status_id !== 9) {
            $response->setStatusCode(409);
            $response->setContent(['success' => false, 'msg' => 'Anúncio não está aberto!']);
            return $response;
        }

        if ($car->user_id === $this->user->id ) {
            $response->setStatusCode(409);
            $response->setContent(['success' => false, 'msg' => 'Este anúncio é seu!']);
            return $response;
        }

        // O favorito existe?
        $carFavorite = CarFavorite::where('user_id', $this->user->id)->where('car_id', $car_id)->get()->first();

        if ($carFavorite) {
            // Favorito existe, remover da lista
            $carFavorite->delete();
            $is_favorite = false;
        } else {
            // Não existe o favorito, inserir
            $carFavorite = CarFavorite::create(['user_id' => $this->user->id, 'car_id' => $car_id]);
            if (!$carFavorite) {
                $response->setStatusCode(500);
                $response->setContent(['success' => false, 'msg' => 'Falha ao criar favorito, tente novamente']);
                return $response;
            }
            $is_favorite = true;
        }

        // 1, 2, 3 ,4 , 5
        // retornar sempre a quantidade de favoritos do usuário
        // $total = CarFavorite::where('user_id', $this->user->id)->count();
        $carFavorites = CarFavorite::where('user_id', $this->user->id)->orderBy('updated_at', 'DESC')->get(['car_id']);
        $arrayFavorites = $carFavorites->pluck('car_id');

        $favorites = Car::whereIn('id',$arrayFavorites)->whereIn('car_status_id', [1,9]);
        $total = $favorites->count();
        $response->setStatusCode(200);
        $response->setContent(
            [
                'success' => true,
                'total' => $total,
                'car_id' => $car_id,
                'is_favorite' => $is_favorite
            ]
        );
        return $response;
    }

    public function listFavorites() {

        $response = new Response();
        $page = ($this->request->get('page') !== null ? (int)$this->request->get('page') : 1);
        $carFavorites = CarFavorite::where('user_id', $this->user->id)->orderBy('updated_at', 'DESC')->get(['car_id']);

        if(!$carFavorites->first()) {
            $response->setStatusCode(200);
            $response->setContent(
                [
                    'success' => true,
                    'total' => 0,
                    'page' => $page,
                    'data' => []
                ]
            );
            return $response;
        } else {
            $content =
                [
                    'success' => true,
                    'total' => 0,
                    'page'  => $page,
                    'data' => []
                ];
            // Select
            $arrayFavorites = $carFavorites->pluck('car_id');
            $ids_ordered = $arrayFavorites->implode(',');


            $favorites = Car::whereIn('id',$arrayFavorites)->whereIn('car_status_id', [1,9])->orderByRaw(DB::raw("FIELD(id, {$ids_ordered})"));
            $content['total'] = $favorites->count();

            // Paginação
            $max = 15;
            $favorites->limit($max)->offset(($page - 1) * $max);
            $favorites = $favorites->get();

            foreach ($favorites as $favorite) {
                $carob = new CarUtil($favorite);
                $car = $carob->getCarObject();
                $car->is_favorite = true;
                $content['data'][] = $car;
            }

            $response->setStatusCode(200);
            $response->setContent($content);

            return $response;
        }

    }

    /**
    * @SWG\Get(path="/my-favorites",
    *   tags={"Favorites"},
    *   summary="List all Favorites",
    *   description="",
    *   operationId="listFavorites",
    *   produces={"application/json"},
    *   @SWG\Parameter( in="query", name="per_page", description="Default: 20", required=false, type="integer" ),
    *    @SWG\Parameter( in="header", name="Authorization", description="Basic Auth", required=true, type="string" ),
    *   @SWG\Parameter( in="query", name="current_page", description="Default: 1", required=false, type="integer" ),
    *   @SWG\Parameter( in="query", name="order", description="ASC or DESC | Default: ASC", required=false, type="string" ),
    *   @SWG\Parameter( in="query", name="order_by", description="options: ID or created_at | Default:ID", required=false, type="string" ),
    *   @SWG\Response( response=200, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="status_code", type="integer", description="200" ),
    *           @SWG\Property( property="data", type="array",
    *               @SWG\Items( type="object",
    *                   @SWG\Property(property="totals", type="integer"),
    *                   @SWG\Property(property="per_page", type="integer"),
    *                   @SWG\Property(property="current_page", type="integer"),
    *                   @SWG\Property(property="items", type="array", @SWG\Items(
    *                       type="object", ref="#/definitions/CarTransformer"
    *                   ))
    *               )
    *           ),
    *       )
    *   ),
    *   @SWG\Response( response=400, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="error", type="string", description="Bad Request" )
    *       )
    *   )
    * )
    */
    public function index( Request $request )
    {
        try {
            $per_page      = $request->input('per_page') ? $request->input('per_page') : 10;
            $current_page  = $request->input('current_page') ? $request->input('current_page') : 1;
            $order_by      = $request->input('order_by') ? $request->input('order_by') : 'id';
            $order         = $request->input('order') ? $request->input('order') : 'DESC';
            $user          = auth()->user();
            $date          = Carbon::now();

            Paginator::currentPageResolver( function() use ( $current_page ) {
                return $current_page;
            });

            $favorites = $user->favorites()->get()->pluck( 'car_id' )->toArray();
            $cars      = Car::where( 'created_at', '>=', $date->subDays( 60 )->toDateTimeString() )
                            ->whereIn( 'id', $favorites )
                            ->whereIn( 'car_status_id', [1,9] )
                            ->orderBy( $order_by, $order )
                            ->paginate( $per_page );

            return ( new CarTransformer )->transformCollection( $cars );
        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['success'=>false, 'msg'=>trans( 'messages.error.unavailable' ), 'errors'=>[]] , 500 );
        }
    }

}