<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 18/04/2018
 * Time: 11:25
 */

namespace App\Api\Http\Controllers;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarFavorite;
use App\Admin\Dashboard\Models\CarPush;
use App\Admin\Dashboard\Models\CarQuery\CarQuery;
use App\Admin\Dashboard\Models\CarTurbo;
use App\Admin\Dashboard\Models\HistoricCarTurbo;
use App\Admin\Dashboard\Models\Product;
use App\Admin\Dashboard\Models\Store\Store;
use App\Admin\Dashboard\Models\Transaction;
use App\Auth\Models\User;
use App\Core\Jobs\CarQuery\PurchaseCarQueryJob;
use App\Core\Jobs\NewCarJob;
use App\Http\Requests\Products\ConsumeTurboRequest;
use App\Repasse\CarUtil;
use App\Repasse\Products\CarQuery\AutoCorp;
use App\Repasse\Products\CarQuery\SuccessNotification;
use App\Repasse\Products\Order\Order;
use App\Repasse\Products\Turbo\ScheduleTurbo;
use App\Repasse\Products\Voucher\ConsumeVoucher;
use App\Traits\Rest\ResponseHelpers;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Queue\Queue;
use Illuminate\Support\Facades\Auth;
use App\Core\Http\Controllers\CoreController;
use Artesaos\Moip\Facades\Moip;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Moip\Resource\Customer;
use Moip\Resource\Orders;
use Swagger\Annotations as SWG;


class ApiProductsController extends CoreController
{
    use DispatchesJobs, ResponseHelpers;

    protected $user;

    public function __construct(Auth $auth)
    {
        $this->user = $auth::user();
    }

    public function getQuoteByType($product_type)
    {
        $produtos = Product::where('type_id', $product_type)->where('status', 1);

        return $produtos->get();
    }

    public function createOrder(Request $request)
    {

        // pega o usuário logado
        $user = $this->user;
        // Pega o produto
        $product_id = $request->get('product_id');
        $anuncio_id = $request->get('car_id');
        $license_plate = mb_strtoupper($request->get('license_plate'));
        $product = Product::findOrFail($product_id);

        if ($product->type_id === 2) {
            // Consulta veicular....
            $data = new \stdClass();
            $data->product = $product;
            $data->user = $user;
            $data->options = ['license_plate' => $license_plate];
            $create = new Order();

            $order_data = $create->createOrder($data);
            if ($order_data) {
                $checkout = $create->createCheckoutLink($order_data);
                // Create carquery
                $car_query = CarQuery::create([
                    'product_id' => $product->options['product'],
                    'order_id' => $checkout->id,
                    'user_id' => $user->id,
                    'license_plate' => $license_plate
                ]);

                return $checkout;

            }

        }

        // Transação
        $Order = new CarTurbo;
        //$Order->user_id = $user->id;
        $Order->status = 1; //1 - created
        $Order->product_id = $product->id;
        $Order->price = $product->price;
        $Order->user_id = $user->id;
        $Order->car_id = $anuncio_id;
        // Salva (código de transação)
        $Order->save();

        // Início da transação do Moip
        $moip = Moip::start();


        /** @var Customer $cliente */
        $cliente = $moip->customers()->setOwnId($this->getClientId($user->id));
        $cliente->setFullname($user->name)->setEmail($user->email);
        //  dd($user);
        //
        if (!empty($user->document)) {
            $type = mb_strlen($user->document) === 11 ? 'CPF' : 'CNPJ';
            $cliente->setTaxDocument($user->document, $type);
        }

        if (!empty($user->cell_phone)) {
            $contryCode = 55;
            $areaCode = mb_substr($user->cell_phone, 0, 2);
            $number = mb_substr($user->cell_phone, 2);
            $cliente->setPhone($areaCode, $number, $contryCode);
        }


        $cliente->addAddress('BILLING', $user->address, $user->number, $user->neighborhood, $user->city, $user->state,
            $user->zipcode);
        $cliente->addAddress('SHIPPING', $user->address, $user->number, $user->neighborhood, $user->city, $user->state,
            $user->zipcode);


        /** @var Orders $moiporder */
        $moiporder = $moip->orders()->setOwnId($this->getOrderId($Order->id));
        $moiporder->addItem($product->name, 1, "Anúncio turbinado {$product->id} {$product->name} ", $product->price,
            'ADVERTISING_AND_MARKETING')
            ->setCustomer($cliente)
            ->create();

        $order_id = $moiporder->getId();
        $order_status = $moiporder->getStatus();

        $retorno = $moiporder->getLinks()->getAllCheckout();
        // dd($retorno->payCheckout);

        /*        echo '<pre>';

                print_r( $retorno );
                echo '</pre>';
                die();*/

        // $Order->provider_data = $retorno;
        $Order->order_id = $order_id;
        $Order->checkout_link = $retorno->payCheckout;
        $Order->order_status = $order_status;
        $Order->hired = $product->options['hired'];
        $Order->boost_interval_hours = $product->options['boost_interval_hours'];
        $Order->ad_airtime_hours = $product->options['ad_airtime_hours'];
        $Order->fulfilled = 0;
        $Order->save();

        return $Order;

    }

    private function getClientId($id)
    {
        return "REPCLI_{$id}";
    }

    private function getOrderId($id)
    {
        return "REPORD_{$id}";
    }

    public function getTurboOrder($order_id)
    {
        $car_turbo = CarTurbo::with('product')->where('order_id', $order_id)->firstOrFail();

        $car = Car::findOrFail($car_turbo->car_id);

        if ($car->user_id !== $this->user->id) {
            $response = new Response();
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Usuário não é dono do anúncio']);
            return $response;
        }

        return $car_turbo;
    }

    public function getOrdersByCar($car_id)
    {
        // verificar se o carro é do dono
        // select turbo com order
        $car = Car::findOrFail($car_id);
        if ($car->user_id !== $this->user->id) {
            $response = new Response();
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Usuário não é dono do anúncio']);
            return $response;

        }
        $orders = CarTurbo::with('product')->where('car_id', $car_id)->orderBy('created_at', 'DESC')->get();
        $total = \count($orders);

        return ['data' => $orders, 'total' => $total];

    }


    public function getAdReach(int $car_id): array
    {
        $user = $this->user;
        $Car = Car::findOrFail($car_id);
        $CarUtil = new CarUtil($Car);
        $CarObject = $CarUtil->getCarObject($user->id);

        if ($CarObject->turbo === false) {
            return ['turbo' => false];
        }

        $favoritos = CarFavorite::where('car_id', $car_id)->count();
        $notifications = CarPush::where('car_id', $car_id)->sum('eligible_tokens');


        return [
            'notifications' => $notifications,
            'negotiations' => $CarObject->chats,
            'calls' => $CarObject->calls,
            'favorites' => $favoritos
        ];


//        return [
//            'notifications' => random_int(3400, 9659),
//            'views' => random_int(4759, 12459),
//            'visits' => random_int(4770,12444),
//            'negotiations' => random_int(45,59),
//            'calls' => random_int(6,26),
//            'favorites' => random_int(2,22)
//        ];

    }

    public function handleWebhooks(Request $request)
    {
        $data = json_decode($request->getContent());

        // checar o tipo de evento "ORDER.PAID" pq a gente só está cuidando desse caso

        $Pedido = CarTurbo::where('order_id', $data->resource->order->id)->firstOrFail();

        if ($Pedido) {

            // atualiza com o status da empresa de pagamento
            $Pedido->order_status = $data->event;

            if ($data->event === 'ORDER.PAID') {

                $Car = Car::find($Pedido->car_id);

                if ((int)$Car->car_status_id !== 5) {
                    $scheduler = new ScheduleTurbo($Pedido);
                    $scheduler->run();
                } else {
                    $Pedido->delayed_schedule = true;
                }

            }

            $Pedido->save();

        }

        return ['success'];
    }

    public function handleCarQueryWebhooks(Request $request)
    {
        $data = json_decode($request->getContent());
        $pedido = \App\Admin\Dashboard\Models\Order\Order::where('order_id', $data->resource->order->id)->first();

        if (!empty($pedido)) {
            $pedido->order_status = $data->event;
            $pedido->save();

            if ($data->event === 'ORDER.PAID') {
                //
                $carQuery = CarQuery::where('order_id', $pedido->id)->first();
                if (!empty($carQuery) && empty($carQuery->response)) {
                    $key = config('carquery.key');
                    $env = config('carquery.env');

                    $job = (new PurchaseCarQueryJob($carQuery, $key, $env))->onQueue('push');
                    $this->dispatch($job);
                }
            }
        }

        return ['success'];

    }


    /**
     *
     * @SWG\Post(path="/products/consume/turbo",
     *   tags={"Turbo"},
     *   summary="Starts a turbo on ad",
     *   description="",
     *   operationId="consumeTurbo",
     *   produces={"application/json"},
     *   @SWG\Parameter( in="formData", name="product_id", description="ID do produto", required=true, type="integer", @SWG\Schema(ref="#/definitions/Product") ),
     *   @SWG\Parameter( in="formData", name="car_id", description="ID do Veículo", required=true, type="integer" ),
     *   @SWG\Parameter( in="formData", name="voucher", description="Voucher de desconto", required=false, type="string" ),
     *   @SWG\Response( response=200, description="", @SWG\Schema(ref="#/definitions/CarTurbo") ),
     *   @SWG\Response( response=400, description="",
     *       @SWG\Schema(
     *           @SWG\Property( property="error", type="string", description="Bad Request" )
     *       )
     *   ),
     *   @SWG\Response( response=403, description="",
     *       @SWG\Schema(
     *           @SWG\Property( property="error", type="object", description="Forbidden", @SWG\Schema(
     *           @SWG\Property(property="success", type="boolean", description="Operation result"),
     *           @SWG\Property(property="msg", type="string", description="User message")
     *
     *          ) )
     *       )
     *   ),
     *   @SWG\Response( response=404, description="",
     *       @SWG\Schema(
     *           @SWG\Property( property="message", type="string", description="Model not found " ),
     *       )
     *   ),
     *   @SWG\Response( response=422, description="", @SWG\Schema(
     *            @SWG\Property( property="message", type="string", description="Validation failed" ),
     *            @SWG\Property( property="errors", type="array",
     *                @SWG\Items( type="object",
     *                    @SWG\Property(property="field", type="string"),
     *                )
     *            ),
     *        )
     *    ),
     * )
     * @param ConsumeTurboRequest $request
     * @return mixed
     */
    public function consumeTurbo(ConsumeTurboRequest $request)
    {

        /*
        a requisição é idêntica a da solicitação do turbo, mesmos dados,
        mesmas rotinas (salvar em car_turbo etc)
        porém a diferença é que ela vai ser executada ao vivo
        e vai salvar os dados novos (transaction, historic_car_turbo)

        */

        // Pega o produto
        $product_id = $request->get('product_id');
        $anuncio_id = $request->get('car_id');

        // @TODO verificação do usuário, se a loja tem plano

        // pega o usuário logado
        /** @var User $user */
        $user = auth()->user();

        /** @var Car $Car */
        $Car = Car::find($anuncio_id);

        $store = $Car->store;

        $has_plan = false;

        foreach($store->plans as $plan) {
            if (!empty($plan)) {
                $has_plan = true;
            }
        }


        if (!$has_plan) {
            // Não tem plano
            return $this->forbidden(['success' => false, 'msg' => 'Usuário não está autorizado a turbinar anúncios']);
        }

        try {


            $product = Product::findOrFail($product_id);


            if ((int)$Car->car_status_id !== 1) {
                return $this->badRequest([
                    'success' => false,
                    'msg' => 'Anúncio não pode ser turbinado (Não está aberto)',
                    'errors' => []
                ], 409);
            }

            // Transação
            DB::beginTransaction();
            $Order = new CarTurbo();
            //$Order->user_id = $user->id;
            $Order->status = 1; //1 - created
            $Order->product_id = $product->id;
            $Order->checkout_link = null;
            $Order->price = $product->price;
            $Order->user_id = $user->id;
            $Order->car_id = $anuncio_id;
            $Order->hired = $product->options['hired'];
            $Order->boost_interval_hours = $product->options['boost_interval_hours'];
            $Order->ad_airtime_hours = $product->options['ad_airtime_hours'];
            $Order->fulfilled = 0;
            $Order->order_id = 'REPORD_' . uuidv4();
            $Order->order_status = 'ORDER.PAID';
            $Order->save();

            if ($request->has('voucher')) {
                // Consume voucher, já foi validado que ele existe, que ele não foi utilizado ainda e que ele é do produto
                ConsumeVoucher::doConsume($request->get('voucher'), $user->id, $Order->car_id);
            }

            // Registrar o consumo
            $historicTurbo = HistoricCarTurbo::create(['user_id' => $user->id, 'car_id' => $Car->id]);

            if ((int)$Car->car_status_id !== 5) {
                $scheduler = new ScheduleTurbo($Order);
                $scheduler->run();
            } else {
                $Order->delayed_schedule = true;
            }

            $Order->save();

            DB::commit();
            return $Order;
        } catch (\Exception $e) {
            \Sentry::captureException($e);
            DB::rollback();
            Log::error($e->getMessage() . ' on file: ' . $e->getFile() . ' on line: ' . $e->getLine());
            return $this->badRequest(['success' => false, 'msg' => trans('messages.error.unavailable'), 'errors' => []],
                500);
        }


    }

}