<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 13/06/2019
 * Time: 17:52
 */

namespace App\Api\Http\Controllers;


use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\CarEdit;
use App\Admin\Dashboard\Models\CarModeration;
use App\Admin\Dashboard\Models\CarOptional;
use App\Admin\Dashboard\Models\CarPhoto;
use App\Admin\Dashboard\Models\CarPublish;
use App\Admin\Dashboard\Models\CarSell;
use App\Admin\Dashboard\Models\Fipe;
use App\Admin\Dashboard\Models\StateDdd;
use App\Admin\Dashboard\Models\Store\Store;
use App\Admin\Dashboard\Models\Transaction;
use App\Auth\Models\User;
use App\Auth\Models\UserType;
use App\Chat\Agent;
use App\Core\Http\Controllers\CoreController;
use App\Core\Jobs\CarStatusPodioJob;
use App\Core\Jobs\EditCarPodioJob;
use App\Core\Jobs\NewCarPodioJob;
use App\Core\Jobs\NewSellPodioJob;
use App\Core\Jobs\StoreSite\SendEmailFormContactJob;
use App\Core\Jobs\StoreSite\SendEmailFormJob;
use App\Http\Requests\Car\ApiCarSellRequest;
use App\Http\Requests\Car\ApiCreateRequest;
use App\Http\Requests\Car\ApiUpdateRequest;
use App\Http\Requests\StoreSite\FormContactRequest;
use App\Http\Requests\StoreSite\FormRequest;
use App\Repasse\Audit\CopyCar;
use App\Repasse\Audit\IsEditable;
use App\Repasse\CarUtil;
use App\Repasse\Fipe\FipeLimit;
use App\Repasse\Moderator\CheckDuplicated;
use App\Repasse\Moderator\CheckFipeValue;
use App\Repasse\Moderator\CheckUserType;
use App\Repasse\Search\SearchPopulate;
use App\Traits\Rest\ResponseHelpers;
use Carbon\Carbon;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Pipeline\Pipeline;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;
use Image;
use Input;
use DB;

class ApiSiteController extends CoreController
{
    use DispatchesJobs, ResponseHelpers;

    public function getCars(Request $request, $store_id): array
    {

        // A pesquisa contempla os carros do cliente


        $search = Car::join('fipe', 'fipe.id', '=', 'car.fipe_id')
            ->join('brand', 'brand.id', '=', 'car.brand_id')
            ->where('car.store_id', $store_id)
            ->whereIn('car_status_id', [1, 9]);

        $car_type = $request->get('car_type');
        if ($car_type !== null) {
            $search = $search->where('car.car_type', $car_type);
        }

        // Marca
        $brand_id = $request->get('brand_id');
        if ($brand_id !== null) {
            $search = $search->where('car.brand_id', $brand_id);
        }

        // Modelo
        $modelo_id = $request->get('model_id');
        if ($modelo_id !== null) {
            $search = $search->where('fipe.modelo_id', $modelo_id);
        }

        // Ano inicial Ano Final
        $start_year = ($request->get('start_year') == null) ? 1984 : $request->get('start_year');
        $end_year = ($request->get('end_year') == null) ? date('Y') + 1 : $request->get('end_year');
        if ($start_year && $end_year) {
            $search = $search->whereBetween('car.year', [$start_year, $end_year]);
        }

        // Combustível
        $fuel = $request->get('fuel');
        if (!empty($fuel)) {
            $search = $search->whereIn('fipe.fuel', $fuel);
        }

        // Valor Inicial / Final
        $start_price = ($request->get('start_price') == null) ? 0 : $request->get('start_price');
        $end_price = ($request->get('end_price') == null) ? 2000000 : $request->get('end_price');
        if ($start_price !== null && $end_price !== null) {
            $search = $search->whereBetween('car.price', [$start_price, $end_price]);
        }

        // Portas (aceita um array)
        $doors = $request->get('doors');
        if (!empty($doors)) {
            $search = $search->whereIn('car.doors', $doors);
        }

        // Eixos (array)
        $eixos = $request->get('eixos');
        if (!empty($eixos)) {
            $search = $search->whereIn('car.eixos', $eixos);
        }

        // Cor (array)
        $color_ids = $request->get('color_ids');
        if (!empty($color_ids)) {
            $search = $search->whereIn('car.color_id', $color_ids);
        }

        // km  inicial / final
        $start_km = ($request->get('start_km') == null) ? 0 : $request->get('start_km');
        $end_km = ($request->get('end_km') == null) ? 400000 : $request->get('end_km');
        if ($start_km !== null && $end_km !== null) {
            $search = $search->whereBetween('car.km', [$start_km, $end_km]);
        }

        // Opcionais (aceita um array)
        $opcionais = $request->get('optionals_id');
        if (!empty($opcionais)) {
            $search = $search->join('car_optional', 'car_optional.car_id', '=',
                'car.id')->whereIn('car_optional.optional_id', $opcionais);
            $search = $search->havingRaw('count(car_optional.car_id) = ' . count($opcionais));
        }

        // Estados e DDDs
        $state_id = $request->get('state_id');
        $ddds = $request->get('ddds');
        if ($state_id !== null && !empty($ddds)) {
            $search = $search->whereIn('car.user_ddd', $ddds);
        }
        if ($state_id !== null && empty($ddds)) {
            $ddds = StateDdd::where('state_id', $state_id)->get(['ddd']);
            $search = $search->whereIn('car.user_ddd', $ddds);
        }

        // Ordem dos anúncios
        $order = $request->get('order_by');
        $direction = $request->get('direction');
        if ($order) {
            switch ($order) {
                case 'price' :
                    $search = $search->orderBy('car.price', $direction);
                    break;
                case 'year':
                    $search = $search->orderBy('car.year', $direction);
                    break;
                case 'km':
                    $search = $search->orderBy('car.km', $direction);
                    break;
                default:
                    $search = $search->orderBy('car.published_at');
            }
        } else {
            $search = $search->orderBy('car.published_at', 'DESC');
        }

        // paginação
        $page = $request->get('page', 1);
        $max = 15;

        $quantidade = $search->groupBy('car.id')->selectRaw('count(car.id) as qtd')->get();
        $total = \count($quantidade);

        $search = $search->limit($max)->offset(($page - 1) * $max)->groupBy('car.id');
        $searchResults = $search->select('car.*')->distinct()->get();
        //passar pelo get car object e retornar
        $results = [];
        foreach ($searchResults as $car) {
            unset($car->cost, $car->podio_id);
            $car_util = new CarUtil($car);
            $results[] = $car_util->getCarObject();
        }

        return [
            'success' => true,
            'total' => $total,
            'order_by' => SearchPopulate::getAvailableSorting(),
            'data' => $results
        ];

    }

    public function getCar(Response $response, $store_id, $car_id)
    {

        // 404 se o carro não existir
        // $z = new Car();
        $car = Car::where('id', $car_id)->carStatusAtivo()->firstOrFail();
        // Se o anúncio estiver fechado (status diferente de 1,2,9) é 404


        // Se o anúncio não é da loja, acesso negado.
        if ((int)$car->store_id !== (int)$store_id) {
            $response->setStatusCode(401);
            $response->setContent(['success' => false, 'msg' => 'Acesso negado']);
            return $response;
        }

        unset($car->cost, $car->podio_id);

        $car_ob = new CarUtil($car);

        $response->setContent([
            'success' => true,
            'data'    => $car_ob->getCarObject()
        ]);

        return $response;

    }

    public function populateByCarType($store_id ,$car_type): array
    {
        $brands = SearchPopulate::getBrands($car_type);
        $modelos = SearchPopulate::getModels(null, $car_type);
        $optional = SearchPopulate::getOptionals($car_type);
        $vendedores = SearchPopulate::getSellers($store_id);
        $cores = SearchPopulate::getColors();
        $eixos = SearchPopulate::getEixos();
        $portas = SearchPopulate::getDoors();
        $anos = SearchPopulate::getYears();

        return array(
            'success' => true,
            'data' => array(
                'brands' => $brands,
                'models' => $modelos,
                'colors' => $cores,
                'doors' => $portas,
                'eixos' => $eixos,
                'optional' => $optional,
                'years' => $anos,
                'sellers' => $vendedores
            )
        );
    }

    public function populateModels($store_id, $brand_id): array
    {
        $models = SearchPopulate::getModels($brand_id, null);
        return [
            'success' => true,
            'data' => [
                'models' => $models
            ]
        ];
    }

    public function populateFipe($store_id, $brand_id, $year)
    {

        $fipes = Fipe::where('brand_id', (int)$brand_id)
            ->where('year', $year)
            ->orderBy('model')
            ->select('id', 'modelo_id', 'brand_id', 'year', 'fuel', 'code', 'price', 'type',
                \DB::raw("CASE fuel WHEN 'Alcool' THEN CONCAT_WS(' ', model, fuel) ELSE model END AS model"))
            ->get();

        return ['success' => true, 'data' => $fipes];

    }

    public function sendContact(FormContactRequest $request, $store_id): array
    {
        $store = Store::findOrFail($store_id);

        $job = (new SendEmailFormContactJob($request->get('name'), $request->get('email'), $request->get('subject'), $request->get('message'), $store) )->onQueue('emails');
        $this->dispatch($job);

        return [
            'success' => true,
            'msg' => 'Solicitação enviada com sucesso!'
        ];

    }

    public function sendForm(FormRequest $request, $store_id): array
    {
        $store = Store::findOrFail($store_id);

        $job = (new SendEmailFormJob($store, $request->get('name'), $request->get('fields')) )->onQueue('push');
        $this->dispatch($job);



        //
        return [
            'success' => true,
            'msg' => 'Solicitação enviada com sucesso!'
        ];

    }

    public function saveCar(ApiCreateRequest $request, $store_id)
    {

        $response = new Response();

        $params = $request->all();
        $user = User::find($params['user_id']);
        // Aqui tem que ter uma validation decente: Store id e attributes->store->id tem que ser iguais
        $store = $request->attributes->get('store');

        // dd($store->staff);

        // user tem que estar em store também!
        $belongs_store = $store->staff->contains(function ($key, $value) use ($user) {
            return $value->id == $user->id;
        });

        if(!$belongs_store) {
            return $this->badRequest(
                [
                    'msg' => trans('messages.error.forbidden'),
                    'errors' => []
                ], 401);
        }



        $car = new Car();
        $car->fill($params);
        //Ticket#78 O status do carro após o cadastro é id 4 (EM CADASTRO)
        $car->store_id = $store->id;
        $car->car_status_id = 4;
        $car->user_id = $user->id;
        $car->user_ddd = substr($user->cell_phone, 0, 2);

        // Ticket#103 salva o valor da fipe no carro
        $fipe = Fipe::find($params['fipe_id']);
        $car->fipe_price = $fipe->price;
        $car->car_type = $fipe->type;

        // Verificar valor da Fipe alterado para trazer o dado da configuração de fipe por tipo de usuário e ano
        //$config = Config::find(1);
        // $percent = -1 * abs($config->percent);
        $fipe_percent = FipeLimit::getDefaultFipePercent($user->user_type, $fipe->year);
        $percent = -1 * abs($fipe_percent);

        $fipe = ($params['price'] - $car->fipe_price) / $car->fipe_price * 100;

        /*
         * Cada anúncio efetuado por este endpoint é de usuário pagante
         * de site, portanto o request não vai ser rejeitado caso viole
         * a regra da fipe, apenas terá a marcação para não ser publicado
         * na plataforma
         */
        $has_site = false;
        if ($fipe > $percent) {
            $has_site = true;
        }

        $car->site_only = $has_site;

        if ($car->save()) {

            foreach ($params['optionals'] as $optional_id) {
                $car_optional = new CarOptional();
                $car_optional->optional_id = $optional_id;
                $car_optional->car_id = $car->id;
                $car_optional->save();
            }

            $podioJob = (new NewCarPodioJob($car))->onQueue('push');
            $this->dispatch($podioJob);

            return ['car_id' => $car->id, 'msg' => 'Anúncio cadastrado com sucesso'];
        }

    }

    public function saveCarImage(Request $request, $store_id, $car_id)
    {
        $response = new Response();


        if ($request->hasFile('filename') AND $request->file('filename')->isValid()) {

            $car = Car::find($car_id);
            $store = $request->attributes->get('store');
            if (!$car) {
                $response->setStatusCode(404);
                $response->setContent(['success' => false, 'msg' => 'Anúncio não localizado']);
                return $response;
            }

            // Precisa verificar se a loja que está mandando o carro é dona do carro
            if ($store->id != $car->store_id) {
                $response->setStatusCode(403);
                $response->setContent(['success' => false, 'msg' => 'Não autorizado']);
                return $response;
            }

            $audit = IsEditable::check($car->car_status_id);

            if ($audit['edit'] === false) {
                $response->setStatusCode(401);
                $response->setContent(['success' => false, 'msg' => 'Anúncio não pode ser editado']);
                return $response;
            }

            if ($audit['copy'] === true) {
                // Cópia do anúncio para todos os anúncios pode ser editados
                $carEdit = new CarEdit();
                $carUtil = new CarUtil($car);
                $copyCar = new CopyCar($carEdit, $car->user_id, $carUtil->getCarObject(), 3);
                $copyCar->make();
            }


            $mimes = array('image/jpeg' => 'jpg', 'image/png' => 'png');
            $file = $request->file('filename');
            $extension = $file->getClientOriginalExtension();
            $fileMime = $file->getClientMimeType();
            if (in_array($fileMime, array_keys($mimes))) {
                //Salvar arquivo
                $filename = uniqid() . time() . '.' . $extension;
                Storage::disk('anuncio-imagem')->put('original_' . $filename, File::get($file));
                //Rotacionar e canvas
                // $background = Image::canvas(600, 450, array(0,0,0));
                $image = Image::make($request->file('filename')->getRealPath())->orientate();
                $image->fit(600, 450);
                // $background->insert($image, 'center');
                Storage::disk('anuncio-imagem')->put($filename, $image->stream());
                $car_photo = CarPhoto::create(['filename' => $filename, 'car_id' => $car_id]);

                if ($car->car_status_id == 6) {
                    $car_status_id = 5;
                    $car->car_status_id = $car_status_id;
                    $car->is_edited = 1;
                    $car->save();
                }


                $data = [
                    'success' => true,
                    'data' => [
                        'id' => $car_photo->id,
                        'filename' => $car_photo->filename
                    ]
                ];
                return $data;


            } else {
                $response->setStatusCode(400);
                $response->setContent(['success' => false, 'msg' => 'Arquivo Inválido (Não é uma imagem jpeg ou png)']);
                return $response;
            }


        } else {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Arquivo não enviado ou inválido']);
            return $response;
        }

    }


    public function removeCarImage(Request $request, $store_id = null, $car_id = null, $image_id = null)
    {
        $response = new Response();
        $usuario = Auth::user();
        $store = $request->attributes->get('store');


        if (!$image_id || !$store_id || !$car_id) {
            $response->setStatusCode(422);
            $response->setContent(['success' => false, 'msg' => 'Falta um parâmetro']);
            return $response;
        }

        $car_photo = CarPhoto::find($image_id);

        if (!$car_photo) {
            $response->setStatusCode(404);
            $response->setContent(['success' => false, 'msg' => 'Imagem não encontrada']);
            return $response;
        }

        $car = Car::findOrFail($car_photo->car_id);

        $audit = IsEditable::check($car->car_status_id);

        if ($audit['edit'] === false) {
            $response->setStatusCode(401);
            $response->setContent(['success' => false, 'msg' => 'Anúncio não pode ser editado']);
            return $response;
        }

        if ($audit['copy'] === true) {
            // Cópia do anúncio para todos os anúncios pode ser editados
            $carEdit = new CarEdit();
            $carUtil = new CarUtil($car);
            $copyCar = new CopyCar($carEdit, $usuario->id, $carUtil->getCarObject(), 3);
            $copyCar->make();
        }

        if ($store->id != $car->store_id) {
            $response->setStatusCode(403);
            $response->setContent(['success' => false, 'msg' => 'Acesso negado']);
            return $response;
        }

        $filename = $car_photo->filename;

        if ($car_photo->delete()) {
            Storage::disk('anuncio-imagem')->delete('original_' . $filename);

            if ($car->car_status_id == 6) {
                $car->car_status_id = 5;
                $car->is_edited = 1;
                $car->save();
            }

            return array('success' => true);
        }
    }

    public function publishCar(Request $request, $store_id, $car_id)
    {
        $response = new Response();

        $store = $request->attributes->get('store');

        /** @var Car $car */
        $car = Car::find($car_id);
        if (!$car) {
            $response->setStatusCode(404);
            $response->setContent(['success' => false, 'msg' => 'Anúncio não encontrado!']);
            return $response;
        }

        if ($store->id != $car->store_id) {
            $response->setStatusCode(403);
            $response->setContent(['success' => false, 'msg' => 'Acesso negado']);
            return $response;
        }

        if ($car->car_status_id != 4) {
            $response->setStatusCode(412);
            $response->setContent(['success' => false, 'msg' => 'Anúncio já foi publicado']);
            return $response;
        }

        $quantidadeFotos = CarPhoto::where('car_id', $car_id)->get()->count();
        if (($quantidadeFotos < 4) OR ($quantidadeFotos > 10)) {
            $response->setStatusCode(409);
            $response->setContent([
                'success' => false,
                'msg' => 'A quantidade de fotos difere da solicitada (entre 4 e 10)'
            ]);
            return $response;
        }

        // Salva o carro e marca como em análise (5)
        $car->car_status_id = 5;

        // $user_types = $request->get('user_types');
        //
        $user_types = UserType::all();

        if (!empty($user_types)) {
            foreach ($user_types as $user_type) {
                $carPublish = CarPublish::create(
                    [
                        'car_id' => $car->id,
                        'user_type' => $user_type->id
                    ]
                );
            }
        }

        $car->save();

        $car_ob = new CarUtil($car);
        $car_data = $car_ob->getCarObject();

        $car_data->score = 10;
        $car_data->reasons = [];
        $pipes = [
            CheckUserType::class,
            CheckDuplicated::class,
            CheckFipeValue::class
        ];

        $anunciar = app(Pipeline::class)
            ->send($car_data)
            ->through($pipes)
            ->then(function ($content) {

                // Checar score, se for abaixo de 10 manter status do anúncio
                if ($content->score <= 5) {
                    // Tabela de moderação.
                    $moderar = CarModeration::create([
                        'car_id' => $content->id,
                        'score' => $content->score,
                        'reasons' => $content->reasons
                    ]);
                }

                return $content;
            });

        // Se o anúncio é oferta exclusiva de site, ele não é publicado, apenas tem data de publicação
        if ($car->site_only) {
            $car->published_at = Carbon::now();
            $car->car_status_id = 1;
            $car->save();
            $podioStatusJob = (new CarStatusPodioJob($car, 1))->onQueue('push');
            $this->dispatch($podioStatusJob);

            $response->setStatusCode(201);
            $response->setContent([
                'success' => true,
                'msg' => 'Oferta exclusiva do seu site criada com sucesso!',
                'car' => $car_data
            ]);

            return $response;
        }

        // Se o anúncio está no score aprovado ele pode ser publicado.
        // Anúncio via api do cliente não manda push notification
        if ($anunciar->score >= 10) {
            $podioStatusJob = (new CarStatusPodioJob($car, 1))->onQueue('push');
            $this->dispatch($podioStatusJob);
            $car->published_at = Carbon::now();
            $car->car_status_id = 1;
            $car->save();

            //

            /*$podioJob = (new NewCarPodioJob($car))->onQueue('push');
            $this->dispatch($podioJob);*/

            $msg = 'Anúncio publicado com sucesso';
        } else {
            $podioStatusJob = (new CarStatusPodioJob($car, 5))->onQueue('push');
            $this->dispatch($podioStatusJob);
            $msg = 'Anúncio encontra-se em análise';
        }
        $response->setStatusCode(201);
        $response->setContent(['success' => true, 'msg' => $msg, 'car' => $car_data]);
        return $response;


    }

    public function updateCar(ApiUpdateRequest $request, $store_id, $car_id)
    {

        $response = new Response();

        /** @var Car $car */
        $car = Car::findOrFail($car_id);
        $store = $request->attributes->get('store');

        $user = User::find($car->user_id);
        if (($user->is_aprovado != 1) || ($car->store_id !== $store->id)) {
            $response->setStatusCode(403);
            $response->setContent(['success' => false, 'msg' => 'Usuário não autorizado']);
            return $response;
        }

        $audit = IsEditable::check($car->car_status_id);

        if ($audit['edit'] === false) {
            $response->setStatusCode(401);
            $response->setContent(['success' => false, 'msg' => 'Anúncio não pode ser editado']);
            return $response;
        }

        if ($audit['copy'] === true) {
            // Cópia do anúncio para todos os anúncios pode ser editados
            $carEdit = new CarEdit();
            $carUtil = new CarUtil($car);
            $copyCar = new CopyCar($carEdit, $user->id, $carUtil->getCarObject(), 3);
            $copyCar->make();
        }

        // meldels
        $params = Input::all();

        if (!empty($params)) {

            // Atualizar campos (color_id, doors, preço, km)
            $car->color_id = $request->get('color_id');
            $car->doors = $request->get('doors', '');
            $car->eixos = $request->get('eixos', '');
            $car->price = $request->get('price');

            if ($request->has('cost')) {
                $car->cost = $request->get('cost');
            }

            $car->km = $request->get('km', '');
            $car->observation = $request->get('observation', '');
            // Ticket#458 - Salvar o preço novo da fipe
            $fipe = Fipe::find($car->fipe_id);
            $car->fipe_price = $fipe->price;

            // Conforme combinado, editou (mas não estava em cadastro) vai pra análise
            if ($car->car_status_id == 6) {
                $car_status_id = 5;
                $car->car_status_id = $car_status_id;
                $car->is_edited = 1;
            }

            // Atualizar com os dados o cadastro
            $car->user_ddd = substr($user->cell_phone, 0, 2);

            if ($car->save()) {
                if (isset($params['optionals'])) {
                    // deleta opcionais antigos
                    $car->optionals()->delete();

                    // cadastra os novos
                    foreach ($params['optionals'] as $optional_id) {
                        $car_optional = new CarOptional();
                        $car_optional->optional_id = $optional_id;
                        $car_optional->car_id = $car->id;
                        $car_optional->save();
                    }
                }
                $carUtil = new CarUtil($car);

                $carEditJob = (new EditCarPodioJob($car))->onQueue('push');
                $this->dispatch($carEditJob);

                return array(
                    'success' => true,
                    'car_id' => $car->id,
                    'msg' => 'Anúncio alterado com sucesso',
                    'data' => $carUtil->getCarObject()
                );
            }
        }
    }


    public function removeCar(ApiCarSellRequest $request, $store_id, $car_id)
    {
        $response = new Response();
        // $vendedor = Auth::user();


        $comprador_id = $request->get('buyer_id', 0);
        // Foram encontrados casos em que o usuário envia o buyer_id como null fazendo a linha de cima praticamente retornar null ao invés de zero
        $comprador_id = $comprador_id ?? 0;

        $motivo = $request->get('reason_id');

        $car = Car::find($car_id);
        $store = $request->attributes->get('store');
        $vendedor = User::find($car->user_id);

        // Carro não encontrado ou excluído
        if (empty($car) or $car->car_status_id == 8) {
            $response->setStatusCode(404);
            $response->setContent(['success' => false, 'msg' => 'Carro não encontrado']);
            return $response;
        }

        if ($store->id !== $car->store_id) {
            $response->setStatusCode(403);
            $response->setContent(['success' => false, 'msg' => 'O usuário não é o proprietário do carro']);
            return $response;
        }

        // Carro só pode ser marcado como vendido ou excluído se estiver aberto (status 1 e 2)
        if (in_array($car->car_status_id, [1, 2, 5, 6, 7, 9], true)) {
            $host = config('chat.host');
            $port = config('chat.port');
            $token = config('chat.token');
            $message = [
                'sender_id' => $car->user_id,
                'receiver_id' => null,
                'car_id' => $car->id,
                'car_status_id' => null

            ];
            $agent = new Agent($host, $port, $token);
            // Motivos que precisam de usuário comprador: 1
            if ($motivo == 1) {
                // Vendeu o carro pelo aplicativo repasse
                $car_status_id = 3;

                $car->car_status_id = $car_status_id;
                $sell = new CarSell();
                $sell->car_id = $car->id;
                $sell->user_sell_id = $car->user_id;
                $sell->user_buy_id = $comprador_id;
                $sell->reason_id = $motivo;


                DB::transaction(function () use ($car, $sell, $comprador_id, $vendedor) {
                    $car->save();
                    $sell->save();

                    // Transação
                    if ($car->store_id) {
                        $store_id = $car->store_id;
                    } else {
                        // se o usuário tem lojas, a primeira em que ele é ativo. mystore não serve pois ele não é diretor da loja
                        $store_id = $vendedor->stores()->where('store_user.status', 1)->first()->id;
                    }

                    $seller = Transaction::create([
                        'type' => 1,
                        'car_id' => $car->id,
                        'user_id' => $car->user_id,
                        'store_id' => $store_id
                    ]);
                    if ($comprador_id !== 0) {
                        //
                        $comprador = User::find($comprador_id);
                        $buyer = Transaction::create([
                            'type' => 2,
                            'car_id' => $car->id,
                            'user_id' => $comprador_id,
                            'store_id' => $comprador->stores()->where('store_user.status', 1)->first()->id
                        ]);
                    }
                });
                // Podio
                $podioJob = (new NewSellPodioJob($sell))->onQueue('push');
                $this->dispatch($podioJob);

                // Mensagem
                $message['car_status_id'] = $car_status_id;
                $message['car_buyer'] = $comprador_id;

                $response->setStatusCode(200);
                $response->setContent([
                    'success' => true,
                    'msg' => 'Parabéns, seu veículo foi vendido.',
                    'car_status_id' => $car->car_status_id
                ]);
            }

            if ($motivo == 2) {
                // Vendeu o carro por outros meios
                $car_status_id = 3;

                $sell = new CarSell();
                $sell->car_id = $car->id;
                $sell->user_sell_id = $car->user_id;
                $sell->user_buy_id = $comprador_id;
                $sell->reason_id = $motivo;
                $car->car_status_id = $car_status_id;

                DB::transaction(function () use ($car, $sell) {
                    $car->save();
                    $sell->save();
                });

                $message['car_status_id'] = $car_status_id;

                $response->setStatusCode(200);
                $response->setContent([
                    'success' => true,
                    'msg' => 'Parabéns, seu veículo foi vendido.',
                    'car_status_id' => $car->car_status_id
                ]);
            }

            if ($motivo == 3) {
                // Desistiu de vender
                $car_status_id = 8;
                $car->car_status_id = $car_status_id;

                $sell = new CarSell();
                $sell->car_id = $car->id;
                $sell->user_sell_id = $car->user_id;
                $sell->user_buy_id = 0;
                $sell->reason_id = $motivo;
                $car->car_status_id = $car_status_id;

                DB::transaction(function () use ($car, $sell) {
                    $car->save();
                    $sell->save();
                });

                $message['car_status_id'] = $car_status_id;

                $response->setStatusCode(200);
                $response->setContent([
                    'success' => true,
                    'msg' => 'Veículo removido com sucesso',
                    'car_status_id' => $car->car_status_id
                ]);
            }

            $podioStatusJob = (new CarStatusPodioJob($car, $car_status_id))->onQueue('push');
            $this->dispatch($podioStatusJob);

            $agent->sendMessage($message);

            return $response;
        } else {
            $response->setStatusCode(409);
            $response->setContent(array(
                'success' => false,
                'msg' => 'Veículo não pode ser marcado como vendido pois seu status não está aberto'
            ));
            return $response;
        }

    }



}