<?php
/**
 * Created by PhpStorm.
 * User: Rafael
 * Date: 29/11/2016
 * Time: 09:52
 */

namespace App\Api\Http\Controllers;

use App\Admin\Dashboard\Models\City;
use App\Admin\Dashboard\Models\Plan\Plan;
use App\Http\Requests\Terms\TermsRequest;
use Carbon\Carbon;
use Illuminate\Http\JsonResponse;
use Log;
use Image;
use JWTAuth;
use App\Auth\Models\User;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Auth\Models\UserType;
use App\Admin\Role\Models\Role;
use App\Core\Jobs\GeolocationJob;
use App\Core\Jobs\NewUserPodioJob;
use App\Repasse\Security\Blacklist;
use App\Core\Jobs\EditUserPodioJob;
use App\Core\Jobs\SendWelcomeEmail;
use Illuminate\Pagination\Paginator;
use App\Traits\Rest\ResponseHelpers;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Auth;
use App\Admin\Dashboard\Models\Config;
use Illuminate\Support\Facades\Storage;
use Illuminate\Database\QueryException;
use App\Transformers\Car\CarTransformer;
use App\Http\Requests\Auth\LoginRequest;
use App\Http\Requests\User\CreateRequest;
use App\Http\Requests\User\SearchRequest;
use Illuminate\Support\Facades\Validator;
use App\Admin\Dashboard\Models\Store\Store;
use App\Http\Requests\User\CheckFieldRequest;
use App\Core\Http\Controllers\CoreController;
use App\Admin\Dashboard\Models\UserAgreement;
use Illuminate\Foundation\Bus\DispatchesJobs;
use App\Admin\Dashboard\Models\TokenBlackList;
use App\Transformers\User\UserSearchTransformer;
use Symfony\Component\HttpFoundation\File\UploadedFile;

class ApiUserController extends CoreController
{
    use DispatchesJobs, ResponseHelpers;

    private $user;
    private $request;
    private $auth;

    /**
     * ApiUserController constructor.
     * @param User $user
     * @param Request $request
     * @param Auth $auth
     */
    public function __construct(User $user, Request $request, Auth $auth)
    {
        $this->user = $user;
        $this->request = $request;
        $this->auth = $auth::user();

    }


    /**
    * @SWG\Post(path="/login",
    *    tags={"User"}, summary="Authenticate User", description="", operationId="authenticateUser", produces={"application/json"},
    *    @SWG\Parameter( name="email", in="formData", required=true, type="string", ),
    *    @SWG\Parameter( name="password", in="formData", description="Min length: 8", required=true, type="string" ),
    *    @SWG\Response( response=200, description="", @SWG\Schema( ref="#/definitions/User" ) ),
    *    @SWG\Response( response=400, description="", @SWG\Schema( @SWG\Property( property="error", type="string", description="Bad Request") ) ),
    *    @SWG\Response( response=401, description="", @SWG\Schema(
    *            @SWG\Property( property="error", type="string", description="Invalid credentials" )
    *        )
    *    ),
    *    @SWG\Response( response=404, description="", @SWG\Schema(
    *            @SWG\Property( property="message", type="string", description="Model not found " ),
    *        )
    *    ),
    *    @SWG\Response( response=422, description="", @SWG\Schema(
    *            @SWG\Property( property="message", type="string", description="Validation failed" ),
    *            @SWG\Property( property="errors", type="array",
    *                @SWG\Items( type="object",
    *                    @SWG\Property(property="field", type="string"),
    *                )
    *            )
    *        )
    *    )
    * )
    */
    public function authenticate( LoginRequest $request )
    {
        try {
            $params = $request->all();

            if ( !$token = JWTAuth::attempt( $request->only( 'email', 'password' ) ) ) {
                return $this->badRequest( ['success'=>false, 'msg' => trans( 'messages.error.user.credentials' ), 'errors'=>[]], 401 );
            }

            $user = Auth::user();

            if ( $user->is_aprovado == 1 && $user->role_id == 2 ) {

                if ( !empty( $params['device_token'] ) ) {
                    if ( !isUuid( $params['device_token'] ) ) {
                        Log::error( "Usuário {$user->name} enviou device_token inválido: {$params['device_token']}" );
                        $user->device_token = null;
                    } else {
                        // Blacklist
                        $blacklisted = TokenBlackList::where( 'device_token', $params['device_token'] )->first();

                        if ( $blacklisted ) {
                            // Setar attempt e Logar
                            Log::info( "Segurança: Usuário: {$user->name}, id {$user->id} tentou enviar um device_token listado como ilegal" );

                            $blacklisted->attempts += 1;
                            $blacklisted->save();

                            // Bloquear usuário
                            $user->is_aprovado = 0;
                            $user->save();

                            // Bloqueia o usuário (faz o aparelho pedir login/senha)
                            return $this->badRequest( ['success'=>false,'msg' => trans( 'messages.error.forbidden' ), 'errors'=>[]], 403 );
                        }
                        $user->device_token = $params['device_token'];
                    }
                }

                $user->last_seen = Carbon::now();
                $user->save();

                $config_percent    = Config::find(1);
                $user->fipePercent = $config_percent->percent;

                $user_type   = UserType::find( $user->user_type );
                $user->type  = ( $user_type ? $user_type->toArray() : ['id' => 0, 'name' => 'Não Informado'] );
                $user->token = $token;

                $stores = [];
                foreach ( $user->stores()->where( 'store_user.status', 1 )->get() as $_store ) {
                    $stores[] = [
                        'id'           => $_store->id,
                        'company_name' => $_store->company_name,
                        'trade_name'   => $_store->trade_name,
                        'cnpj'         => $_store->cnpj,
                        'city'         => isset($_store->city) ? $_store->city->name : null,
                        'neighborhood' => $_store->neighborhood,
                        'street'       => $_store->street,
                        'number'       => $_store->number,
                        'complement'   => $_store->complement,
                        'landmark'     => $_store->landmark,
                        'zipcode'      => $_store->zipcode,
                        'have_plan'    => (bool)$_store->plans()->where( 'plan_store.status', 1 )->first()
                    ];
                }

                $user->stores = $stores;
                $user->roles  = $user->roles;

                return array( 'success' => true, 'data' => $user );

            } else {
                return $this->badRequest( ['success'=>false, 'msg' => trans( 'messages.error.user.pending' ), 'errors'=>[]], 403 );
            }

            // @codeCoverageIgnoreStart
        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['message'=>$e->getMessage()] , 500 );
        }
    }
    // @codeCoverageIgnoreEnd

    /**
    * @SWG\Get(path="/refresh",
    *   tags={"User"},
    *   summary="Refresh Token",
    *   description="",
    *   operationId="refreshToken",
    *   produces={"application/json"},
    *   @SWG\Response( response=200, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="token", type="integer", description="422" ),
    *       )
    *   ),
    *   @SWG\Response( response=422, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="status_code", type="integer", description="200" ),
    *           @SWG\Property( property="message", type="string", description="Token inválido" ),
    *       )
    *   )
    * )
    **/
    public function refresh()
    {
        $token = JWTAuth::getToken();

        if( !$token ){
            $this->badRequest( ['success'=>false, 'msg'=>trans( 'messages.error.token.not_provided' ), 'errors'=>[]], 400 );
        }
        try {
            $token = JWTAuth::refresh( $token );
        } catch ( Exception $e ) {
            $this->badRequest( ['success'=>false, 'msg'=>trans( 'messages.error.token.invalid' ), 'errors'=>[]], 400 );
        }

        return $this->ApiResponse( ['success'=>true, 'data'=>compact( 'token' )], 200 );
    }


    public function getUserTypes()
    {
        $user_types = UserType::orderBy('order')->get(['id', 'name']);
        return ['success' => true, 'data' => $user_types];
    }


    /**
     * function getUser
     * @param null $user_id
     * @return array|Response
     */
    public function getUser($user_id = null)
    {

        $response = new Response();

        if ($user_id === null) {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Parâmetro não informado']);
            return $response;
        }

        $user = $this->user->findOrFail($user_id);

        $user_type = UserType::find($user['user_type']);
        $user->type = ($user_type ? $user_type->toArray() : ['id' => 0, 'name' => 'Não Informado']);

        $stores = [];
        foreach ( $user->stores()->where( 'store_user.status', 1 )->get() as $_store ) {
            $stores[] = [
                'id'           => $_store->id,
                'company_name' => $_store->company_name,
                'trade_name'   => $_store->trade_name,
                'cnpj'         => $_store->cnpj,
                'city'         => isset($_store->city) ? $_store->city->name : null,
                'neighborhood' => $_store->neighborhood,
                'street'       => $_store->street,
                'number'       => $_store->number,
                'complement'   => $_store->complement,
                'landmark'     => $_store->landmark,
                'zipcode'      => $_store->zipcode,
                'have_plan'    => (bool)$_store->plans()->where( 'plan_store.status', 1 )->first()
            ];
        }

        $user->stores = $stores;
        $user->roles  = $user->roles;


        return ['success' => true, 'data' => $user];

    }

     /**
    * @SWG\Post(path="/user/search",
    *    tags={"User"}, summary="Authenticate User", description="", operationId="authenticateUser", produces={"application/json"},
    *    @SWG\Parameter( name="field", in="formData", required=true, type="string", description="Valores aceitos: document, email | o campo document pode ser CPF ou CNPJ" ),
    *    @SWG\Parameter( name="value", in="formData", description="", required=true, type="string" ),
    *    @SWG\Response( response=200, description="", @SWG\Schema( ref="#/definitions/User" ) ),
    *    @SWG\Response( response=400, description="", @SWG\Schema( @SWG\Property( property="error", type="string", description="Bad Request") ) ),
    *    @SWG\Response( response=401, description="", @SWG\Schema(
    *            @SWG\Property( property="error", type="string", description="Invalid credentials" )
    *        )
    *    ),
    *    @SWG\Response( response=404, description="", @SWG\Schema(
    *            @SWG\Property( property="message", type="string", description="Model not found " ),
    *        )
    *    ),
    *    @SWG\Response( response=422, description="", @SWG\Schema(
    *            @SWG\Property( property="message", type="string", description="Validation failed" ),
    *            @SWG\Property( property="errors", type="array",
    *                @SWG\Items( type="object",
    *                    @SWG\Property(property="field", type="string"),
    *                )
    *            )
    *        )
    *    )
    * )
    */
    public function search( SearchRequest $request )
    {
        try {
            $fields = $request->all();

            if ( !$user = User::where( $fields['field'], $fields['value'] )->first() ) {
                return $this->modelNotFound( ['success'=>false, 'msg'=>trans( 'messages.error.notfound' ), 'errors'=>[]] );
            }

            return ( new UserSearchTransformer )->transform( $user );
        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['message'=>$e->getMessage()] , 500 );
        }
    }

    /**
    * @SWG\Get(path="/user/{user_id}/cars",
    *   tags={"User"},
    *   summary="List All Cars by user",
    *   description="",
    *   operationId="listAllCarsByUser",
    *   produces={"application/json"},
    *   @SWG\Parameter( in="header", name="Authorization", description="Basic Auth", required=true, type="string" ),
    *   @SWG\Parameter( in="path", name="user_id", description="", required=true, type="integer" ),
    *   @SWG\Parameter( in="query", name="current_page", description="Default: 1", required=false, type="integer" ),
    *   @SWG\Parameter( in="query", name="order", description="ASC or DESC | Default: ASC", required=false, type="string" ),
    *   @SWG\Parameter( in="query", name="order_by", description="options: id,created_at,price and year | Default:ID", required=false, type="string" ),
    *   @SWG\Response( response=200, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="status_code", type="integer", description="200" ),
    *           @SWG\Property( property="data", type="array",
    *               @SWG\Items( type="object",
    *                   @SWG\Property(property="totals", type="integer"),
    *                   @SWG\Property(property="per_page", type="integer"),
    *                   @SWG\Property(property="current_page", type="integer"),
    *                   @SWG\Property(property="items", type="array", @SWG\Items(
    *                       type="object", ref="#/definitions/CarTransformer"
    *                   ))
    *               )
    *           ),
    *       )
    *   ),
    *   @SWG\Response( response=400, description="",
    *       @SWG\Schema(
    *           @SWG\Property( property="error", type="string", description="Bad Request" )
    *       )
    *   )
    * )
    */
    public function getCarsByUser( Request $request, $user_id )
    {
        try {
            if ( !$user = User::where( 'id', $user_id )->first() ) {
                return $this->modelNotFound( ['success'=>false, 'msg'=>trans( 'messages.error.notfound' ), 'errors'=>[]] );
            }

            $per_page      = $request->input('per_page') ? $request->input('per_page') : 10;
            $current_page  = $request->input('current_page') ? $request->input('current_page') : 1;
            $order_by      = $request->input('order_by') ? $request->input('order_by') : 'id';
            $order         = $request->input('order') ? $request->input('order') : 'DESC';

            Paginator::currentPageResolver( function() use ( $current_page ) {
                return $current_page;
            });

            $cars = $user->anuncios()->orderBy( $order_by, $order )->paginate( $per_page );

            return ( new CarTransformer )->transformCollection( $cars );
        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['message'=>$e->getMessage()] , 500 );
        }
    }

    /**
     * function registerUser
     * @return array|Response|JsonResponse
     */
    public function registerUser( CreateRequest $request )
    {
        try {
            $fields    = $request->all();
            $blacklist = new Blacklist();
            $response  = new Response();

            if ( $blacklist->check('document',
                    $this->request->get('document')) || $blacklist->phoneCheck($this->request->get('phone'),
                    $this->request->get('cell_phone'))) {
                Log::error("Sistema de segurança Usuário {$this->request->get('name')} tentou acessar o sistema usando um dado que está na blacklist",
                    $this->request->all());
                return $this->badRequest( ['success'=>false,'msg'=>trans( 'messages.error.forbidden' ), 'errors'=>[]] , 401 );
            }

            /** @noinspection StaticInvocationViaThisInspection */
            $user = $this->user->fill( $this->request->all() );

            $user->photo       = $this->request->input( 'filename' );
            $user->role_id     = 2;
            // $user->is_aprovado = 1; // REP-197 - solicitação do junior liberar todos os usuários automaticamente
            $user->is_aprovado = UserType::findOrFail($request->get('user_type'))->create_status;
            $user->chat_token  = uuidv4();
            $user->email_token = uuidv4();

            if ( in_array( $fields['user_type'], [
                UserType::LOJISTA,
                UserType::CONCESSIONARIA,
                UserType::LOCADORA] ) ) {
                $user->dealership = $fields['dealership_trade_name'];
            } else {
                $user->dealership = $fields['name'];
            }

            if ( $user->save() ) {
                $UserAgreement = new UserAgreement();
                $UserAgreement->user_id = $user->id;
                $UserAgreement->version = config( 'user.agreement_version' );
                $UserAgreement->save();

                $userdata = array(
                    'email'    => $this->request->input('email'),
                    'password' => $this->request->input('password')
                );

                if ( Auth::attempt( $userdata ) ) {
                    $user = Auth::user();
                    $link = route( 'user.confirm', ['token' => $user->email_token] );

                    // Salva o e-mail na fila (envio em 1 minuto)
                    $job = ( new SendWelcomeEmail( $user, $this->request->input( 'password' ), $link ) )->onQueue( 'emails' );
                    $this->dispatch( $job );

                    $response->setContent( ['success' => true, 'data' => $user] );

                    if ( in_array( $fields['user_type'], UserType::PROFISSIONAIS ) ) {
                        // passar o endereço da loja para a tabela user
                        $user->zipcode = $request->get('dealership_zipcode');
                        $user->address = $request->get('dealership_street');
                        $user->number = $request->get('dealership_number');
                        $user->neighborhood = $request->get('dealership_neighborhood');
                        $city = City::find($request->get('dealership_city_id'));
                        if ($city) {
                            $user->city = $city->name;
                            $user->state = $city->state->initials;
                        }
                        $user->save();

                        $store_data = [];
                        foreach ( $fields as $key => $value ) {
                            $new_key = str_replace( 'dealership_', '', $key );
                            $store_data[$new_key] = $value;
                        }

                        $store = Store::create( array_merge( $store_data, ['user_id'=>$user->id] ) );

                        $role_chief    = Role::where( 'name', 'chief' )->first();
                        $role_business = Role::where( 'name', 'business' )->first();

                        $store->staff()->attach( $user->id, ['role_id' => 2, 'status'=>1] );
                        $user->roles()->attach( $role_chief->id );
                        $user->roles()->attach( $role_business->id );

                        // $store->plans()->attach( $fields['plan_id'], ['status'=>0] );
                    } else {

                        $role_individual = Role::where( 'name', 'individual' )->first();
                        $role_sales = Role::where('name', 'salesman')->first();
                        $user->roles()->attach( $role_individual->id );
                        $user->roles()->attach($role_sales->id);

                        // Incluir o usuário na loja de acordo com o tipo
                        switch($fields['user_type']) {
                            // Particular
                            case 3:
                                $loja = Store::where('cnpj', '33333333333333')->first();
                                break;
                            case 4:
                                $loja = Store::where('cnpj', '44444444444444')->first();
                                break;
                        }
                        $loja->staff()->attach($user->id, ['role_id' => $role_sales->id, 'status' => 1]);
                    }

                    if (!empty($user->address)) {
                        $jobGeolocation = ( new GeolocationJob( $user ) )->onQueue( 'geolocation' );
                        $this->dispatch( $jobGeolocation );
                    }

                    // A tarefa do podio fica aqui para contemplar a alteração do status do usuário.

                    $podio = ( new NewUserPodioJob( $user ) )->onQueue( 'push' );
                    $this->dispatch( $podio );


                    return $response;
                }
            }
            // @codeCoverageIgnoreStart
        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['message'=>$e->getMessage()] , 500 );

        }
    }
    // @codeCoverageIgnoreEnd

    /**
    * @SWG\Get(path="/check-exist-field",
    *    tags={"User"}, summary="Verifica se um determinado valor está em uso por algum usuário", description="", operationId="existUserByField", produces={"application/json"},
    *    @SWG\Parameter( name="field", in="formData", required=true, type="string", description="Opções: cpf, email e phone" ),
    *    @SWG\Parameter( name="value", in="formData", description="", required=true, type="string" ),
    *    @SWG\Response( response=200, description="", @SWG\Schema( ref="#/definitions/User" ) ),
    *    @SWG\Response( response=400, description="", @SWG\Schema( @SWG\Property( property="error", type="string", description="Bad Request") ) ),
    *    @SWG\Response( response=401, description="", @SWG\Schema(
    *            @SWG\Property( property="error", type="string", description="Invalid credentials" )
    *        )
    *    ),
    *    @SWG\Response( response=404, description="", @SWG\Schema(
    *            @SWG\Property( property="message", type="string", description="Model not found " ),
    *        )
    *    ),
    *    @SWG\Response( response=422, description="", @SWG\Schema(
    *            @SWG\Property( property="message", type="string", description="Validation failed" ),
    *            @SWG\Property( property="errors", type="array",
    *                @SWG\Items( type="object",
    *                    @SWG\Property(property="field", type="string"),
    *                )
    *            )
    *        )
    *    )
    * )
    */
    public function checkExistField( CheckFieldRequest $request )
    {
        try {
            $field = $request->input( 'field' ) == 'cpf' ? 'document' : $request->input( 'field' );
            $value = $request->input( 'value' );

            return $this->ApiResponse( ['success'=>true, 'data'=>['exist'=>(bool)User::where( $field, $value )->count()]] );
        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['message'=>$e->getMessage()] , 500 );
        }
    }

    /**
     * function updateUser
     * @return array|Response
     */
    public function updateUser()
    {
        try {
            $response = new Response();

            $validation = Validator::make(
                $this->request->all(),
                [
                    'dealership' => ['required'],
                    'name' => ['required'],
                    'zipcode' => ['required'],
                    'state' => ['required'],
                    'city' => ['required'],
                    'cell_phone' => ['required']
                ],
                [
                    'required' => 'O campo não foi preenchido'
                ]
            );

            if ( $validation->fails() ) {
                $response->setStatusCode( 400 );
                $response->setContent( ['success' => false, 'msg' => $validation->messages()] );
                return $response;
            }

            $fields = $this->request->all();

            /* Alterado para editar a loja somente nos casos que possuem loja (lojista, repassador, concessionária) */
            if ( isset( $fields['store_id'] ) && in_array($this->auth->user_type, [1,2,5,6]) ) {
                $store = Store::find( $fields['store_id'] );

                $store_data = [];
                foreach ( $fields as $key => $value ) {
                    $new_key = str_replace( 'dealership_', '', $key );
                    $store_data[$new_key] = $value;
                }

                $store->fill( $store_data )->save();

                if ( isset( $fields['plan_id'] ) ) {
                    $store->plans()->detach();
                    $store->plans()->attach( $fields['plan_id'], ['status'=>1] );
                }
            }


            $userData = $this->user->find($this->auth->id)->update($this->request->all());

            if ( $userData ) {
                $userUpdate = $this->user->find($this->auth->id);

                if ( $userUpdate->save() ) {

                    $jobGeolocation = (new GeolocationJob($userUpdate))->onQueue('geolocation');
                    $this->dispatch($jobGeolocation);

                    $podioJob = (new EditUserPodioJob($userUpdate, $userUpdate))->onQueue('push');
                    $this->dispatch($podioJob);

                    return ['success' => true, 'data' => $userUpdate];
                } else {
                    $response->setStatusCode(500);
                    $response->setContent(['success' => false, 'msg' => 'Não foi possível atualizar seu usuário']);
                    return $response;
                }

            } else {
                $response->setStatusCode(500);
                $response->setContent(['success' => false, 'msg' => 'Não foi possível atualizar seu usuário']);
                return $response;
            }
        } catch ( \Exception $e ) {
            \Sentry::captureException($e);
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
            return $this->badRequest( ['message'=>$e->getMessage()] , 500 );
        }
    }

    public function updateToken()
    {
        $response = new Response();
        $params = $this->request->all();

        if (!array_key_exists('device_token', $params)) {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Faltam parâmetros para concluir a operação']);
            return $response;
        }

        $users = User::where('role_id', 2)->where('device_token', $params['device_token'])->get();

        foreach ($users as $user) {
            $user->device_token = null;
            $user->save();
        }

        $user = User::find($this->auth->id);

        if (!isUuid($params['device_token'])) {
            Log::error("Usuário {$this->auth->name} enviou device_token inválido: {$params['device_token']}");
            $user->device_token = null;
        } else {
            /*
             * Blacklist
             */
            $blacklisted = TokenBlackList::where('device_token', $params['device_token'])->first();

            if ($blacklisted) {
                // Setar attempt e Logar
                Log::info("Segurança: Usuário: {$user->name}, id {$user->id} tentou enviar um device_token listado como ilegal");
                $blacklisted->attempts += 1;
                $blacklisted->save();

                // Bloquear usuário
                $user->is_aprovado = 0;
                $user->save();
                // Bloqueia o usuário (faz o aparelho pedir login/senha)
                $response = new Response();
                $response->setStatusCode(403);
                $response->setContent(['success' => false, 'msg' => 'Acesso Negado']);
                return $response;
            } else {
                $user->device_token = $params['device_token'];
            }

        }

        if ($user->save()) {

            $user_type = UserType::find($user->user_type);
            $user->type = ($user_type ? $user_type->toArray() : ['id' => 0, 'name' => 'Não Informado']);
            return array('success' => true, 'data' => $user);
        } else {
            $response->setStatusCode(500);
            $response->setContent(['success' => false, 'msg' => 'Falha ao atualizar token']);
            return $response;
        }
    }

    public function userUploadImage(Request $request)
    {
        Log::debug('Inicio do processo de envio de imagem');

        $response = new Response();

        if ($request->hasFile('filename') AND $request->file('filename')->isValid()) {
            $mimes = array('image/jpeg' => 'jpg', 'image/png' => 'png');
            $file = $request->file('filename');
            $extension = $file->getClientOriginalExtension();
            $fileMime = $file->getClientMimeType();
            if (in_array($fileMime, array_keys($mimes))) {
                $filename = uniqid() . time() . '.' . $extension;
                $image = Image::make(File::get($file))->orientate();
                $image->fit(500, 500);
                Storage::disk('user-avatar')->put($filename, $image->stream());
                $image->destroy();

                return ['success' => true, 'filename' => $filename];

            } else {
                $response->setStatusCode(400);
                $response->setContent(['success' => false, 'msg' => 'Tipo de arquivo inválido']);
                return $response;
            }

        } else {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Arquivo não enviado ou conteúdo inválido']);
            return $response;
        }

    }

    public function updateAvatar()
    {
        $response = new Response();
        // Procura foto original (salva a variável)
        $userData = $this->user->find($this->auth->id);
        Log::info($userData->defaultPhoto);
        $oldPhoto = ($userData->photo === $userData->defaultPhoto) ? false : $userData->photo;
        // Salva a foto nova (salva o nome do arquivo)
        if ($this->request->hasFile('filename') AND $this->request->file('filename')->isValid()) {
            $mimes = array('image/jpeg' => 'jpg', 'image/png' => 'png');
            /** @var UploadedFile $file */
            $file = $this->request->file('filename');
            $extension = $file->getClientOriginalExtension();
            $fileMime = $file->getClientMimeType();
            if (in_array($fileMime, array_keys($mimes))) {
                $filename = uniqid() . time() . '.' . $extension;
                $image = Image::make(File::get($file))->orientate();
                $image->fit(500, 500);
                Storage::disk('user-avatar')->put($filename, $image->stream());
                $image->destroy();
                // Atualiza no banco de dados
                $userData->photo = $filename;
                if ($userData->save()) {
                    // Remove arquivo físico anterior
                    // @TODO existe um caso específico em que o servidor não acha/não consegue apagar essa foto, refatorar pra checar se o arquivo existe antes de excluir
                    if ($oldPhoto && Storage::disk('user-avatar')->has($oldPhoto)) {
                        Storage::disk('user-avatar')->delete($oldPhoto);
                    }

                    return ['success' => true, 'filename' => $filename];
                } else {
                    $response->setStatusCode(500);
                    $response->setContent(['success' => false, 'msg' => 'Falha ao atualizar a imagem tente novamente']);
                    return $response;
                }
            } else {
                $response->setStatusCode(400);
                $response->setContent(['success' => false, 'msg' => 'Tipo de arquivo inválido']);
                return $response;
            }
        } else {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Arquivo não enviado ou conteúdo inválido']);
            return $response;
        }
    }

    public function updateCredentials()
    {
        $response = new Response();

        $user = $this->user->find($this->auth->id);

        if (!$user) {
            $response->setStatusCode(404);
            $response->setContent(['success' => false, 'msg' => 'Usuário não encontrado']);
            return $response;
        }

        //verificar e-mail duplicado
        $searchUser = $this->user->where('email', '=', $this->request->input('email'))->where('id', '<>',
            $this->auth->id)->get();
        if (isset($searchUser->id)) {
            $response->setStatusCode(409);
            $response->setContent(['success' => false, 'msg' => 'Este e-mail já está cadastrado']);
            return $response;
        }
        unset($searchUser);

        if ($this->request->input('email') != null) {
            $user->email = $this->request->input('email');
        }

        if ($this->request->input('password') != null) {
            $user->password = $this->request->input('password');
        }


        if ($user->save()) {

            $podioJob = (new EditUserPodioJob($user, $this->auth))->onQueue('push');
            $this->dispatch($podioJob);

            return ['success' => true, 'data' => $user];
        } else {

            $response->setStatusCode(500);
            $response->setContent(['success' => false, 'msg' => 'Falha ao atualizar dados']);

            return $response;
        }



    }

    public function setUserType()
    {

        $response = new Response();
        // Se user_type diferente de zero recusa

        if ($this->auth->user_type !== 0) {
            $response->setStatusCode(403);
            $response->setContent(['success' => false, 'msg' => 'Usuário não pode alterar o próprio tipo']);
            return $response;
        }
        $user = $this->user->find($this->auth->id);
        // Informar o tipo do usuário
        $user->user_type = $this->request->input('user_type');

        if ($user->save()) {

            $jobGeolocation = (new GeolocationJob($user))->onQueue('geolocation');
            $this->dispatch($jobGeolocation);

            $podioJob = (new EditUserPodioJob($user, $this->auth))->onQueue('push');
            $this->dispatch($podioJob);

            $response->setStatusCode(200);
            $response->setContent(['success' => true, 'data' => $user]);

            return $response;

        } else {
            $response->setStatusCode(500);
            $response->setContent(['success' => false, 'msg' => 'Falha ao atualizar o usuário']);
            return $response;
        }

    }

    public function adminLogin(Request $request)
    {
        $response = new Response();

        $email = $request->get('email');
        $password = $request->get('password');
        $device_token = $request->get('device_token');

        if ( !$token = JWTAuth::attempt( $request->only( 'email', 'password' ) ) ) {
            return $this->badRequest( ['success'=>false, 'msg' => trans( 'messages.error.unauthorized' ), 'errors'=>[]], 401 );
        }

        if (($email !== null) && ($password !== null)) {
            $userdata = array(
                'email' => $email,
                'password' => $password
            );


            if (Auth::attempt($userdata)) {
                // Salva device_token
                $user = Auth::user();
                $user->device_token = $device_token;
                $user->save();
                $user->token = $token;
                //
                return ['success', 'data' => ['user' => $user]];
            } else {
                $response->setStatusCode(403);
                $response->setContent(['success' => false, 'msg' => 'Falha na autenticação']);
                return $response;
            }
        } else {
            $response->setStatusCode(400);
            $response->setContent(['success' => false, 'msg' => 'Faltam parâmetros para o login']);
            return $response;
        }
    }

    /**
     * @SWG\Get(path="/user/terms",
     *    tags={"User"}, summary="Check User Status (terms and plans)", description="", operationId="checkTermsAndPlan", produces={"application/json"},
     *    @SWG\Response( response=200, description="", @SWG\Schema( ref="#/definitions/Plan" ) ),
     *    @SWG\Response( response=400, description="", @SWG\Schema( @SWG\Property( property="error", type="string", description="Bad Request") ) ),
     *    @SWG\Response( response=401, description="", @SWG\Schema(
     *            @SWG\Property( property="error", type="string", description="Invalid credentials" )
     *        )
     *    ),
     *    @SWG\Response( response=404, description="", @SWG\Schema(
     *            @SWG\Property( property="message", type="string", description="Model not found " ),
     *        )
     *    ),
     *    @SWG\Response( response=422, description="", @SWG\Schema(
     *            @SWG\Property( property="message", type="string", description="Validation failed" ),
     *            @SWG\Property( property="errors", type="array",
     *                @SWG\Items( type="object",
     *                    @SWG\Property(property="field", type="string"),
     *                )
     *            )
     *        )
     *    )
     * )
     * Verifica se o usuário aceitou os termos atuais
     * @param UserAgreement $agreement
     * @return array
     */
    public function getTermsStatus(UserAgreement $agreement)
    {
        /** @var User $user */
        $user = $this->auth;

        // Listagem de planos
        $plans = null;


       if (!$user->is_testing && $user->hasRole('chief') && $user->hasRole('business')) {
           $store = $user->stores()->where( 'store_user.role_id', 2 )->first();
           $plan = (bool)$store->plans()->where('plan_store.status', 1)->first();
           $plans = Plan::all();
        } else {
            $plan = false;
        }

       //comentado temporariamente pelo erro dos termos no ios
        /*$accepted = $agreement->where('user_id', $user->id)->where('version',
            config('user.agreement_version'))->first();

        if ($accepted) {
            $terms = true;
        } else {
            $terms = false;
        }*/

        return ['success' => true, 'terms' => true, 'plan' => $plan, 'plans' => $plans];

    }


    /**
     * Aceita os termos atuais
     * @SWG\Post(path="/user/terms/accept",
     *    tags={"Plan"}, summary="Aceita os termos de uso e seleciona um plano", description="", operationId="acceptTerms", produces={"application/json"},
     *    @SWG\Parameter( in="header", name="Authorization", description="Basic Auth", required=true, type="string" ),
     *    @SWG\Parameter( name="plan_id", in="formData", description="", required=false, type="integer" ),
     *    @SWG\Response( response=200, description=""),
     *    @SWG\Response( response=400, description="", @SWG\Schema( @SWG\Property( property="error", type="string", description="Bad Request") ) ),
     *    @SWG\Response( response=401, description="", @SWG\Schema(
     *            @SWG\Property( property="error", type="string", description="Error message" )
     *        )
     *    ),
     *    @SWG\Response( response=404, description="", @SWG\Schema(
     *            @SWG\Property( property="message", type="string", description="Model not found " ),
     *        )
     *    ),
     *    @SWG\Response( response=422, description="", @SWG\Schema(
     *            @SWG\Property( property="message", type="string", description="Validation failed" ),
     *            @SWG\Property( property="errors", type="array",
     *                @SWG\Items( type="object",
     *                    @SWG\Property(property="field", type="string"),
     *                )
     *            ),
     *        )
     *    ),
     * )
     * @param UserAgreement $agreement
     * @return array
     */
    public function setTermsStatus(TermsRequest $request, UserAgreement $agreement): array
    {
        $user = $this->auth;

        if ($request->has('plan_id')) {
            $user_id = $user->id;
            $plan_id = $request->get('plan_id');

            if (in_array($user->user_type, [1, 2, 5, 6])) {
                // Check se usuário pertence a empresa
                $store = Store::where('user_id', $user_id)->first();

                // se não pertence: criar empresa e fazer o vínculo e vincular plano a empresa
                if (empty($store)) {
                    // Localizar cidade
                    $city = City::where('name', 'like', "%{$user->city}%")->first();

                    // Criar empresa
                    $store = Store::create([
                        'user_id' => $user->id,
                        'company_name' => $user->dealership,
                        'trade_name' => $user->dealership,
                        'cnpj' => $user->document,
                        'city_id' => !empty($city) ? $city->id : 999,
                        'neighborhood' => $user->neighborhood,
                        'street' => $user->address,
                        'number' => $user->number,
                        'status' => 1,
                        'zipcode' => $user->zipcode
                    ]);
                    // Vincular usuário a empresa
                    $role_chief = Role::where('name', 'chief')->first();
                    $role_business = Role::where('name', 'business')->first();

                    $store->staff()->attach($user->id, ['role_id' => 2, 'status' => 1]);
                    $user->roles()->attach($role_chief->id);
                    $user->roles()->attach($role_business->id);

                    $store->plans()->attach($plan_id, ['status' => 1]);
                } else {
                    $store->plans()->sync([1 => ['plan_id' => $plan_id, 'status' => 1]]);
                }

            } else {
                $role_individual = Role::where('name', 'individual')->first();
                $user->roles()->attach($role_individual->id);
            }
        }
        $agreement->create(['user_id' => $user->id, 'version' => config('user.agreement_version')]);
        return ['success' => true];
    }


    /**
     * Ativa o período de teste do usuário
     * @SWG\Put(path="/user/trial",
     *    tags={"User"}, summary="Ativa o período de teste do usuário", description="", operationId="setTrialStatus", produces={"application/json"},
     *    @SWG\Parameter( in="header", name="Authorization", description="Basic Auth", required=true, type="string" ),
     *    @SWG\Response( response=200, description="", @SWG\Schema( ref="#/definitions/User" ) ),
     *    @SWG\Response( response=400, description="", @SWG\Schema( @SWG\Property( property="error", type="string", description="Bad Request") ) ),
     *    @SWG\Response( response=401, description="", @SWG\Schema(
     *            @SWG\Property( property="error", type="string", description="Error message" )
     *        )
     *    ),
     * )

     * @return User
     */
    public function setTrialStatus()
    {
        $user = auth()->user();

        if ($user && (int)$user->is_testing !== 1) {
            // Usuário não está em trial e vamos aumentar o período em sete dias
            $user->is_testing = 1;
            $user->expires_at = Carbon::now()->addDays(7);
            $user->save();
        }
        return $user;
    }

}