<?php

namespace App\Core\Console;

use App\Core\Console\Commands\Ads\CheckAdStatus;
use App\Core\Console\Commands\Car\ExpireCarCommand;
use App\Core\Console\Commands\Fipe\UpdateFipeCommand;
use App\Core\Console\Commands\Mail\MonthlyStats;
use App\Core\Console\Commands\Podio\UpdateLastSeen;
use App\Core\Console\Commands\PushAllAntiFraud;
use App\Core\Console\Commands\PushAllCarQueryOffer;
use App\Core\Console\Commands\PushAllDennounce;
use App\Core\Console\Commands\PushAllShareApp;
use App\Core\Console\Commands\PushAllSignup;
use App\Core\Console\Commands\PushCloseAd;
use App\Core\Console\Commands\PushFinishSignup;
use App\Core\Console\Commands\PushLastSeen;
use App\Core\Console\Commands\PushNewSeller;
use App\Core\Console\Commands\PushOpenCartsCarQuery;
use App\Core\Console\Commands\PushOpenCartsTurbo;
use App\Core\Console\Commands\PushSellAgain;
use Illuminate\Console\Scheduling\Schedule;
use Illuminate\Foundation\Console\Kernel as ConsoleKernel;


class Kernel extends ConsoleKernel
{
    /**
     * The Artisan commands provided by your application.
     *
     * @var array
     */
    protected $commands = [
        \App\Core\Console\Commands\Inspire::class,
        \App\Core\Console\Commands\ChatServer::class,
        \App\Core\Console\Commands\SendChatMessages::class,
        \App\Core\Console\Commands\RemoverPatrocinioAnuncio::class,
        \App\Core\Console\Commands\PushAllTurboOffer::class,
        PushAllDennounce::class,
        PushAllAntiFraud::class,
        PushAllShareApp::class,
        PushCloseAd::class,
        PushSellAgain::class,
        PushLastSeen::class,
        PushFinishSignup::class,
        PushNewSeller::class,
        PushAllSignup::class,
        CheckAdStatus::class,
        PushAllCarQueryOffer::class,
        UpdateLastSeen::class,
        MonthlyStats::class,
        ExpireCarCommand::class,
        PushOpenCartsCarQuery::class,
        PushOpenCartsTurbo::class,
        UpdateFipeCommand::class
    ];

    /**
     * Define the application's command schedule.
     *
     * @param  \Illuminate\Console\Scheduling\Schedule $schedule
     * @return void
     */
    protected function schedule(Schedule $schedule)
    {

        $schedule->command('turbo:remove')->hourly();

        /*
         * Push notification automatizados
         */
        $schedule->command('push:lastseen')->daily()->at('11:00');
        $schedule->command('push:closead')->daily()->at('16:00');
        $schedule->command('push:sellagain')->daily()->at('13:00');
        $schedule->command('push:newseller')->daily()->at('13:00');
        $schedule->command('push:turbo')->weekly()->mondays()->at('12:00');
        $schedule->command('push:shareapp')->weekly()->saturdays()->at('12:00');
        $schedule->command('push:dennounce')->weekly()->thursdays()->at('20:00');
        $schedule->command('push:antifraud')->weekly()->fridays()->at('19:00');
        $schedule->command('push:finishsignup')->weekly()->mondays()->at('15:00');
        $schedule->command('push:finishsignup')->weekly()->thursdays()->at('15:00');
        $schedule->command('push:carquery')->weekly()->tuesdays()->at('10:00');
        $schedule->command('push:signup')->cron('0 10 */2 * * ');
        $schedule->command('ads:check')->hourly();
        $schedule->command('podio:lastseen')->hourly();
        $schedule->command('push:opencartcarquery')->daily()->at('10:20');
        $schedule->command('push:opencartturbo')->daily()->at('10:40');
        $schedule->command('mail:userstats')->monthlyOn(5, '08:00');

    }
}
