<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 04/01/2019
 * Time: 12:09
 */

namespace App\Core\Jobs;


use App\Auth\Models\User;
use App\Repasse\Integration\Podio\Models\UserFields;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Repasse\LaravelPodio\Services\PodioService;

class EditUserPodioJob extends Job implements ShouldQueue
{
    use SerializesModels, InteractsWithQueue, DispatchesJobs;

    /** @var User $user */
    protected $user;

    protected $requestUser;

    public function __construct(User $user, $requestUser)
    {
        $this->user = $user;

        $this->requestUser = $requestUser;
    }

    public function handle(PodioService $podioService)
    {

        $appUser = $podioService->getApp('Usuários');

        // Autenticar com o app publicações,
        // $podioService->authenticateWithApp('Publicações');

        if (!$podioService->isAuthenticated()) {
            $podioService->authenticateWithPassword();
        }

        // checar se o user tem podio_id senão pesquisa etc
        if ($this->user->podio_id === null) {
            $user = \PodioItem::filter($appUser['id'], [
                'limit' => 1,
                'filters' => [
                    'id-usuario-2' => [
                        'from' => (int)$this->user->id,
                        'to' => (int)$this->user->id
                    ]
                ]
            ]);

            if ($user[0]) {
                $this->user->podio_id = $user[0]->item_id;
                $this->user->save();
            } else {
                $podioJob = (new NewUserPodioJob($this->user))->onQueue('push');
                $this->dispatch($podioJob);

                // Release job to queue
                $this->release(20);
            }
        }

        // pegar o array que vai pro podio
        $userFields = new UserFields($this->user);
        $fields = $userFields->toPodio();

        // chamar a função update

        $update = \PodioItem::update($this->user->podio_id, $fields);
        //  @TODO aqui vai o podio comment do item editado
        if (!empty($this->requestUser)) {
            \PodioComment::create('item', $this->user->podio_id, [
                'value' => "Alteração enviada por id: {$this->requestUser->id} email: {$this->requestUser->email}"
            ]);
        }

    }

    public function failed()
    {
        \Mail::raw('tarefa falhou', function ($m) {

            $m->to('rafael.barreto@gruporepasse.com.br', 'rafael barreto')->subject('Tarefa falhou!');
        });
    }

}