<?php

namespace App\Core\Jobs;

use App\Admin\Dashboard\Models\CarIncident;
use App\Auth\Models\User;
use App\Core\Jobs\Job;
use App\Push\PushNotification;
use Illuminate\Queue\SerializesModels;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Config;
use Log;

class SendPushDenunciaAdmin extends Job implements SelfHandling, ShouldQueue
{
    use InteractsWithQueue, SerializesModels;


    protected $admins;
    protected $push;
    protected $carIncident;

    /**
     * Create a new job instance.
     *
     * @param User $user
     * @param PushNotificationJob $push
     * @param CarIncident $carIncident
     */
    public function __construct($admins, PushNotification $push, $carIncident)
    {
        //
        $this->admins = $admins;
        $this->push = $push;
        $this->carIncident = $carIncident;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        //
        $parameters = [
            'include_player_ids' => [],
            'headings' => [
                'en' => 'Chegou uma nova denúncia para análise'
            ],
            'contents' => [
                'en' => "Existem {$this->carIncident} denúncias não analisadas no momento"
            ],
            'android_group' => 2,
            'android_group_message' => [
                'en' => '$[notif_count] novas denúncia'
            ],
            'small_icon' => 'repasse_small_icon_white',
            'large_icon' => 'repasse_icon',
            'data' => ['denuncia' => true]
        ];

        foreach ($this->admins as $admin) {
            if (  isUuid($admin->device_token)) {
                $parameters['include_player_ids'][] = $admin->device_token;
            }
        }

        $this->push->sendCustom($parameters);

    }
}
