<?php

namespace App\Core\Jobs\Store;

use App\Core\Jobs\Job;
use App\Auth\Models\User;
use Illuminate\Queue\SerializesModels;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Contracts\Bus\SelfHandling;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Support\Facades\Mail;

class SendEmailRegisterStaffJob extends Job implements SelfHandling, ShouldQueue
{

    use InteractsWithQueue, SerializesModels;


    private $user;
    private $store;
    private $role;

    /**
     * Create a new job instance.
     *
     * @param $user User
     * @param $password string
     * @param $link string
     */
    public function __construct( $user, $store, $role )
    {
        $this->user  = $user;
        $this->store = $store;
        $this->role  = $role;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle( Mail $mail )
    {
        $mail::send( 'emails.store.register_staff', [
            'user'  => $this->user,
            'store' => $this->store,
            'role'  => $this->role,
        ], function( $message ) {
            $message->to( $this->user->email, $this->user->name )->subject( $this->user->name . ', você agora é ' . $this->role->display_name . ' na ' . $this->store->company_name );
        });

    }
}
