<?php

namespace App\Http\Requests\Checkout;

use App\Http\Requests\Request;

class CheckoutRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return auth()->check();
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'product_id'             => 'required|exists:products,id',
            'license_plate'          => 'required|max:7|min:7',
            'dob'                    => 'required|date_format:"Y-m-d"',
            'credit_card_number'     => 'required|ccn',
            'credit_card_date'       => 'required|ccd|date_format:"d/y"',
            'credit_validation_code' => 'required|cvc',
        ];
    }

    public function messages()
    {
        return [
            'credit_card_date.ccd'   => 'data de validade inválida',
            'credit_card_number.ccn' => 'número de cartão inválido',
        ];
    }
}
