<?php

namespace App\Http\Requests\User;

use App\Http\Requests\Request;

class CreateRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'user_type'               => 'required|in:1,2,3,4,5,6',
            'dealership_company_name' => 'required_if:user_type,1,2,5,6|max:255',
            'dealership_trade_name'   => 'required_if:user_type,1,2,5,6|max:255',
            'dealership_cnpj'         => 'required_if:user_type,1,2,5,6|max:255|unique:stores,cnpj',
            'dealership_city_id'      => 'required_if:user_type,1,2,5,6',
            'dealership_neighborhood' => 'required_if:user_type,1,2,5,6|max:255',
            'dealership_street'       => 'required_if:user_type,1,2,5,6|max:255',
            'dealership_number'       => 'required_if:user_type,1,5,6|max:255',
            'dealership_complement'   => 'max:255',
            'dealership_landmark'     => 'max:255',
            'dealership_zipcode'      => 'required_if:user_type,1,2,5,6|max:10',
            // 'plan_id'                 => 'required_if:user_type,1,2,5|exists:plans,id',
            'name'                    => 'required',
            'document'                => 'required_if:user_type,1,2,5,6',
            'email'                   => 'required|email|unique:user,email',
            'zipcode'                 => 'required_if:user_type,3,4|max:10',
            'state'                   => 'required_if:user_type,3,4',
            'city'                    => 'required_if:user_type,3,4',
            'cell_phone'              => 'required',
            'password'                => 'required'
        ];
    }

    public function messages()
    {
        return [
            'dealership_cnpj.unique' => 'O Documento informado já está em uso.'
        ];
    }
}
