<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 13/02/2017
 * Time: 16:26
 */

namespace App\Repasse\Audit;


class Edits {
    protected $new;
    protected $edit;

    public function __construct($car, $edit) {
        $this->new = $car;
        $this->edit = $edit;
        $this->old = unserialize($edit->car_object);
    }

    private function hasChanged($field) {
        $new = $this->new->{$field} ?? 0;
        $old = $this->old->{$field} ?? 0;
        //return  $this->new->{$field} !== $this->old->{$field};
        return $new !== $old;
    }

    private function makeEditArray($field, $label) {
        return ['label' => $label, 'is_edited' => $this->hasChanged($field), 'new' => $this->new->{$field}, 'old' => $this->old->{$field}];
    }

    private function makeColorEdit() {
        return ['label' => 'cor', 'is_edited' => $this->hasChanged('color_id'), 'new' => $this->new->color->name, 'old' => $this->old->color->name];
    }

    private function makeOptionalEdit() {
        $hasChanged = $this->hasChanged('array_optionals');
        $old = [];
        $new = [];
        foreach ($this->old->optionals as $opt) {
            $old[] = $opt['name'];
        }
        foreach ($this->new->optionals as $opt) {
            $new[] = $opt['name'];
        }
        return [
            'label' => 'Opcionais',
            'is_edited' => $hasChanged,
            'new' => implode(',', $new),
            'old' => implode(',', $old)
        ];
    }

    private function makePriceArray() {
        return [
            'label' => 'Valor',
            'is_edited' => $this->hasChanged('price'),
            'new' => 'R$ ' . number_format($this->new->price, 2, ',', '.'),
            'old' => 'R$ ' . number_format($this->old->price, 2, ',', '.')
        ];
    }

    private function makeCostArray() {
        return [
            'label' => 'Custo',
            'is_edited' => $this->hasChanged('cost'),
            'new' => 'R$ ' . (isset($this->new->cost) ? number_format($this->new->cost, 2, ',', '.') : 'Não informado'),
            'old' => 'R$ ' . (isset($this->old->cost) ? number_format($this->old->cost, 2, ',', '.') : 'Não informado')
        ];
    }

    private function makeFipePriceArray() {
        return [
            'label' => 'Valor da Fipe',
            'is_edited' => $this->hasChanged('fipe_price'),
            'new' => 'R$ ' . number_format($this->new->fipe_price, 2, ',', '.'),
            'old' => 'R$ ' . number_format($this->old->fipe_price, 2, ',', '.')
        ];
    }

    private function makePhotoArray() {
        $old = [];
        $new = [];
        foreach($this->old->photos as $photos) {
            $old[] = $photos['filename'];
        }

        foreach($this->new->photos as $photos) {
            $new[] = $photos['filename'];
        }

        $hasChanged = $old !== $new;

        return ['label' => 'Fotos', 'is_edited' => $hasChanged, 'old' => $old, 'new' => $new];
    }

    public function getEditArray() {
        $changes = [];
        $changes['price'] = $this->makePriceArray();
        $changes['cost']  = $this->makeCostArray();
        $changes['color'] = $this->makeColorEdit();
        $changes['doors'] = $this->makeEditArray('doors', 'portas');
        $changes['km'] = $this->makeEditArray('km', 'quilometragem');
        $changes['eixos'] = $this->makeEditArray('eixos', 'eixos');
        $changes['observation'] = $this->makeEditArray('observation', 'descrição');
        $changes['optionals'] = $this->makeOptionalEdit();
        $changes['fipe_price'] = $this->makeFipePriceArray();

        $photos = $this->makePhotoArray();

        return ['changes' => $changes, 'photos' => $photos];
    }





}