<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 27/09/2019
 * Time: 14:11
 */

namespace App\Repasse\Products\CarQuery;


use App\Admin\Dashboard\Models\CarQuery\CarQuery;
use GuzzleHttp\Client;
use Illuminate\Support\Facades\Storage;

class AutoCorp
{
    private $key;

    private $env;

    private $urls = [
        'dev' => 'https://api.autocorp.com.br/json/homologa.aspx',
        'prod' => 'https://api.autocorp.com.br/json/service.aspx'
    ];

    public function __construct($key, $env)
    {
        $this->key = $key;
        $this->env = $env;
    }

    public function getServiceUrl(): string
    {
        return $this->urls[$this->env];
    }

    /**
     * Esta função faz o download da consulta veicular (json) da empresa autocorp para o nosso banco
     * retorna o nome local do arquivo
     * @param CarQuery $autocorpCarQuery
     * @return CarQuery
     */
    public function getCarQueryData(CarQuery $autocorpCarQuery)
    {
        // em getServiceurl tem o endereço
        // na tabela tem license_plate e produto
        // lets resolver essa ansiedade e fazer esse download
        $url = $this->getServiceUrl();
        $params = [
            'CodigoProduto' => (string)"$autocorpCarQuery->product_id",
            'Versao'        => '20180521',
            'ChaveAcesso'   => "{$this->key}",
            'Parametros'    => [
                'Placa' => $autocorpCarQuery->license_plate
            ]
        ];

        $client = new Client();
        $req = $client->post($url, ['json' => $params]);
        $res = $req->getBody();
        // eu não preciso parsear o json///
        $autocorpCarQuery->fill(['response' => $res]);
        $autocorpCarQuery->save();
        $car_query = json_decode($res);
        // dd($car_query->HEADER->INFORMACOES_RETORNO->STATUS_RETORNO->CODIGO);

        if ($car_query->HEADER->INFORMACOES_RETORNO->STATUS_RETORNO->CODIGO === "1") {
            //  consulta ok, fazer o downlod do xml
            $reqxml = $client->get($car_query->HEADER->INFORMACOES_RETORNO->PDF);
            $resp = $reqxml->getBody();
            $autocorpCarQuery->xml = $resp;
            $autocorpCarQuery->save();
            // parse xml
            libxml_use_internal_errors(true);
            $xml = simplexml_load_string($resp);

            if ($xml !== false) {
                $pdf_url = (string)$xml->URL;
            } else {
                // Quer dizer então que tu não manda mais XML? Et tu brutus?
                $xml = json_decode($resp);
                $pdf_url = $xml->url;
            }

            $autocorpCarQuery->pdf = $pdf_url;
            $autocorpCarQuery->save();
            $putStream = tmpfile();
            $reqpdf = $client->get($pdf_url, ['sink' =>  $putStream]);
            rewind($putStream);
            //store
            $filename = uuidv4() . '.pdf';

            Storage::disk('carqueries')->put($filename, $putStream);
            //release tempfile
            fclose($putStream);
            $autocorpCarQuery->local_pdf = $filename;
            $autocorpCarQuery->save();
            return $autocorpCarQuery;
        }
    }

}