<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 23/09/2019
 * Time: 11:12
 */

namespace App\Repasse\Products\Order;


use App\Admin\Dashboard\Models\OrderItem\OrderItem;
use Artesaos\Moip\Facades\Moip;
use Illuminate\Support\Facades\DB;
use Moip\Resource\Orders;

class Order
{

    public function createOrder($data)
    {
        //
        // Com os dados criar order e order itens
        // Uma função auxiliar vai criar o pedido do moip, salvar neste order

        try {
            DB::beginTransaction();
            $order = \App\Admin\Dashboard\Models\Order\Order::create([
                'user_id' => $data->user->id,
                'total' => ($data->product->price / 100),
                'subtotal' => ($data->product->price / 100)
            ]);

            OrderItem::create([
                'order_id' => $order->id,
                'product_id' => $data->product->id,
                'price' => ($data->product->price / 100),
                'qty' => 1,
                'options' => json_encode($data->options)
            ]);
            DB::commit();

            return $order;

        } catch (\Exception $e) {
            DB::rollback();
            throw new \Exception('Falha ao criar pedido');
        }

    }

    public function createCheckoutLink(\App\Admin\Dashboard\Models\Order\Order $order): \App\Admin\Dashboard\Models\Order\Order
    {
        //
        $moip = Moip::start();
        $cliente = $moip->customers()->setOwnId($this->getClientId($order->user->id));
        $cliente->setFullname($order->user->name)->setEmail($order->user->email);

        if (!empty($order->user->document)) {
            $type = mb_strlen($order->user->document) === 11 ? 'CPF' : 'CNPJ';
            $cliente->setTaxDocument($order->user->document, $type);
        }

        if (!empty($order->user->cell_phone)) {
            $contryCode = 55;
            $areaCode = mb_substr($order->user->cell_phone, 0, 2);
            $number = mb_substr($order->user->cell_phone, 2);
            $cliente->setPhone($areaCode, $number, $contryCode);
        }

        $cliente->addAddress('BILLING', $order->user->address, $order->user->number, $order->user->neighborhood,
            $order->user->city, $order->user->state, $order->user->zipcode);
        $cliente->addAddress('SHIPPING', $order->user->address, $order->user->number, $order->user->neighborhood,
            $order->user->city, $order->user->state, $order->user->zipcode);

        /** @var Orders $moiporder */
        $moiporder = $moip->orders()->setOwnId($this->getOrderId($order->id));
        foreach($order->items as $item) {
            $moiporder->addItem($item->product->name, 1, "Pedido {$item->product->description} {$item->product->name} ", $item->product->price,
                'ADVERTISING_AND_MARKETING');
        }

        $moiporder->setCustomer($cliente)->create();

        $order_id = $moiporder->getId();
        $order_status = $moiporder->getStatus();
        $retorno = $moiporder->getLinks()->getAllCheckout();
        $checkout_link = $retorno->payCheckout;

        $order->fill(['order_id' => $order_id, 'order_status' => $order_status, 'checkout_link' => $checkout_link]);
        $order->save();
        return $order;


    }

    private function getClientId($id)
    {
        return "REPCLI_{$id}";
    }

    private function getOrderId($id)
    {
        return "REPORDG_{$id}";
    }

}