<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 10/01/2017
 * Time: 14:12
 */

namespace App\Repasse\Search;


use App\Admin\Dashboard\Models\Brand;
use App\Admin\Dashboard\Models\CarType;
use App\Admin\Dashboard\Models\Color;
use App\Admin\Dashboard\Models\Modelo;
use App\Admin\Dashboard\Models\Optional;
use App\Admin\Dashboard\Models\State;
use App\Admin\Dashboard\Models\StateDdd;
use App\Admin\Dashboard\Models\Store\Store;

class SearchPopulate
{
    const MAX_KM = 900000;

    public static function getCarTypes()
    {
        return CarType::get(['id', 'name']);
    }

    public static function getBrands($car_type = null)
    {
        $columns = ['id', 'name', 'type'];
        if ($car_type !== null) {
            return Brand::where('type', $car_type)->get($columns);
        } else {
            return Brand::get($columns);
        }
    }

    public static function getModels($brand_id = null, $car_type = null)
    {
        $columns = ['id', 'name', 'car_type', 'brand_id'];

        if (!$car_type && !$brand_id) {
            return Modelo::get($columns);
        }

        if ($car_type) {
            return Modelo::where('car_type', $car_type)->get($columns);

        }

        if ($brand_id) {
            return Modelo::where('brand_id', $brand_id)->get($columns);
        }

    }

    public static function getYears()
    {
        $array = range(date('Y') + 1, 1984);
        array_unshift($array, 'Zero KM');
        return $array;
    }

    public static function getFuel()
    {
        return [
            [
                'label' => 'Álcool',
                'value' => 'Alcool'
            ],
            [
                'label' => 'Gasolina',
                'value' => 'Gasolina'
            ],
            [
                'label' => 'Diesel',
                'value' => 'Diesel'
            ]
        ];
    }

    public static function getOptionals($car_type = null)
    {
        $columns = ['id', 'name', 'type'];
        if ($car_type !== null) {
            return Optional::where('type', $car_type)->get($columns);
        } else {
            return Optional::get($columns);
        }
    }

    public static function getDoors()
    {
        return range(2, 5);
    }

    public static function getEixos()
    {
        return ['1', '2', '3', '4', '4x2', '6x2', '6x4', '8x2', '8x4'];
    }

    public static function getColors()
    {
        return Color::get(['id', 'name']);
    }

    public static function getStates()
    {
        return State::get(['id', 'initials', 'name']);
    }

    public static function getDDD($state_id = null)
    {
        $columns = ['id', 'ddd', 'name', 'state_id'];

        if ($state_id !== null) {
            return StateDdd::where('state_id', $state_id)->get($columns);

        } else {
            return StateDdd::get($columns);
        }
    }

    public static function getUserTypes()
    {
        return [
            ['id' => 5, 'name' => 'Concessionária'],
            ['id' => 1, 'name' => 'Lojista'],
            ['id' => 6, 'name' => 'Locadora'],
            ['id' => 2, 'name' => 'Repassador'],
            ['id' => 4, 'name' => 'Corretor de Imóveis'],
            ['id' => 3, 'name' => 'Particular']
        ];
    }

    public static function getPriceRange($start, $end, $step)
    {
        return range($start, $end, $step);
    }

    public static function getKmRange($start, $end, $step)
    {

        $first = 0;
        // $second = 5000;

        $range = range($start, $end, $step);

        array_unshift($range, $first);

        return $range;
    }

    public static function getAvailableSorting(): array
    {
        return [
            [
                'label' => 'Ordenação original',
                'value' => [
                    'order_by' => null,
                    'direction' => null
                ]
            ],
            [
                'label' => 'Menor ano',
                'value' => [
                    'order_by' => 'year',
                    'direction' => 'ASC'
                ]
            ],
            [
                'label' => 'Maior ano',
                'value' => [
                    'order_by' => 'year',
                    'direction' => 'DESC'
                ]
            ],
            [
                'label' => 'Menor preço',
                'value' => [
                    'order_by' => 'price',
                    'direction' => 'ASC'
                ]
            ],
            [
                'label' => 'Maior preço',
                'value' => [
                    'order_by' => 'price',
                    'direction' => 'DESC'
                ]
            ],
            [
                'label' => 'Menor Km',
                'value' => [
                    'order_by' => 'km',
                    'direction' => 'ASC'
                ]
            ],
            [
                'label' => 'Maior Km',
                'value' => [
                    'order_by' => 'km',
                    'direction' => 'DESC'

                ]
            ]
        ];
    }

    public static function getSellers($store_id)
    {
        $store = Store::findOrFail($store_id);
        $vendedores = [];
        $store_staff = $store->staff;

        foreach($store_staff as $staff) {
            $vendedores[] = [
                'id' => $staff->id,
                'name' => $staff->name
            ];
        }

        return $vendedores;

    }


}