<?php
/**
 * Created by PhpStorm.
 * User: Rafael Mena Barreto
 * Date: 03/03/2020
 * Time: 16:25
 */

namespace App\Repasse\UserControl;

use App\Admin\Dashboard\Models\CarTurbo;
use App\Admin\Dashboard\Models\Store\Store;

class UserStats
{

    private $store;

    private $carTurbo;

    /**
     * UserStats constructor.
     * @param Store $store
     * @param CarTurbo $carTurbo
     */
    public function __construct(Store $store, CarTurbo $carTurbo)
    {
        $this->store = $store;
        $this->carTurbo = $carTurbo;
    }

    public function getStats($store_id, $period = null): array
    {
        // a estatística mensal, tem todos os anúncios que foram cadastrados no período para aquela loja
        // todas as salas criadas nesse mês (mas com que lista de anúncios?)
        $loja = $this->store->find($store_id);

        $anuncios = $loja->cars();
        $todos = $loja->cars()->get();
        $staff = $loja->staff()->pluck('id');

        $turbos = $this->carTurbo->whereIn('user_id', $staff);

        if ($period !== null) {
            $turbos = $turbos->whereBetween('created_at', [$period['start'], $period['end']]);
            $anuncios = $anuncios->whereBetween('created_at', [$period['start'], $period['end']]);
        }

        $negociacoes = 0;
        $vendas = 0;

        foreach ($todos as $anuncio) {
            $venda = $anuncio->car_sell()->where('reason_id', 1);
            $anuncio_negociacoes = $anuncio->rooms();
            $anuncio_ligacoes = $anuncio->calls();

            if ($period !== null) {
                $venda = $venda->whereBetween('created_at', [$period['start'], $period['end']]);
                $anuncio_ligacoes->whereBetween('created_at', [$period['start'], $period['end']]);
                $anuncio_negociacoes->whereBetween('created_at', [$period['start'], $period['end']]);
            }


            $negociacoes += $anuncio_ligacoes->count();
            $negociacoes += $anuncio_negociacoes->count();
            $vendas += $venda->count();
        }

        return [
            'anuncios' => $anuncios->count(),
            'negociacoes' => $negociacoes,
            'turbos' => $turbos->count(),
            'vendas' => $vendas,
            'staff' => $staff->count()
        ];

    }


}