<?php

namespace App\Traits;

use Illuminate\Support\Str;

trait HasSlug
{
    protected static function bootHasSlug()
    {
        static::creating(function ($model) {
            $model->slug = static::generateUniqueSlug($model, $model->name);
        });

        static::updating(function ($model) {
            if ($model->isDirty('name')) { 
                $model->slug = static::generateUniqueSlug($model, $model->name, $model->id);
            }
        });
    }

    protected static function generateUniqueSlug($model, $name, $ignoreId = null)
    {
        $baseSlug = Str::slug($name);
        $slug = $baseSlug;
        $count = 1;

        $existingSlugs = $model->where('slug', 'LIKE', "{$baseSlug}%")
            ->when($ignoreId, fn($query) => $query->where('id', '!=', $ignoreId))
            ->pluck('slug')
            ->toArray();

        while (in_array($slug, $existingSlugs)) {
            $slug = "{$baseSlug}-{$count}";
            $count++;
        }

        return $slug;
    }
}