<?php

namespace App\Transformers\Order;

use App\Transformers\Transformer;

class OrderTransformer extends Transformer
{
    public function transform( $value )
    {
        $car_query = [];
        if ( count( $value->car_query ) ) {
            $car_query = [
                'car_query_id' => $value->car_query->id,
                'license_plate' => $value->car_query->license_plate,
                'response' => json_decode( $value->car_query->response )
            ];
        }

        return [
            'success' => true,
        	'data' => [
	        	'id' => (integer)$value->id,
	        	'user' => [
                    'id'    => $value->user->id,
                    'name'  => $value->user->name,
                    'email' => $value->user->email,
                ],
                'product'          => $value->items[0]->product,
                'total'            => (double)$value->total,
                'price'            => number_format($value->total, 2, ',', '.'),
                'subtotal'         => (double)$value->subtotal,
                'discount'         => (double)$value->discount,
                'transaction_code' => $value->transaction_code,
                'checkout_link'    => $value->checkout_link,
                'car_query'        => $car_query,
                'created_at'       => $value->created_at->format('d/m/Y H:i:s'),
                'updated_at'       => $value->updated_at->format('Y-m-d H:i:s'),
                'status'           => (integer)$value->status,
                'order_status'     => $value->order_status,
                'situation'        => $value->situation
	        ]
        ];
    }

    public function transformCollection ( $values )
    {
        $data = [];
        foreach ( $values as $value ) {
            $data[] = $this->transform( $value );
        }

        return [
            'success' => true,
            'data'  => [
                'totals'       => $values->total(),
                'per_page'     => $values->perPage(),
                'current_page' => $values->currentPage(),
                'items'        => $data,
            ]
        ];
    }

    public function transformGroupedCollection ( $values )
    {
        $data = [];
        foreach ( $values as $key => $value ) {
            foreach( $value as $val ) {
                $orders[] = $this->transform( $val );
            }
            $data[] = [
                'license_plate' => $key,
                'car_queries'   => $orders
            ];
        }

        return [
            'success' => true,
            'data'  => [
                'totals'       => count( $values ),
                'per_page'     => count( $values ),
                'current_page' => 1,
                'items'        => $data,
            ]
        ];
    }
}