<?php

use App\Admin\Dashboard\Models\Store\Store;
use App\Admin\Role\Models\Role;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class StoresParticularMigration extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        \DB::beginTransaction();

        try {

            // Esta migration vai criar duas lojas genéricas, uma para particuar e outra para corretor de imóveis
            $particular = \App\Auth\Models\UserType::where('name', 'Particular')->first();
            $corretor = \App\Auth\Models\UserType::where('name', 'Corretor de Imóveis')->first();

            // Palhoça
            $city = \App\Admin\Dashboard\Models\City::where('name', 'Palhoça')->first();
            $loja_particular = Store::create([
                'user_id' => 0,
                'company_name' => 'Particular',
                'trade_name' => 'Particular',
                'cnpj' => '33333333333333',
                'city_id' => $city->id
            ]);

            $loja_corretor = Store::create([
                'user_id' => 0,
                'company_name' => 'Corretor de Imóveis',
                'trade_name' => 'Corretor de Imóveis',
                'cnpj' => '44444444444444',
                'city_id' => $city->id
            ]);

            $role_individual = Role::where('name', 'salesman')->first();
            // Colocar todos os $particular na $loja_particular
            \App\Auth\Models\User::where('user_type', $particular->id)->where('is_aprovado', '<>', 0)->chunk(500,
                function ($users) use ($loja_particular, $role_individual) {
                    foreach ($users as $user) {
                        // usuário para loja
                        $user->roles()->attach($role_individual->id);
                        $loja_particular->staff()->attach($user->id,
                            ['role_id' => $role_individual->id, 'status' => 1]);
                    }
                });

            // Colocar todos os $corretor na $loja_corretor
            \App\Auth\Models\User::where('user_type', $corretor->id)->where('is_aprovado', '<>', 0)->chunk(500,
                function ($users) use ($loja_corretor, $role_individual) {
                    foreach ($users as $user) {
                        // usuário para loja
                        $user->roles()->attach($role_individual->id);
                        $loja_corretor->staff()->attach($user->id, ['role_id' => $role_individual->id, 'status' => 1]);
                    }
                });
            \DB::commit();
        } catch (\Exception $e) {
            Log::error( $e->getMessage() . ' on file ' . $e->getFile() . ' on line ' . $e->getLine() );
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        //
    }
}
