<?php

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ReportControllerTest extends TestCase
{

    public function testReportConcessionaria()
    {
        $this->withoutMiddleware();
        $this->visit('/admin/relatorio/Concessionarias')
            ->see('Nome da Concessionária')
            ->assertResponseStatus(200);

        $this->visit('/admin/relatorio/Concessionarias?order=DESC')
            ->see('Nome da Concessionária')
            ->assertResponseStatus(200);
    }

    public function testReportNegociosConcluidos()
    {
        $this->withoutMiddleware();
        $this->visit('/admin/relatorio/Negociacoes')
            ->see('VENDEDOR')
            ->assertResponseStatus(200);
    }

    public function testReportNovosAnuncios()
    {
        $this->withoutMiddleware();
        $this->visit('/admin/relatorio/Anuncios')
            ->see('Relatório de Novos Anúncios')
            ->assertResponseStatus(200);
    }

    public function testReportInstalacoes()
    {
        $this->withoutMiddleware();
        $this->visit('/admin/relatorio/Instalacoes')
            ->see('Instalações')
            ->assertResponseStatus(200);
    }

    public function testReportAvaliacoes()
    {
        $this->withoutMiddleware();
        $this->visit('/admin/relatorio/Avaliacoes')
            ->see('Relatório de Avaliações: Média')
            ->assertResponseStatus(200);
    }

    public function testReportLeads()
    {
        $this->withoutMiddleware();
        $this->visit('/admin/relatorio/Leads')
            ->see('Relatório de Leads')
            ->assertResponseStatus(200);
    }

    public function testReportEstoque()
    {
        $this->withoutMiddleware();
        $this->visit('/admin/relatorio/Estoque/4')
            ->see('Exibindo')
            ->assertResponseOk();
    }

    public function testReportEmptyEstoque()
    {
        $this->withoutMiddleware();
        $this->visit('/admin/relatorio/Estoque')
            ->see('Publicação')
            ->assertResponseOk();
    }

    public function testReportCar()
    {
        $user = \App\Auth\Models\User::find(2);
        $this->actingAs($user)
            ->visit('/admin/relatorio/Anuncio/1303')
            ->see('Visualizando Anúncio')
            ->assertResponseOk();
    }

    public function testReportCarNotFound()
    {
        $user = \App\Auth\Models\User::find(2);
        $this->actingAs($user)
            ->get('/admin/relatorio/Anuncio/9999')
            ->assertResponseStatus(404);
    }

    public function testReportAnuncioEditado()
    {

        $user = \App\Auth\Models\User::find(2);
        $this->actingAs($user)
            ->visit('/admin/relatorio/Anuncio/1146')
            ->see('Visualizando Anúncio')
            ->assertResponseOk();

    }

    public function testReportAnuncioNoStore()
    {
        $car = \App\Admin\Dashboard\Models\Car::find(1715);
        $car->store_id = null;
        $car->save();

        $user = \App\Auth\Models\User::find(2);
        $this->actingAs($user)
            ->visit('/admin/relatorio/Anuncio/1715')
            ->see('Visualizando Anúncio')
            ->see('Sem Loja Vinculada!')
            ->assertResponseOk();


    }
}
