<?php

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiControllerCarNegotiationsTest extends TestCase
{

    public function testNegotiationCarNotFound()
    {
        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'password' => '123',
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);
        
        
        $roles = \App\Admin\Role\Models\Role::getIndividualRole();
        $user->roles()->sync($roles);
        $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();
        $store->staff()->attach($user->id, ['role_id' => $roles[0], 'status'=> 1] );
        

        $response = $this->call('GET', '/api/car-negotiations/99999999', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($user->email . ':' . '123'),
                'PHP_AUTH_USER' => $user->email,
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => false])->assertResponseStatus( 404 );
    }

    public function testNegotiationsNotMyCar()
    {

        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'password' => '123',
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);        
        
        $roles = \App\Admin\Role\Models\Role::getIndividualRole();
        $user->roles()->sync($roles);
        $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();
        $store->staff()->attach($user->id, ['role_id' => $roles[0], 'status'=> 1] );


        /** @var \App\Auth\Models\User $user */
        $user2 = factory(\App\Auth\Models\User::class)->create([
            'password' => '123',
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);        
        
        $roles2 = \App\Admin\Role\Models\Role::getIndividualRole();
        $user2->roles()->sync($roles2);
        $store2 = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();
        $store2->staff()->attach($user2->id, ['role_id' => $roles2[0], 'status'=> 1]);


        $response = $this->call('GET', '/api/car-negotiations/947', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($user->email . ':' . '123'),
                'PHP_AUTH_USER' => $user->email,
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => false, 'msg' => 'Acesso negado.'])->assertResponseStatus( 401 );

    }


    public function testCorrectLoginOnCarNegotiations()
    {
        // call( $method, $uri, $parameters = [], $cookies = [], $files = [], $server = [], $content = null)
        $response = $this->call('GET', '/api/car-negotiations/1667', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => true])->assertResponseStatus( 200 );
    }

    public function testNegotiationsWithBuyer()
    {
        $response = $this->call('GET', '/api/car-negotiations/1564', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => true])->assertResponseStatus( 200 );
    }

    public function testNegotiationsNotAllowed()
    {

        $response = $this->call('GET', '/api/car-negotiations/1218', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('zero@zero.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'zero@zero.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => false, 'msg' => 'Acesso negado.'])->assertResponseStatus( 401 );
    }

    public function testNegotiationsCallBuyer()
    {
        $response = $this->call('GET', '/api/car-negotiations/1555', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => true])->assertResponseStatus( 200 );
    }

    public function testNegotiationsChatBuyer()
    {
        $response = $this->call('GET', '/api/car-negotiations/1298', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => true])->assertResponseStatus( 200 );
    }

    public function testNegotiationsCarSold()
    {
        $response = $this->call('GET', '/api/car-negotiations/1489', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => true])->assertResponseStatus( 200 );

    }

    public function testInternalServerError()
    {
        $response = $this->call('GET', '/api/car-negotiations/962', [], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);
        $this->assertResponseStatus( 500);

    }


    public function test401UnauthorizedOnCarNegotiations()
    {
        $response = $this->call('GET', '/api/car-negotiations/1218');
        $this->assertResponseStatus( 401);
    }
}
