<?php

use App\Core\Jobs\CarStatusPodioJob;
use App\Core\Jobs\NewSellPodioJob;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiControllerCarSoldTest extends TestCase
{
    //

    /**
     * Carro vendido na plataforma
     */
    public function testSoldCar()
    {
        /** @var \App\Admin\Dashboard\Models\Car $car */
        $car = \App\Admin\Dashboard\Models\Car::with('car_sell')->find(1489);
        // Remove a venda
        $car->car_sell()->delete();
        // Marca o carro como aberto
        $car->car_status_id = 1;
        $car->save();

        // jobs
        $this->expectsJobs([NewSellPodioJob::class, CarStatusPodioJob::class]);
        // remove o carro
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 1], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => true, 'msg' => 'Parabéns, seu veículo foi vendido.', 'car_status_id' => 3])->assertResponseStatus( 200);
    }

    /**
     * Carro vendido fora da plataforma
     */
    public function testSoldCarOtherWay()
    {

        /** @var \App\Admin\Dashboard\Models\Car $car */
        $car = \App\Admin\Dashboard\Models\Car::with('car_sell')->find(1489);
        // Remove a venda
        $car->car_sell()->delete();
        // Marca o carro como aberto
        $car->car_status_id = 1;
        $car->save();

        // jobs
        $this->expectsJobs([CarStatusPodioJob::class]);
        // remove o carro
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 2], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => true, 'msg' => 'Parabéns, seu veículo foi vendido.', 'car_status_id' => 3])->assertResponseStatus( 200);
    }

    /**
     * Segundo a tarfefa 882 e 195 anúncio em 5 análise 7 bloqueado 6 suspenso podem ser vendidos
     */
    public function testSellCarAnalysis()
    {
        /** @var \App\Admin\Dashboard\Models\Car $car */
        $car = \App\Admin\Dashboard\Models\Car::with('car_sell')->find(1489);
        // Remove a venda
        $car->car_sell()->delete();
        // Marca o carro como aberto
        $car->car_status_id = 5;
        $car->save();

        // jobs
        $this->expectsJobs([CarStatusPodioJob::class]);
        // remove o carro
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 2], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => true, 'msg' => 'Parabéns, seu veículo foi vendido.', 'car_status_id' => 3])->assertResponseStatus( 200);

    }

    public function testSellCarSuspended()
    {
        /** @var \App\Admin\Dashboard\Models\Car $car */
        $car = \App\Admin\Dashboard\Models\Car::with('car_sell')->find(1489);
        // Remove a venda
        $car->car_sell()->delete();
        // Marca o carro como aberto
        $car->car_status_id = 6;
        $car->save();

        // jobs
        $this->expectsJobs([CarStatusPodioJob::class]);
        // remove o carro
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 2], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => true, 'msg' => 'Parabéns, seu veículo foi vendido.', 'car_status_id' => 3])->assertResponseStatus( 200);
    }

    public function testRemoveCarSuspended()
    {
        /** @var \App\Admin\Dashboard\Models\Car $car */
        $car = \App\Admin\Dashboard\Models\Car::with('car_sell')->find(1489);
        // Remove a venda
        $car->car_sell()->delete();
        // Marca o carro como aberto
        $car->car_status_id = 6;
        $car->save();

        // jobs
        $this->expectsJobs([CarStatusPodioJob::class]);
        // remove o carro
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 3], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => true, 'msg' => 'Veículo removido com sucesso', 'car_status_id' => 8])->assertResponseStatus( 200);
    }

    public function testSellCarBlocked()
    {
        /** @var \App\Admin\Dashboard\Models\Car $car */
        $car = \App\Admin\Dashboard\Models\Car::with('car_sell')->find(1489);
        // Remove a venda
        $car->car_sell()->delete();
        // Marca o carro como aberto
        $car->car_status_id = 7;
        $car->save();

        // jobs
        $this->expectsJobs([CarStatusPodioJob::class]);
        // remove o carro
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 2], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => true, 'msg' => 'Parabéns, seu veículo foi vendido.', 'car_status_id' => 3])->assertResponseStatus( 200);
    }

    public function testRemoveCarBlocked()
    {
        /** @var \App\Admin\Dashboard\Models\Car $car */
        $car = \App\Admin\Dashboard\Models\Car::with('car_sell')->find(1489);
        // Remove a venda
        $car->car_sell()->delete();
        // Marca o carro como aberto
        $car->car_status_id = 7;
        $car->save();

        // jobs
        $this->expectsJobs([CarStatusPodioJob::class]);
        // remove o carro
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 3], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => true, 'msg' => 'Veículo removido com sucesso', 'car_status_id' => 8])->assertResponseStatus( 200);
    }

    public function testRemoveCar()
    {
        /** @var \App\Admin\Dashboard\Models\Car $car */
        $car = \App\Admin\Dashboard\Models\Car::with('car_sell')->find(1489);
        // Remove a venda
        $car->car_sell()->delete();
        // Marca o carro como aberto
        $car->car_status_id = 1;
        $car->save();

        // jobs
        $this->expectsJobs(CarStatusPodioJob::class);
        // remove o carro
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 3], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => true, 'msg' => 'Veículo removido com sucesso', 'car_status_id' => 8])->assertResponseStatus( 200);

    }



    public function testCarNotFoundOrRemoved()
    {
        // call( $method, $uri, $parameters = [], $cookies = [], $files = [], $server = [], $content = null)
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1489, 'reason_id' => 3], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => false, 'msg' => 'Carro não encontrado'])->assertResponseStatus( 404);
    }

    public function testCarNotMine()
    {
        // call( $method, $uri, $parameters = [], $cookies = [], $files = [], $server = [], $content = null)
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1703, 'reason_id' => 3], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => false, 'msg' => 'O usuário não é o proprietário do carro'])->assertResponseStatus( 403);
    }

    public function testCarNotSellable()
    {
        $response = $this->call('POST', '/api/car-sold', ['car_id' => 1146, 'reason_id' => 3], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]);

        $this->seeJson(['success' => false, 'msg' => 'Veículo não pode ser marcado como vendido pois seu status não está aberto'])->assertResponseStatus( 409);

    }

    public function testCarSold401()
    {
        $response = $this->call('POST', '/api/car-sold');
        $this->assertResponseStatus( 401);
    }
}
