<?php

use App\Core\Jobs\EditCarPodioJob;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiControllerEditCarTest extends TestCase
{

    use DatabaseTransactions;

    public function testCarNotFound()
    {

                /** @var \App\Auth\Models\User $user */
                $user = factory(\App\Auth\Models\User::class)->create([
                    'password' => '123',
                    'user_type' => 3,
                    'role_id' => 2,
                    'is_aprovado' => 1
                ]);
        
                $roles = \App\Admin\Role\Models\Role::getIndividualRole();
        
                $user->roles()->sync($roles);
                $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();
        
        
                $store->staff()->attach($user->id, ['role_id' => $roles[0], 'status'=> 1] );
        

        $response = $this->call('POST', '/api/car-edit', [
            'car_id' => 9999
        ], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode($user->email . ':' . '123'),
                'PHP_AUTH_USER' => $user->email,
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->assertResponseStatus( 404 );

    }

    public function testEditNotMyCar()
    {

        
                /** @var \App\Auth\Models\User $user */
                $user = factory(\App\Auth\Models\User::class)->create([
                    'password' => '123',
                    'user_type' => 3,
                    'role_id' => 2,
                    'is_aprovado' => 1
                ]);
        
                $roles = \App\Admin\Role\Models\Role::getIndividualRole();
        
                $user->roles()->sync($roles);
                $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();
        
        
                $store->staff()->attach($user->id, ['role_id' => $roles[0], 'status'=> 1] );
        


        $response = $this->call('POST', '/api/car-edit', [
            'car_id' => 1215
        ], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJsonEquals(['success' => false, 'msg' => 'Usuário não autorizado'])->assertResponseStatus( 403 );

    }

    public function testCarNotEditable()
    {
        $car = \App\Admin\Dashboard\Models\Car::find(1213);
        $car->car_status_id = 3;
        $car->save();

        $response = $this->call('POST', '/api/car-edit', [
            'car_id' => 1213
        ], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJsonEquals(['success' => false, 'Anúncio não pode ser editado'])->assertResponseStatus( 401 );

    }

    public function testCarEditFailedValidation()
    {

        $response = $this->call('POST', '/api/car-edit', [
            'car_id' => 1213
        ], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => false])->assertResponseStatus( 400 );

    }

    public function testCarEdit()
    {
        $this->expectsJobs(EditCarPodioJob::class);

        $response = $this->call('POST', '/api/car-edit', [
            'car_id' => 1213,
            'color_id' => 3,
            'km' => 254445,
            'price' => 22457.01,
            'observation' => 'O anúncio editado foi editado com sucesso ;)'
        ], [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );
        $this->seeJson(['success' => true])->assertResponseStatus( 200 );
        $this->seeInDatabase('car', ['id' => 1213, 'color_id' => 3, 'price' => 22457.01, 'km' => 254445, 'observation' => 'O anúncio editado foi editado com sucesso ;)']);

    }

}
