<?php

use App\Admin\Dashboard\Models\Car;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiFavoriteControllerTest extends TestCase
{
    use DatabaseTransactions;

    public function testFavoritesList()
    {
        $this->call('POST', '/api/favorites/', [], [], [], [
            'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
            'PHP_AUTH_USER' => 'a@a.com',
            'PHP_AUTH_PW' => '123'
        ]);
        $this->seeJson(['success' => true]);
        $this->assertResponseStatus(200);

    }

    public function testSetFavorite()
    {
        $car = \App\Admin\Dashboard\Models\Car::find(1702);
        $car->car_status_id = 1;
        $car->save();

        $this->call('GET', '/api/favorites/1702/change', [], [], [], [
            'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
            'PHP_AUTH_USER' => 'a@a.com',
            'PHP_AUTH_PW' => '123'
        ]);
        $this->seeJson(['success' => true]);
        $this->assertResponseStatus(200);
    }

    public function testSetFavoriteCarNotFound()
    {
        $this->call('GET', '/api/favorites/9999/change', [], [], [], [
            'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
            'PHP_AUTH_USER' => 'a@a.com',
            'PHP_AUTH_PW' => '123'
        ]);
        $this->seeJson(['success' => false, 'msg' => 'Anúncio não encontrado!']);
        $this->assertResponseStatus(404);
    }


    public function testSetFavoriteCarNotAllowed()
    {
        $this->call('GET', '/api/favorites/1705/change', [], [], [], [
            'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
            'PHP_AUTH_USER' => 'a@a.com',
            'PHP_AUTH_PW' => '123'
        ]);
        $this->seeJson(['success' => false, 'msg' => 'Anúncio não está aberto!']);
        $this->assertResponseStatus(409);
    }

    public function testSetFavoriteMyCar()
    {
        $car = \App\Admin\Dashboard\Models\Car::find(1565);
        $car->car_status_id = 1;
        $car->save();

        $this->call('GET', '/api/favorites/1565/change', [], [], [], [
            'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
            'PHP_AUTH_USER' => 'a@a.com',
            'PHP_AUTH_PW' => '123'
        ]);
        $this->seeJson(['success' => false, 'msg' => 'Este anúncio é seu!']);
        $this->assertResponseStatus(409);
    }

    public function testFavoriteNoCars()
    {
        $this->withoutMiddleware();


        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        $roles = \App\Admin\Role\Models\Role::getIndividualRole();

        $user->roles()->sync($roles);
        $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();


        $store->staff()->attach($user->id, ['role_id' => $roles[0], 'status'=> 1] );

        $this->actingAs($user);
        $this->json('POST','/api/favorites')
            ->seeJsonStructure([
                'success',
                'total',
                'page',
                'data'
            ]);

    }

    public function testRemoveFavoriteLastCar()
    {
        $this->withoutMiddleware();
        //
        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        $roles = \App\Admin\Role\Models\Role::getIndividualRole();
        $user->roles()->sync($roles);
        $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();
        $store->staff()->attach($user->id, ['role_id' => $roles[0], 'status'=> 1] );

        $car = Car::find(1702);
        $car->car_status_id = 1;
        $car->save();

        \App\Admin\Dashboard\Models\CarFavorite::create(['car_id' => 1702, 'user_id' => $user->id]);

        $this->actingAs($user);
        $response = $this->json('GET', '/api/favorites/1702/change');

        $this->seeJsonStructure(['success', 'total', 'car_id', 'is_favorite']);

        $this->assertResponseStatus(200);

    }
}
