<?php

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiUserControllerAuthenticateUserTest extends TestCase
{
    use DatabaseTransactions;

    public function testLoginBlacklistedToken()
    {
        // Add User to blacklist
        $data = [
            'device_token' => 'c3bb73ce-d907-4ff1-9c64-980940c053fe',
            'reason' => 'Coloquei vc na blacklist só pra testes',
            'attempts' => 0
        ];
        $blacklist = \App\Admin\Dashboard\Models\TokenBlackList::create($data);
        $this->seeInDatabase('token_blacklist', $data);

        $user = \App\Auth\Models\User::where('email', 'samuelfpolis@hotmail.com')->first();
        $user->password = '123';

        $user->save();

        // Login
        $data = [
            'email' => 'samuelfpolis@hotmail.com',
            'password' => '123',
            'device_token' => 'c3bb73ce-d907-4ff1-9c64-980940c053fe'
        ];
        $this->post('/api/v2/login', $data)
            ->seeJson(['success' => false]);
        $this->assertResponseStatus(403);
    }

    // login com token inválido (not a uuidv4)
    public function testLoginInvalidToken()
    {
        $user = \App\Auth\Models\User::where('email', 'samuelfpolis@hotmail.com')->first();
        $user->password = '123';

        $user->save();

        // Login
        $data = [
            'email' => 'samuelfpolis@hotmail.com',
            'password' => '123',
            'device_token' => 'rpiuegnerpiusgpirutestrb'
        ];

        $this->post('/api/v2/login', $data)
            ->seeJson(['success' => true]);
        $this->assertResponseStatus(200);
    }


    // login com token normal (not in blacklist)
    public function testLoginWithToken()
    {
        $user = \App\Auth\Models\User::where('email', 'samuelfpolis@hotmail.com')->first();
        $user->password = '123';
        $user->device_token = 'c3bb73ce-d907-4ff1-9c64-980940c053fe';

        $user->save();

        // Login
        $data = [
            'email' => 'samuelfpolis@hotmail.com',
            'password' => '123',
            'device_token' => 'c3bb73ce-d907-4ff1-9c64-980940c053fe'
        ];

        $this->post('/api/v2/login', $data)
            ->seeJson(['success' => true]);
        $this->assertResponseStatus(200);
    }

    // login com usuário lead (status pending)
    public function testLoginWithLeadUser()
    {
        $user = \App\Auth\Models\User::where('email', 'samuelfpolis@hotmail.com')->first();
        // Lead
        $user->password = '123';
        $user->is_aprovado = 3;
        $user->save();

        // Login
        $data = [
            'email' => 'samuelfpolis@hotmail.com',
            'password' => '123'
        ];

        $this->post('/api/v2/login', $data)
            ->seeJson(['success' => false, 'msg' => 'Nossa equipe ainda está avaliando seu cadastro, em breve entraremos em contato para validar suas informações e liberar seu cadastro.']);
        $this->assertResponseStatus(403);

    }

}
