<?php

use App\Auth\Models\User;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiUserControllerTest extends TestCase
{
    const API_ROUTE = '/api/v2/login';

    public function testSuccessfullLogin()
    {
        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'password' => '123',
            'user_type' => 3,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        $roles = \App\Admin\Role\Models\Role::getIndividualRole();

        $user->roles()->sync($roles);
        $store = \App\Admin\Dashboard\Models\Store\Store::getParticularStore();


        $store->staff()->attach($user->id, ['role_id' => $roles[0], 'status'=> 1] );


        $this->post(self::API_ROUTE, ['email' => $user->email, 'password' => '123'])
            ->seeJson(['success' => true]);
    }


    public function testFailedLogin()
    {
        $this->post(self::API_ROUTE, ['email' => 'a@a.com', 'password' => '321'])
            ->seeJson(['success' => false, 'msg' => 'Usuário e/ou senha inválido!']);
    }

    public function testRepassadorLogin()
    {

        /** @var \App\Auth\Models\User $user */
        $user = factory(\App\Auth\Models\User::class)->create([
            'password' => '123',
            'user_type' => 2,
            'role_id' => 2,
            'is_aprovado' => 1
        ]);

        $roles = \App\Admin\Role\Models\Role::getProfessionalRole();

        $user->roles()->sync($roles);

        $store = factory(\App\Admin\Dashboard\Models\Store\Store::class)->create([
            'user_id' => $user->id
        ]);

        $store->staff()->attach($user->id, ['role_id' => 2, 'status'=> 1] );

        $this->post(self::API_ROUTE, ['email' => $user->email, 'password' => '123'])
            ->seeJson(['success' => true]);

    }




}
