<?php

use App\Auth\Models\User;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiControllerSaveCarTest extends TestCase
{
    use DatabaseTransactions;

    public function testUserBlocked()
    {
        // Esse erro é exclusivo da v2
        $user = User::where('email', 'paulo@kit.net')->first();
        $this->withoutMiddleware();
        $this->actingAs($user);

        $postdata = [
            'store_id' => 4,
            'color_id' => 1,
            'doors' => 5,
            'brand_id' => 194,
            'fipe_id' => 12897,
            'year' => 1997,
            'observation' => 'Teste',
            'cost' => 6459.70,
            'price' => 10634.88,
            'km' => 14557,
            'optionals' => [
                60,
                61,
                63
            ]

        ];

        $response = $this->call('POST', '/api/v2/car', $postdata, [], [], []);

        $this->seeJson(['success' => false, 'msg' => 'Não autorizado.'])
            ->assertResponseStatus(403);

    }

    public function testNoStore()
    {
        $postdata = [
            'store_id' => null,
            'color_id' => 1,
            'doors' => 5,
            'brand_id' => 194,
            'fipe_id' => 12897,
            'year' => 1997,
            'observation' => 'Teste',
            'cost' => 6459.70,
            'price' => 10634.88,
            'km' => 14557,
            'optionals' => [
                60,
                61,
                63
            ]

        ];

        $response = $this->call('POST', '/api/car', $postdata, [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );

        $this->seeJson(['success' => false])
            ->assertResponseStatus(422);

    }

    public function testWrongStore()
    {
        $postdata = [
            'store_id' => 44,
            'color_id' => 1,
            'doors' => 5,
            'brand_id' => 194,
            'fipe_id' => 12897,
            'year' => 1997,
            'observation' => 'Teste',
            'cost' => 6459.70,
            'price' => 10634.88,
            'km' => 14557,
            'optionals' => [
                60,
                61,
                63
            ]

        ];

        $response = $this->call('POST', '/api/car', $postdata, [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );

        $this->seeJson(['success' => false])
            ->assertResponseStatus(401);

    }

    public function testSaveCar()
    {

        $this->expectsJobs([\App\Core\Jobs\NewCarPodioJob::class]);

        $postdata = [
            'store_id' => 4,
            'color_id' => 1,
            'doors' => 5,
            'brand_id' => 194,
            'fipe_id' => 12897,
            'year' => 1997,
            'observation' => 'Teste',
            'cost' => 6459.70,
            'price' => 12345.67,
            'km' => 14557,
            'optionals' => [
                60,
                61,
                63
            ]

        ];

        $response = $this->call('POST', '/api/car', $postdata, [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('a@a.com' . ':' . '123'),
                'PHP_AUTH_USER' => 'a@a.com',
                'PHP_AUTH_PW' => '123'
            ]
        );

        $this->seeJson(['success' => true])
            ->seeInDatabase('car', [
                'store_id' => 4,
                'color_id' => 1,
                'doors' => 5,
                'brand_id' => 194,
                'fipe_id' => 12897,
                'year' => 1997,
                'observation' => 'Teste',
                'cost' => 6459.70,
                'price' => 12345.67,
                'km' => 14557
            ])
            ->assertResponseOk();
    }

    public function testFailedFipeValidation()
    {

        $postdata = [
            'store_id' => 125,
            'color_id' => 1,
            'doors' => 5,
            'brand_id' => 194,
            'fipe_id' => 12897,
            'year' => 1997,
            'observation' => 'Teste',
            'cost' => 6459.70,
            'price' => 12345.67,
            'km' => 14557,
            'optionals' => [
                60,
                61,
                63
            ]

        ];

        $response = $this->call('POST', '/api/car', $postdata, [], [],
            [
                'HTTP_Authorization' => 'Basic ' . base64_encode('thaless@kit.net' . ':' . '123'),
                'PHP_AUTH_USER' => 'thaless@kit.net',
                'PHP_AUTH_PW' => '123'
            ]
        );

        $this->seeJson(['success' => false, 'msg' => 'Valor da Fipe foge da regra'])->assertResponseStatus(409);

    }

}
