<?php

use App\Admin\Dashboard\Models\Car;
use App\Admin\Dashboard\Models\Store\Store;
use App\Core\Jobs\EditCarPodioJob;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiSiteControllerTest extends TestCase
{
    use DatabaseTransactions;


    private $uploadedFile = __DIR__ . '/../../../../stubs/test.jpg';


    public function testRefusedUser()
    {
        $this->get('/api/store_site/3/cars')
            ->seeJsonEquals(['success' => false, 'msg' => 'Consulta não autorizada contate o suporte!'])
            ->assertResponseStatus(403);
    }

    public function testPopulateStart()
    {
        $this->get('/api/store_site/4/populate')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testPopuplateByCarType()
    {
        $this->get('/api/store_site/4/populate/type/0')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testPopulateModels()
    {
        $this->get('/api/store_site/4/populate/models/134')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testContactForm()
    {
        // $job = (new SendEmailFormContactJob($request->get('name'), $request->get('email'), $request->get('subject'), $request->get('message'), $store) )->onQueue('emails')

        $this->expectsJobs([\App\Core\Jobs\StoreSite\SendEmailFormContactJob::class]);
        $this->post('/api/store_site/4/contact', [
            'name' => 'Fulaninho',
            'email' => 'fru@fru.com',
            'subject' => 'Assunto',
            'message' => 'aoufhiodwuhvpurwoevipreuvnipue'

        ])->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testCarNotFound()
    {
        $this->get('/api/store_site/4/car/999999')
            ->assertResponseStatus(404);
    }

    public function testCarDifferentStore()
    {
        $car = Car::find(1024);
        $car->car_status_id = 1;
        $car->save();
        $this->json('GET', '/api/store_site/4/car/1024')
            ->seeJson(['success' => false])
            ->assertResponseStatus(401);
    }

    public function testCarSingle()
    {
        // Aberto em 28/05/2020 é qualquer status igual a 1 (aberto) 2 (negociando) e 9 (turbinado)
        $car = Car::find(1146);
        $car->car_status_id = 1;
        $car->save();

        $this->get('/api/store_site/4/car/1146')
            ->seeJson(['success' => true])
            ->assertResponseOk();


        $car->car_status_id = 2;
        $car->save();

        $this->get('/api/store_site/4/car/1146')
            ->seeJson(['success' => true])
            ->assertResponseOk();


        $car->car_status_id = 9;
        $car->save();

        $this->get('/api/store_site/4/car/1146')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testCarSingleNotOpened()
    {
        // Não aberto em 28/05/2020 é qualquer status diferente de 1 (aberto) 2 (negociando) e 9 (turbinado)
        $car = Car::find(1146);
        $car->car_status_id = 3;
        $car->save();
        $this->json('GET','/api/store_site/4/car/1146')
            ->seeJson(['success' => false])
            ->assertResponseStatus(404);

        $car->car_status_id = 4;
        $car->save();
        $this->json('GET','/api/store_site/4/car/1146')
            ->seeJson(['success' => false])
            ->assertResponseStatus(404);

        $car->car_status_id = 5;
        $car->save();
        $this->json('GET','/api/store_site/4/car/1146')
            ->seeJson(['success' => false])
            ->assertResponseStatus(404);

        $car->car_status_id = 6;
        $car->save();
        $this->json('GET','/api/store_site/4/car/1146')
            ->seeJson(['success' => false])
            ->assertResponseStatus(404);


        $car->car_status_id = 7;
        $car->save();
        $this->json('GET','/api/store_site/4/car/1146')
            ->seeJson(['success' => false])
            ->assertResponseStatus(404);

        $car->car_status_id = 8;
        $car->save();
        $this->json('GET','/api/store_site/4/car/1146')
            ->seeJson(['success' => false])
            ->assertResponseStatus(404);

        $car->car_status_id = 10;
        $car->save();
        $this->json('GET','/api/store_site/4/car/1146')
            ->seeJson(['success' => false])
            ->assertResponseStatus(404);
    }

    public function testGetCars()
    {
        $this->get('/api/store_site/4/cars')
            ->seeJson(['success' => true])
            ->assertResponseOk();
    }

    public function testGetCarsParams()
    {
        $response = $this->call('GET', '/api/store_site/4/cars', [
            'car_type' => 0,
            'brand_id' => 134,
            'model_id' => 198,
            'start_year' => 2001,
            'end_year' => 2012,
            'fuel' => ['Gasolina'],
            'start_price' => 14,
            'end_price' => 55535,
            'doors' => [2,4,5],
            'eixos' => ['4'],
            'start_km' => 2,
            'end_km' => 254445,
            'state_id' => 24,
            'ddds' => [47, 48, 49],
            'optionals_id' => [58,59,60],
            'order_by' => 'price',
            'direction' => 'DESC',
            'page' => 1
        ]);
        $this->seeJson(['success' => true])->assertResponseOk();
    }

    public function testGetCarsState()
    {
        $response = $this->call('GET', '/api/store_site/4/cars', [
            'car_type' => 0,
            'brand_id' => 134,
            'model_id' => 198,
            'start_year' => 2001,
            'end_year' => 2012,
            'color_ids' => [1,2,3,4],
            'fuel' => ['Gasolina'],
            'start_price' => 14,
            'end_price' => 55535,
            'doors' => [2,4,5],
            'eixos' => ['4'],
            'start_km' => 2,
            'end_km' => 254445,
            'state_id' => 24,
            'optionals_id' => [58,59,60],
            'order_by' => 'price',
            'direction' => 'DESC',
            'page' => 1
        ]);
        $this->seeJson(['success' => true])->assertResponseOk();
    }


    public function testGetCarsOrdersPriceUp()
    {
        $response = $this->call('GET', '/api/store_site/4/cars', [
            'order_by' => 'price',
            'direction' => 'ASC',
            'page' => 1
        ]);
        $this->seeJson(['success' => true])->assertResponseOk();
    }

    public function testGetCarsOrdersYearUp()
    {
        $response = $this->call('GET', '/api/store_site/4/cars', [
            'order_by' => 'year',
            'direction' => 'ASC',
            'page' => 1
        ]);
        $this->seeJson(['success' => true])->assertResponseOk();
    }

    public function testGetCarsOrdersYearDown()
    {
        $response = $this->call('GET', '/api/store_site/4/cars', [
            'order_by' => 'year',
            'direction' => 'DESC',
            'page' => 1
        ]);
        $this->seeJson(['success' => true])->assertResponseOk();
    }

    public function testGetCarsOrdersKmUp()
    {
        $response = $this->call('GET', '/api/store_site/4/cars', [
            'order_by' => 'km',
            'direction' => 'ASC',
            'page' => 1
        ]);
        $this->seeJson(['success' => true])->assertResponseOk();
    }

    public function testGetCarsOrdersKmDown()
    {
        $response = $this->call('GET', '/api/store_site/4/cars', [
            'order_by' => 'km',
            'direction' => 'DESC',
            'page' => 1
        ]);
        $this->seeJson(['success' => true])->assertResponseOk();
    }

    public function testGenericFormValidation()
    {

        $this->post('/api/store_site/4/form', [])
            ->seeJson(['success' => false, 'msg' => 'Encontramos alguns erros.'])
            ->assertResponseStatus(422);
    }

    public function testGenericFormSuccess()
    {
        $this->expectsJobs([\App\Core\Jobs\StoreSite\SendEmailFormJob::class]);
        $this->post('/api/store_site/4/form', [
            'name' => 'Formulário DUT',
            'fields' => [
                'Nome' => 'Fulano de souza'
            ]
        ])->seeJson(['success' => true, 'msg' => 'Solicitação enviada com sucesso!'])->assertResponseOk();

    }

    public function testPopulateFipe()
    {
        $store = \App\Admin\Dashboard\Models\Store\Store::find(4);
        $response = $this->get(
            '/api/store_site/4/populate/model/1084/2016',
            ['Api-Key' => $store->store_token]);

        $this->seeJson(['success' => true]);
    }

    public function testSaveCar()
    {
        $this->expectsJobs(\App\Core\Jobs\NewCarPodioJob::class);

        $store = \App\Admin\Dashboard\Models\Store\Store::find(4);
        $this->post(
            '/api/store_site/4/car',
            [
                "user_id" => 9,
                "color_id" => 1,
                "doors" => 4,
                "brand_id" => 134,
                "fipe_id" => 16015,
                "year" => 2013,
                "observation" => "fouirhfniu hneirughn ierughnieur huemeig",
                "price" => 25457,
                "km" => 4546546,
                "optionals" => [58, 59, 60]
            ],
            ['Api-Key' => $store->store_token])->seeJson(['msg' => 'Anúncio cadastrado com sucesso']);

    }

    public function testSaveCarAboveFipe()
    {
        $this->expectsJobs(\App\Core\Jobs\NewCarPodioJob::class);

        $store = \App\Admin\Dashboard\Models\Store\Store::find(4);
        $this->post(
            '/api/store_site/4/car',
            [
                "user_id" => 9,
                "color_id" => 1,
                "doors" => 4,
                "brand_id" => 134,
                "fipe_id" => 16015,
                "year" => 2013,
                "observation" => "fouirhfniu hneirughn ierughnieur huemeig",
                "price" => 30499,
                "km" => 45465,
                "optionals" => [58, 59, 60]
            ],
            ['Api-Key' => $store->store_token])->seeJson(['msg' => 'Anúncio cadastrado com sucesso']);

    }

    public function testSaveNotMyCar()
    {

        $store = \App\Admin\Dashboard\Models\Store\Store::find(4);
        $this->post(
            '/api/store_site/4/car',
            [
                "user_id" => 4,
                "color_id" => 1,
                "doors" => 4,
                "brand_id" => 134,
                "fipe_id" => 16015,
                "year" => 2013,
                "observation" => "fouirhfniu hneirughn ierughnieur huemeig",
                "price" => 25457,
                "km" => 4546546,
                "optionals" => [58, 59, 60]
            ],
            ['Api-Key' => $store->store_token])->seeJson(['msg' => 'Acesso negado.'])->assertResponseStatus(401);

    }

    public function testImageUpload()
    {
        $store = Store::find(4);
        $uploadedFile = new Illuminate\Http\UploadedFile($this->uploadedFile, 'test.jpg',
            'image/jpeg', 562690, 0, true);

        $response = $this->call('POST', '/api/store_site/4/car/1734/image',
            [], [], ['filename' => $uploadedFile], [
                'HTTP_API_KEY' => $store->store_token
            ]);
        $this->seeJson(['success' => true])->assertResponseOk();

    }

    public function testImageUploadError()
    {
        $store = Store::find(4);
        $uploadedFile = new Illuminate\Http\UploadedFile($this->uploadedFile, 'test.jpg',
            'image/jpeg', 562690, 0, false);

        $response = $this->call('POST', '/api/store_site/4/car/1734/image',
            [], [], ['filename' => $uploadedFile], [
                'HTTP_API_KEY' => $store->store_token
            ]);
        $this->seeJson(['success' => false, 'msg' => 'Arquivo não enviado ou inválido'])->assertResponseStatus(400);

    }

    public function testImageUploadErrorMime()
    {
        $store = Store::find(4);
        $uploadedFile = new Illuminate\Http\UploadedFile($this->uploadedFile, 'test.jpg',
            'image/jpg', 562690, 0, true);

        $response = $this->call('POST', '/api/store_site/4/car/1734/image',
            [], [], ['filename' => $uploadedFile], [
                'HTTP_API_KEY' => $store->store_token
            ]);
        $this->seeJson(['success' => false, 'msg' => 'Arquivo Inválido (Não é uma imagem jpeg ou png)'])->assertResponseStatus(400);

    }



    public function testImageUploadCarNotFound()
    {
        $store = Store::find(4);
        $uploadedFile = new Illuminate\Http\UploadedFile($this->uploadedFile, 'test.jpg',
            'image/jpeg', 562690, 0, true);

        $response = $this->call('POST', '/api/store_site/4/car/9999/image',
            [], [], ['filename' => $uploadedFile], [
                'HTTP_API_KEY' => $store->store_token
            ]);
        $this->seeJson(['success' => false])->assertResponseStatus(404);

    }

    public function testImageUploadNotMyCar()
    {
        $store = Store::find(4);
        $uploadedFile = new Illuminate\Http\UploadedFile($this->uploadedFile, 'test.jpg',
            'image/jpeg', 562690, 0, true);

        $response = $this->call('POST', '/api/store_site/4/car/1709/image',
            [], [], ['filename' => $uploadedFile], [
                'HTTP_API_KEY' => $store->store_token
            ]);
        $this->seeJson(['success' => false, 'msg' => 'Não autorizado'])->assertResponseStatus(403);

    }

    public function testImageUploadCarNotEditable()
    {
        $store = Store::find(4);
        $car = Car::find(1734);
        $car->car_status_id = 3;
        $car->save();
        $uploadedFile = new Illuminate\Http\UploadedFile($this->uploadedFile, 'test.jpg',
            'image/jpeg', 562690, 0, true);

        $response = $this->call('POST', '/api/store_site/4/car/1734/image',
            [], [], ['filename' => $uploadedFile], [
                'HTTP_API_KEY' => $store->store_token
            ]);
        $this->seeJson(['success' => false, 'msg' => 'Anúncio não pode ser editado'])->assertResponseStatus(401);

    }

    public function testImageUploadCarEditableAuditable()
    {
        $store = Store::find(4);
        $car = Car::find(1734);
        $car->car_status_id = 2;
        $car->save();
        $uploadedFile = new Illuminate\Http\UploadedFile($this->uploadedFile, 'test.jpg',
            'image/jpeg', 562690, 0, true);

        $response = $this->call('POST', '/api/store_site/4/car/1734/image',
            [], [], ['filename' => $uploadedFile], [
                'HTTP_API_KEY' => $store->store_token
            ]);
        $this->seeJson(['success' => true])->assertResponseOk();

    }


    public function testImageUploadBackToModeration()
    {
        $store = Store::find(4);
        $car = Car::find(1734);
        $car->car_status_id = 6;
        $car->save();

        $uploadedFile = new Illuminate\Http\UploadedFile($this->uploadedFile, 'test.jpg',
            'image/jpeg', 562690, 0, true);

        $response = $this->call('POST', '/api/store_site/4/car/1734/image',
            [], [], ['filename' => $uploadedFile], [
                'HTTP_API_KEY' => $store->store_token
            ]);
        $this->seeJson(['success' => true])->assertResponseOk();
        $this->seeInDatabase('car', ['id' => $car->id, 'car_status_id' => 5]);

    }

    public function testCarPublish()
    {
        $this->expectsJobs([\App\Core\Jobs\CarStatusPodioJob::class]);
        $store = Store::find(4);
        $car = \App\Admin\Dashboard\Models\Car::find(1718);
        $car->car_status_id = 4;
        $car->save();
        $this->post('/api/store_site/4/car/1718/publish', [],
            ['Api-Key' => $store->store_token])->seeJson(['success' => true])->assertResponseStatus(201);
    }

    public function testCarPublishNotFound()
    {
        $store = Store::find(4);
        $this->post('/api/store_site/4/car/9999/publish', [],
            ['Api-Key' => $store->store_token])->seeJson(['success' => false])->assertResponseStatus(404);
    }

    public function testCarPublishNotMyCar()
    {
        $store = Store::find(4);
        $this->post('/api/store_site/4/car/1709/publish', [],
            ['Api-Key' => $store->store_token])->seeJson(['success' => false, 'msg' => 'Acesso negado'])->assertResponseStatus(403);
    }

    public function testCarPublishAlreadyPublished()
    {
        $store = Store::find(4);
        $this->post('/api/store_site/4/car/1718/publish', [],
            ['Api-Key' => $store->store_token])->seeJson(['success' => false, 'msg' => 'Anúncio já foi publicado'])->assertResponseStatus(412);
    }

    public function testCarPublishLowPhotos()
    {
        $store = Store::find(4);
        $this->post('/api/store_site/4/car/1734/publish', [],
            ['Api-Key' => $store->store_token])->seeJson(['success' => false, 'msg' => 'A quantidade de fotos difere da solicitada (entre 4 e 10)'])->assertResponseStatus(409);
    }

    public function testCarPublishSiteOnly()
    {
        $this->expectsJobs([\App\Core\Jobs\CarStatusPodioJob::class]);
        $store = Store::find(4);
        \App\Admin\Dashboard\Models\CarPhoto::create(['car_id' => 1730, 'filename' => 'xpto1.jpg']);
        \App\Admin\Dashboard\Models\CarPhoto::create(['car_id' => 1730, 'filename' => 'xpto2.jpg']);
        \App\Admin\Dashboard\Models\CarPhoto::create(['car_id' => 1730, 'filename' => 'xpto3.jpg']);
        \App\Admin\Dashboard\Models\CarPhoto::create(['car_id' => 1730, 'filename' => 'xpto4.jpg']);

        $this->post('/api/store_site/4/car/1730/publish', [],
            ['Api-Key' => $store->store_token])->seeJson(['success' => true, 'msg' => 'Oferta exclusiva do seu site criada com sucesso!'])->assertResponseStatus(201);
        $this->seeInDatabase('car', ['id' => 1730, 'car_status_id' => 1]);
    }

    public function testCarPublishRegular()
    {
        $this->expectsJobs([\App\Core\Jobs\CarStatusPodioJob::class]);
        $store = Store::find(4);
        $car = Car::find(1730);
        $car->site_only = 0;
        $car->fipe_id = 16014;
        $car->save();
        \App\Admin\Dashboard\Models\CarPhoto::create(['car_id' => 1730, 'filename' => 'xpto1.jpg']);
        \App\Admin\Dashboard\Models\CarPhoto::create(['car_id' => 1730, 'filename' => 'xpto2.jpg']);
        \App\Admin\Dashboard\Models\CarPhoto::create(['car_id' => 1730, 'filename' => 'xpto3.jpg']);
        \App\Admin\Dashboard\Models\CarPhoto::create(['car_id' => 1730, 'filename' => 'xpto4.jpg']);

        $this->post('/api/store_site/4/car/1730/publish', [],
            ['Api-Key' => $store->store_token])->seeJson(['success' => true, 'msg' => 'Anúncio publicado com sucesso'])->assertResponseStatus(201);
        $this->seeInDatabase('car', ['id' => 1730, 'car_status_id' => 1]);
    }

    public function testCarEdit()
    {
        $this->expectsJobs([EditCarPodioJob::class]);
        $store = Store::find(4);
        $car = \App\Admin\Dashboard\Models\Car::find(1718);
        $car->car_status_id = 4;
        $car->save();


        $response = $this->call('PUT', '/api/store_site/4/car/1718', [
            "observation" => "fouirhfniu hneirughn ierughnieur huemeig",
            "price" => 25457,
            "color_id" => 1,
            'cost' => 12447,
            "km" => 4546546,
            "optionals" => [58, 59, 60]
        ], [], [], [
            'HTTP_API_KEY' => $store->store_token
        ]);
        $this->seeJson(['success' => true])->assertResponseStatus(200);
        $this->seeInDatabase('car', ['id' => $car->id, 'observation' => 'fouirhfniu hneirughn ierughnieur huemeig']);
    }

    public function testCarEditNotMyCar()
    {
        $store = Store::find(4);
        /*$car = \App\Admin\Dashboard\Models\Car::find(1718);
        $car->car_status_id = 4;
        $car->save();*/


        $response = $this->call('PUT', '/api/store_site/4/car/1702', [
            "observation" => "fouirhfniu hneirughn ierughnieur huemeig",
            "price" => 25457,
            "color_id" => 1,
            "km" => 4546546,
            "optionals" => [58, 59, 60]
        ], [], [], [
            'HTTP_API_KEY' => $store->store_token
        ]);
        $this->seeJson(['success' => false, 'msg' => 'Usuário não autorizado'])->assertResponseStatus(403);

    }

    public function testCarEditNotEditable()
    {
        $store = Store::find(4);
        $car = \App\Admin\Dashboard\Models\Car::find(1718);
        $car->car_status_id = 3;
        $car->save();


        $response = $this->call('PUT', '/api/store_site/4/car/1718', [
            "observation" => "fouirhfniu hneirughn ierughnieur huemeig",
            "price" => 25457,
            "color_id" => 1,
            "km" => 4546546,
            "optionals" => [58, 59, 60]
        ], [], [], [
            'HTTP_API_KEY' => $store->store_token
        ]);
        $this->seeJson(['success' => false, 'msg' => 'Anúncio não pode ser editado'])->assertResponseStatus(401);

    }

    public function testCarEditAuditable()
    {
        $this->expectsJobs([EditCarPodioJob::class]);
        $store = Store::find(4);
        $car = \App\Admin\Dashboard\Models\Car::find(1718);
        $car->car_status_id = 1;
        $car->save();


        $response = $this->call('PUT', '/api/store_site/4/car/1718', [
            "observation" => "fouirhfniu hneirughn ierughnieur huemeig",
            "price" => 25457,
            "color_id" => 1,
            'cost' => 12447,
            "km" => 4546546,
            "optionals" => [58, 59, 60]
        ], [], [], [
            'HTTP_API_KEY' => $store->store_token
        ]);
        $this->seeJson(['success' => true])->assertResponseStatus(200);
        $this->seeInDatabase('car', ['id' => $car->id, 'observation' => 'fouirhfniu hneirughn ierughnieur huemeig']);
    }

    public function testCarEditBackToModeration()
    {
        $this->expectsJobs([EditCarPodioJob::class]);
        $store = Store::find(4);
        $car = \App\Admin\Dashboard\Models\Car::find(1718);
        $car->car_status_id = 6;
        $car->save();


        $response = $this->call('PUT', '/api/store_site/4/car/1718', [
            "observation" => "fouirhfniu hneirughn ierughnieur huemeig",
            "price" => 25457,
            "color_id" => 1,
            'cost' => 12447,
            "km" => 4546546,
            "optionals" => [58, 59, 60]
        ], [], [], [
            'HTTP_API_KEY' => $store->store_token
        ]);
        $this->seeJson(['success' => true])->assertResponseStatus(200);
        $this->seeInDatabase('car', ['id' => $car->id, 'car_status_id' => 5, 'is_edited' => 1, 'observation' => 'fouirhfniu hneirughn ierughnieur huemeig']);
    }

    public function testRemoveCar()
    {
        $this->expectsJobs([\App\Core\Jobs\CarStatusPodioJob::class, \App\Core\Jobs\NewSellPodioJob::class]);

        $store = Store::find(4);
        $car = \App\Admin\Dashboard\Models\Car::find(1718);
        $car->car_status_id = 1;
        $car->save();


        $response = $this->call('POST', '/api/store_site/4/car/1718/remove', [
            'reason_id' => 1
        ], [], [], [
            'HTTP_API_KEY' => $store->store_token
        ]);
        $this->seeJson(['success' => true, 'msg' => 'Parabéns, seu veículo foi vendido.'])->assertResponseStatus(200);

    }


}
