<?php

use App\Core\Jobs\CarStatusPodioJob;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class ApiUserControllerRegisterUserTest extends TestCase
{

    use DatabaseTransactions;

    private function removeDealershipData(array $data): array
    {
        return array_filter($data, function($key) {
            if (strstr($key, 'dealership_')) {
                return false;
            }
            return true;
        }, ARRAY_FILTER_USE_KEY);

    }

    public function testValidationFail()
    {
        $this->post('/api/register')
            ->assertResponseStatus(422);
    }

    public function testRegisterDocumentOnBlacklist()
    {
        // insert document on database
        $data = [
            'field_name' => 'document',
            'field_content' => '28425805910',
            'reason' => 'Coloquei vc na blacklist só pra testes',
            'attempts' => 0
        ];
        $blacklist = \App\Admin\Dashboard\Models\UserBlacklist::create($data);
        $this->seeInDatabase('user_blacklist', $data);

        $userdata = [
            'user_type'               => 3,
            'dealership_company_name' => 'sdfsdf',
            'dealership_trade_name'   => 'sdfsdfsd',
            'dealership_cnpj'         => '28425805910',
            'dealership_city_id'      => '4459',
            'dealership_neighborhood' => 'Pagani',
            'dealership_street'       => 'Av Atílio Pedro Pagani',
            'dealership_number'       => '420',
            'dealership_complement'   => 'Caosucijas',
            'dealership_landmark'     => 'ascasc',
            'dealership_zipcode'      => '88117292',
            'name'                    => 'Fulaninho',
            'document'                => '28425805910',
            'email'                   => 'xpato@zzpt.com',
            'zipcode'                 => '88117292',
            'state'                   => 'SC',
            'city'                    => 'Palhoça',
            'cell_phone'              => '4899194141',
            'password'                => '321'
        ];

        $this->post('/api/register', $userdata)
            ->seeJson(['success' => false])
            ->assertResponseStatus(401);
    }
    
    public function testParticularRegister()
    {

        $this->expectsJobs([\App\Core\Jobs\SendWelcomeEmail::class, \App\Core\Jobs\NewUserPodioJob::class]);

        $userdata = [
            'user_type'               => 3,
            'dealership_company_name' => 'sdfsdf',
            'dealership_trade_name'   => 'sdfsdfsd',
            'dealership_cnpj'         => '28425805910',
            'dealership_city_id'      => '4459',
            'dealership_neighborhood' => 'Pagani',
            'dealership_street'       => 'Av Atílio Pedro Pagani',
            'dealership_number'       => '420',
            'dealership_complement'   => 'Caosucijas',
            'dealership_landmark'     => 'ascasc',
            'dealership_zipcode'      => '88117292',
            'name'                    => 'Fulaninho',
            'document'                => '28425805910',
            'email'                   => 'xpato@zzpt.com',
            'zipcode'                 => '88117292',
            'state'                   => 'SC',
            'city'                    => 'Palhoça',
            'cell_phone'              => '4899194141',
            'password'                => '321'
        ];

        $user = $this->removeDealershipData($userdata);

        unset($user['password']);

        $this->post('/api/register', $userdata)
            ->seeJson(['success' => true])
            ->assertResponseStatus(200);
        $this->seeInDatabase('user', $user);
    }

    public function testCorretorRegister()
    {

        $this->expectsJobs([\App\Core\Jobs\SendWelcomeEmail::class, \App\Core\Jobs\GeolocationJob::class, \App\Core\Jobs\NewUserPodioJob::class]);

        $userdata = [
            'user_type'               => 4,
            'dealership_company_name' => 'sdfsdf',
            'dealership_trade_name'   => 'sdfsdfsd',
            'dealership_cnpj'         => '28425805910',
            'dealership_city_id'      => '4459',
            'dealership_neighborhood' => 'Pagani',
            'dealership_street'       => 'Av Atílio Pedro Pagani',
            'dealership_number'       => '420',
            'dealership_complement'   => 'Caosucijas',
            'dealership_landmark'     => 'ascasc',
            'dealership_zipcode'      => '88117292',
            'name'                    => 'Fulaninho',
            'document'                => '28425805910',
            'address'                 => 'Av Atílio Pedro Pagani',
            'email'                   => 'xpato@zzpt.com',
            'zipcode'                 => '88117292',
            'state'                   => 'SC',
            'city'                    => 'Palhoça',
            'cell_phone'              => '4899194141',
            'password'                => '321'
        ];

        $user = $this->removeDealershipData($userdata);

        unset($user['password']);

        $this->post('/api/register', $userdata)
            ->seeJson(['success' => true])
            ->assertResponseStatus(200);
        $this->seeInDatabase('user', $user);
    }

    public function testLojistaRegister()
    {
        $this->expectsJobs([\App\Core\Jobs\SendWelcomeEmail::class, \App\Core\Jobs\GeolocationJob::class, \App\Core\Jobs\NewUserPodioJob::class]);


        $userdata = [
            'user_type'               => 1,
            'dealership_company_name' => 'sdfsdf',
            'dealership_trade_name'   => 'sdfsdfsd',
            'dealership_cnpj'         => '28425805910',
            'dealership_city_id'      => '4593',
            'dealership_neighborhood' => 'Pagani',
            'dealership_street'       => 'Av Atílio Pedro Pagani',
            'dealership_number'       => '420',
            'dealership_complement'   => 'Caosucijas',
            'dealership_landmark'     => 'ascasc',
            'dealership_zipcode'      => '88117292',
            'name'                    => 'Fulaninho',
            'document'                => '28425805910',
            'email'                   => 'xpato@zzpt.com',
            'cell_phone'              => '4899194141',
            'password'                => '321'
        ];

        $user = $this->removeDealershipData($userdata);

        unset($user['password']);

        $this->post('/api/register', $userdata)
            ->seeJson(['success' => true])
            ->assertResponseStatus(200);
        $this->seeInDatabase('user', $user);

    }

    public function testRegisterParticularDealershipName()
    {

        $this->expectsJobs([\App\Core\Jobs\SendWelcomeEmail::class, \App\Core\Jobs\NewUserPodioJob::class]);

        $userdata = [
            'user_type'               => 3,
            'dealership_company_name' => 'sdfsdf',
            'dealership_trade_name'   => 'sdfsdfsd',
            'dealership_cnpj'         => '28425805910',
            'dealership_city_id'      => '4459',
            'dealership_neighborhood' => 'Pagani',
            'dealership_street'       => 'Av Atílio Pedro Pagani',
            'dealership_number'       => '420',
            'dealership_complement'   => 'Caosucijas',
            'dealership_landmark'     => 'ascasc',
            'dealership_zipcode'      => '88117292',
            'name'                    => 'Fulaninho',
            'document'                => '28425805910',
            'email'                   => 'xpato@zzpt.com',
            'zipcode'                 => '88117292',
            'state'                   => 'SC',
            'city'                    => 'Palhoça',
            'cell_phone'              => '4899194141',
            'password'                => '321'
        ];

        $user = $this->removeDealershipData($userdata);

        unset($user['password']);
        $user['dealership'] = $user['name'];

        $this->post('/api/register', $userdata)
            ->seeJson(['success' => true])
            ->assertResponseStatus(200);
        $this->seeInDatabase('user', $user);
    }

    public function testRepassadorRegister()
    {

        $this->expectsJobs([\App\Core\Jobs\SendWelcomeEmail::class, \App\Core\Jobs\NewUserPodioJob::class]);

        $userdata = [
            'user_type'               => 2,
            'name'                    => 'Fulaninho',
            'document'                => '28425805910',
            'cell_phone'              => '4899194141',
            'password'                => '321',
            'email'                   => 'xpato@zzpt.com'
        ];

        $user = $this->removeDealershipData($userdata);

        unset($user['password']);
        $user['dealership'] = $user['name'];

        $this->post('/api/register', $userdata)
            ->seeJson(['success' => true])
            ->assertResponseStatus(200);
        $this->seeInDatabase('user', $user);
    }

}
